@@ -10,7 +10,7 @@
 #include "xmp.h"
 
 #if defined(__GNUC__) || defined(__clang__)
-#if !defined(WIN32) && !defined(ANDROID) && !defined(__APPLE__) && !defined(__AMIGA__) && !defined(B_BEOS_VERSION) && !defined(__ATHEOS__) && !defined(EMSCRIPTEN) && !defined(__MINT__) 
+#if !defined(WIN32) && !defined(__ANDROID__) && !defined(__APPLE__) && !defined(__AMIGA__) && !defined(B_BEOS_VERSION) && !defined(__ATHEOS__) && !defined(EMSCRIPTEN) && !defined(__MINT__) 
 #define USE_VERSIONED_SYMBOLS
 #endif
 #endif
@@ -45,7 +45,6 @@ typedef signed long long int64;
 /* Constants */
 #define PAL_RATE	250.0		/* 1 / (50Hz * 80us)		  */
 #define NTSC_RATE	208.0		/* 1 / (60Hz * 80us)		  */
-#define C4_FREQ		130812		/* 440Hz / (2 ^ (21 / 12)) * 1000 */
 #define C4_PAL_RATE	8287		/* 7093789.2 / period (C4) * 2	  */
 #define C4_NTSC_RATE	8363		/* 7159090.5 / period (C4) * 2	  */
 
@@ -92,7 +91,7 @@ void __inline CLIB_DECL D_(const char *text, ...) { do {} while (0); }
 #endif
 #endif
 
-#elif defined ANDROID
+#elif defined __ANDROID__
 
 #ifdef DEBUG
 #include <android/log.h>
@@ -147,7 +146,7 @@ void __inline CLIB_DECL D_(const char *text, ...) { do {} while (0); }
 #define QUIRK_VOLPDN	(1 << 9)	/* Set priority to volume slide down */
 #define QUIRK_UNISLD	(1 << 10)	/* Unified pitch slide/portamento */
 #define QUIRK_ITVPOR	(1 << 11)	/* Disable fine bends in IT vol fx */
-/*#define QUIRK_LINEAR	(1 << 12)*/	/* Linear periods */
+#define QUIRK_FTMOD	(1 << 12)	/* Flag for multichannel mods */
 /*#define QUIRK_MODRNG	(1 << 13)*/	/* Limit periods to MOD range */
 #define QUIRK_INSVOL	(1 << 14)	/* Use instrument volume */
 #define QUIRK_VIRTUAL	(1 << 15)	/* Enable virtual channels */
@@ -228,6 +227,11 @@ struct smix_data {
 	struct xmp_sample *xxs;
 };
 
+/* This will be added to the sample structure in the next API revision */
+struct extra_sample_data {
+	double c5spd;
+};
+
 struct module_data {
 	struct xmp_module mod;
 
@@ -264,6 +268,7 @@ struct module_data {
 	char *instrument_path;
 	void *extra;			/* format-specific extra fields */
 	char **scan_cnt;		/* scan counters */
+	struct extra_sample_data *xtra;
 #ifndef LIBXMP_CORE_DISABLE_IT
 	struct xmp_sample *xsmp;	/* sustain loop samples */
 #endif
@@ -377,12 +382,12 @@ struct context_data {
 
 /* Prototypes */
 
-char	*adjust_string		(char *);
-int	exclude_match		(char *);
-int	prepare_scan		(struct context_data *);
-int	scan_sequences		(struct context_data *);
-int	get_sequence		(struct context_data *, int);
-int	set_player_mode		(struct context_data *);
+char	*libxmp_adjust_string	(char *);
+int	libxmp_exclude_match	(char *);
+int	libxmp_prepare_scan	(struct context_data *);
+int	libxmp_scan_sequences	(struct context_data *);
+int	libxmp_get_sequence	(struct context_data *, int);
+int	libxmp_set_player_mode	(struct context_data *);
 
 int8	read8s			(FILE *, int *err);
 uint8	read8			(FILE *, int *err);
@@ -406,7 +411,7 @@ uint32	readmem24b		(uint8 *);
 uint32	readmem32l		(uint8 *);
 uint32	readmem32b		(uint8 *);
 
-struct xmp_instrument *get_instrument(struct context_data *, int);
-struct xmp_sample *get_sample(struct context_data *, int);
+struct xmp_instrument *libxmp_get_instrument(struct context_data *, int);
+struct xmp_sample *libxmp_get_sample(struct context_data *, int);
 
 #endif /* LIBXMP_COMMON_H */
