@@ -44,6 +44,7 @@ xmp_context xmp_create_context()
 
 	ctx->state = XMP_STATE_UNLOADED;
 	ctx->m.defpan = 100;
+	ctx->s.numvoc = SMIX_NUMVOC;
 
 	return (xmp_context)ctx;
 }
@@ -69,7 +70,7 @@ static void set_position(struct context_data *ctx, int pos, int dir)
 
 	/* If dir is 0, we can jump to a different sequence */
 	if (dir == 0) {
-		seq = get_sequence(ctx, pos);
+		seq = libxmp_get_sequence(ctx, pos);
 	} else {
 		seq = p->sequence;
 	}
@@ -211,7 +212,7 @@ int xmp_seek_time(xmp_context opaque, int time)
 		if (pat >= m->mod.pat) {
 			continue;
 		}
-		if (get_sequence(ctx, i) != p->sequence) {
+		if (libxmp_get_sequence(ctx, i) != p->sequence) {
 			continue;
 		}
 		t = m->xxo_info[i].time;
@@ -278,10 +279,13 @@ extern int xmp_set_player_v41__(xmp_context, int, int)
 	__attribute__((alias("xmp_set_player_v40__")));
 extern int xmp_set_player_v43__(xmp_context, int, int)
 	__attribute__((alias("xmp_set_player_v40__")));
+extern int xmp_set_player_v44__(xmp_context, int, int)
+	__attribute__((alias("xmp_set_player_v40__")));
 
 asm(".symver xmp_set_player_v40__, xmp_set_player@XMP_4.0");
 asm(".symver xmp_set_player_v41__, xmp_set_player@XMP_4.1");
-asm(".symver xmp_set_player_v43__, xmp_set_player@@XMP_4.3");
+asm(".symver xmp_set_player_v43__, xmp_set_player@XMP_4.3");
+asm(".symver xmp_set_player_v44__, xmp_set_player@@XMP_4.4");
 
 #define xmp_set_player__ xmp_set_player_v40__
 #else
@@ -296,10 +300,17 @@ int xmp_set_player__(xmp_context opaque, int parm, int val)
 	struct mixer_data *s = &ctx->s;
 	int ret = -XMP_ERROR_INVALID;
 
+
 	if (parm == XMP_PLAYER_SMPCTL || parm == XMP_PLAYER_DEFPAN) {
 		/* these should be set before loading the module */
-		if (ctx->state >= XMP_STATE_LOADED)
+		if (ctx->state >= XMP_STATE_LOADED) {
 			return -XMP_ERROR_STATE;
+		}
+	} else if (parm == XMP_PLAYER_VOICES) {
+		/* these should be set before start playing */
+		if (ctx->state >= XMP_STATE_PLAYING) {
+			return -XMP_ERROR_STATE;
+		}
 	} else if (ctx->state < XMP_STATE_PLAYING) {
 		return -XMP_ERROR_STATE;
 	}
@@ -328,11 +339,7 @@ int xmp_set_player__(xmp_context opaque, int parm, int val)
 		ret = 0;
 		break;
 	case XMP_PLAYER_FLAGS: {
-		int vblank = p->flags & XMP_FLAGS_VBLANK;
 		p->player_flags = val;
-		p->flags |= val;
-		if (vblank != (p->flags & XMP_FLAGS_VBLANK))
-			scan_sequences(ctx);
 		ret = 0;
 		break; }
 
@@ -341,7 +348,7 @@ int xmp_set_player__(xmp_context opaque, int parm, int val)
 		int vblank = p->flags & XMP_FLAGS_VBLANK;
 		p->flags = val;
 		if (vblank != (p->flags & XMP_FLAGS_VBLANK))
-			scan_sequences(ctx);
+			libxmp_scan_sequences(ctx);
 		ret = 0;
 		break; }
 	case XMP_PLAYER_SMPCTL:
@@ -368,6 +375,17 @@ int xmp_set_player__(xmp_context opaque, int parm, int val)
 			ret = 0;
 		}
 		break;
+
+	/* 4.4 */
+	case XMP_PLAYER_MODE:
+		p->mode = val;
+		libxmp_set_player_mode(ctx);
+		libxmp_scan_sequences(ctx);
+		ret = 0;
+		break;
+	case XMP_PLAYER_VOICES:
+		s->numvoc = val;
+		break;
 	}
 
 	return ret;
@@ -380,11 +398,14 @@ extern int xmp_get_player_v42__(xmp_context, int)
 	__attribute__((alias("xmp_get_player_v40__")));
 extern int xmp_get_player_v43__(xmp_context, int)
 	__attribute__((alias("xmp_get_player_v40__")));
+extern int xmp_get_player_v44__(xmp_context, int)
+	__attribute__((alias("xmp_get_player_v40__")));
 
 asm(".symver xmp_get_player_v40__, xmp_get_player@XMP_4.0");
 asm(".symver xmp_get_player_v41__, xmp_get_player@XMP_4.1");
 asm(".symver xmp_get_player_v42__, xmp_get_player@XMP_4.2");
-asm(".symver xmp_get_player_v43__, xmp_get_player@@XMP_4.3");
+asm(".symver xmp_get_player_v43__, xmp_get_player@XMP_4.3");
+asm(".symver xmp_get_player_v44__, xmp_get_player@@XMP_4.4");
 
 #define xmp_get_player__ xmp_get_player_v40__
 #else
@@ -445,6 +466,28 @@ int xmp_get_player__(xmp_context opaque, int parm)
 	case XMP_PLAYER_DEFPAN:
 		ret = m->defpan;
 		break;
+
+	/* 4.4 */
+	case XMP_PLAYER_MODE:
+		ret = p->mode;
+		break;
+	case XMP_PLAYER_MIXER_TYPE:
+		ret = XMP_MIXER_STANDARD;
+		if (p->flags & XMP_FLAGS_A500) {
+			if (IS_AMIGA_MOD()) {
+#ifdef LIBXMP_PAULA_SIMULATOR
+				if (p->filter) {
+					ret = XMP_MIXER_A500F;
+				} else {
+					ret = XMP_MIXER_A500;
+				}
+#endif
+			}
+		}
+		break;
+	case XMP_PLAYER_VOICES:
+		ret = s->numvoc;
+		break;
 	}
 
 	return ret;
