@@ -780,7 +780,7 @@ int decompress(FILE *in, struct huffman_t *huffman, struct bitstream_t *bitstrea
       if (window_ptr>=WINDOW_SIZE)
       {
         fwrite(window,1,WINDOW_SIZE,out);
-        huffman->checksum=crc32_A2(huffman->window,WINDOW_SIZE,huffman->checksum);
+        huffman->checksum=libxmp_crc32_A2(huffman->window,WINDOW_SIZE,huffman->checksum);
         window_ptr=0;
       }
     }
@@ -959,7 +959,7 @@ exit(0);
           if (window_ptr>=WINDOW_SIZE)
           {
             fwrite(window,1,WINDOW_SIZE,out);
-            huffman->checksum=crc32_A2(huffman->window,WINDOW_SIZE,huffman->checksum);
+            huffman->checksum=libxmp_crc32_A2(huffman->window,WINDOW_SIZE,huffman->checksum);
             window_ptr=0;
           }
         }
@@ -978,7 +978,7 @@ exit(0);
   return 0;
 }
 
-int inflate(FILE *in, FILE *out, uint32 *checksum, int is_zip)
+int libxmp_inflate(FILE *in, FILE *out, uint32 *checksum, int is_zip)
 {
 /* #ifndef ZIP */
   unsigned char CMF, FLG;
@@ -1111,7 +1111,7 @@ if (!is_zip) {
         if (huffman.window_ptr>=WINDOW_SIZE)
         {
           fwrite(huffman.window,1,WINDOW_SIZE,out);
-          huffman.checksum=crc32_A2(huffman.window,WINDOW_SIZE,huffman.checksum);
+          huffman.checksum=libxmp_crc32_A2(huffman.window,WINDOW_SIZE,huffman.checksum);
           huffman.window_ptr=0;
         }
       }
@@ -1163,7 +1163,7 @@ if (!is_zip) {
   if (huffman.window_ptr!=0)
   {
     fwrite(huffman.window,1,huffman.window_ptr,out);
-    huffman.checksum=crc32_A2(huffman.window,huffman.window_ptr,huffman.checksum);
+    huffman.checksum=libxmp_crc32_A2(huffman.window,huffman.window_ptr,huffman.checksum);
   }
 
 
