@@ -27,7 +27,7 @@ static int decrunch_xz(FILE *in, FILE *out)
 	unsigned char *membuf;
 	int ret = 0;
 
-	crc32_init_A();
+	libxmp_crc32_init_A();
 
 	memset(&b, 0, sizeof(b));
 	if ((membuf = malloc(2 * BUFFER_SIZE)) == NULL)
@@ -76,7 +76,7 @@ static int decrunch_xz(FILE *in, FILE *out)
 	return ret;
 }
 
-struct depacker xz_depacker = {
+struct depacker libxmp_depacker_xz = {
 	test_xz,
 	decrunch_xz
 };
