@@ -34,8 +34,8 @@
 #define HAS_QUIRK(x) (m->quirk & (x))
 
 #define SET_LFO_NOTZERO(lfo, depth, rate) do { \
-	if ((depth) != 0) set_lfo_depth(lfo, depth); \
-	if ((rate) != 0) set_lfo_rate(lfo, rate); \
+	if ((depth) != 0) libxmp_lfo_set_depth(lfo, depth); \
+	if ((rate) != 0)  libxmp_lfo_set_rate(lfo, rate); \
 } while (0)
 
 #define EFFECT_MEMORY__(p, m) do { \
@@ -83,14 +83,14 @@ static void do_toneporta(struct context_data *ctx,
 
 	if (note >= 1 && note <= 0x80 && (uint32)xc->ins < m->mod.ins) {
 		note--;
-		xc->porta.target = note_to_period(ctx, note + sub->xpo +
+		xc->porta.target = libxmp_note_to_period(ctx, note + sub->xpo +
 			instrument->map[xc->key_porta].xpo, xc->finetune,
 			xc->per_adj);
 	}
 	xc->porta.dir = xc->period < xc->porta.target ? 1 : -1;
 }
 
-void process_fx(struct context_data *ctx, struct channel_data *xc, int chn,
+void libxmp_process_fx(struct context_data *ctx, struct channel_data *xc, int chn,
 		struct xmp_event *e, int fnum)
 {
 	struct player_data *p = &ctx->p;
@@ -259,6 +259,10 @@ void process_fx(struct context_data *ctx, struct channel_data *xc, int chn,
 		break;
 
 	case FX_SETPAN:		/* Set pan */
+		if (HAS_QUIRK(QUIRK_PROTRACK)) {
+			break;
+		}
+	    fx_setpan:
 		/* From OpenMPT PanOff.xm:
 		 * "Another chapter of weird FT2 bugs: Note-Off + Note Delay
 		 *  + Volume Column Panning = Panning effect is ignored."
@@ -397,7 +401,7 @@ void process_fx(struct context_data *ctx, struct channel_data *xc, int chn,
 			break;
 		case EX_VIBRATO_WF:	/* Set vibrato waveform */
 			fxp &= 3;
-			set_lfo_waveform(&xc->vibrato.lfo, fxp);
+			libxmp_lfo_set_waveform(&xc->vibrato.lfo, fxp);
 			break;
 		case EX_FINETUNE:	/* Set finetune */
 			if (!HAS_QUIRK(QUIRK_FT2BUGS) || note > 0) {
@@ -428,8 +432,11 @@ void process_fx(struct context_data *ctx, struct channel_data *xc, int chn,
 			}
 			break;
 		case EX_TREMOLO_WF:	/* Set tremolo waveform */
-			set_lfo_waveform(&xc->tremolo.lfo, fxp & 3);
+			libxmp_lfo_set_waveform(&xc->tremolo.lfo, fxp & 3);
 			break;
+		case EX_SETPAN:
+			fxp <<= 4;
+			goto fx_setpan;
 		case EX_RETRIG:		/* Retrig note */
 			SET(RETRIG);
 			xc->retrig.val = fxp;
@@ -632,7 +639,7 @@ void process_fx(struct context_data *ctx, struct channel_data *xc, int chn,
 		 */
 		if (HAS_QUIRK(QUIRK_FT2BUGS)) {
 			struct xmp_instrument *instrument;
-			instrument = get_instrument(ctx, xc->ins);
+			instrument = libxmp_get_instrument(ctx, xc->ins);
 			if (instrument != NULL) {
 				if (instrument->aei.flg & XMP_ENVELOPE_SUS) {
 					xc->p_idx = fxp;
@@ -767,25 +774,25 @@ void process_fx(struct context_data *ctx, struct channel_data *xc, int chn,
 	case FX_IT_INSTFUNC:
 		switch (fxp) {
 		case 0:	/* Past note cut */
-			virt_pastnote(ctx, chn, VIRT_ACTION_CUT);
+			libxmp_virt_pastnote(ctx, chn, VIRT_ACTION_CUT);
 			break;
 		case 1:	/* Past note off */
-			virt_pastnote(ctx, chn, VIRT_ACTION_OFF);
+			libxmp_virt_pastnote(ctx, chn, VIRT_ACTION_OFF);
 			break;
 		case 2:	/* Past note fade */
-			virt_pastnote(ctx, chn, VIRT_ACTION_FADE);
+			libxmp_virt_pastnote(ctx, chn, VIRT_ACTION_FADE);
 			break;
 		case 3:	/* Set NNA to note cut */
-			virt_setnna(ctx, chn, XMP_INST_NNA_CUT);
+			libxmp_virt_setnna(ctx, chn, XMP_INST_NNA_CUT);
 			break;
 		case 4:	/* Set NNA to continue */
-			virt_setnna(ctx, chn, XMP_INST_NNA_CONT);
+			libxmp_virt_setnna(ctx, chn, XMP_INST_NNA_CONT);
 			break;
 		case 5:	/* Set NNA to note off */
-			virt_setnna(ctx, chn, XMP_INST_NNA_OFF);
+			libxmp_virt_setnna(ctx, chn, XMP_INST_NNA_OFF);
 			break;
 		case 6:	/* Set NNA to note fade */
-			virt_setnna(ctx, chn, XMP_INST_NNA_FADE);
+			libxmp_virt_setnna(ctx, chn, XMP_INST_NNA_FADE);
 			break;
 		case 7:	/* Turn off volume envelope */
 			SET_PER(VENV_PAUSE);
@@ -820,7 +827,7 @@ void process_fx(struct context_data *ctx, struct channel_data *xc, int chn,
 		SET_LFO_NOTZERO(&xc->panbrello.lfo, LSN(fxp) << 4, MSN(fxp));
 		break;
 	case FX_PANBRELLO_WF:	/* Panbrello waveform */
-		set_lfo_waveform(&xc->panbrello.lfo, fxp & 3);
+		libxmp_lfo_set_waveform(&xc->panbrello.lfo, fxp & 3);
 		break;
 	case FX_HIOFFSET:	/* High offset */
 		xc->offset.val &= 0xffff;
@@ -853,14 +860,14 @@ void process_fx(struct context_data *ctx, struct channel_data *xc, int chn,
 		break;
 	case FX_PITCH_ADD:
 		SET_PER(TONEPORTA);
-		xc->porta.target = note_to_period(ctx, note - 1, xc->finetune, 0)
+		xc->porta.target = libxmp_note_to_period(ctx, note - 1, xc->finetune, 0)
 			+ fxp;
 		xc->porta.slide = 2;
 		xc->porta.dir = 1;
 		break;
 	case FX_PITCH_SUB:
 		SET_PER(TONEPORTA);
-		xc->porta.target = note_to_period(ctx, note - 1, xc->finetune, 0)
+		xc->porta.target = libxmp_note_to_period(ctx, note - 1, xc->finetune, 0)
 			- fxp;
 		xc->porta.slide = 2;
 		xc->porta.dir = -1;
@@ -1044,7 +1051,7 @@ void process_fx(struct context_data *ctx, struct channel_data *xc, int chn,
 		break;
 	case FX_669_VIBRATO:	/* 669 vibrato */
 		if (LSN(fxp) != 0) {
-			set_lfo_waveform(&xc->vibrato.lfo, 669);
+			libxmp_lfo_set_waveform(&xc->vibrato.lfo, 669);
 			SET_PER(VIBRATO);
 		} else {
 			RESET_PER(VIBRATO);
@@ -1055,7 +1062,7 @@ void process_fx(struct context_data *ctx, struct channel_data *xc, int chn,
 
 	default:
 #ifndef LIBXMP_CORE_PLAYER
-		extras_process_fx(ctx, xc, chn, note, fxt, fxp, fnum);
+		libxmp_extras_process_fx(ctx, xc, chn, note, fxt, fxp, fnum);
 #endif
 		break;
 	}
