@@ -31,60 +31,60 @@
  * Module extras
  */
 
-void release_module_extras(struct context_data *ctx)
+void libxmp_release_module_extras(struct context_data *ctx)
 {
 	struct module_data *m = &ctx->m;
 
 	if (HAS_MED_MODULE_EXTRAS(*m))
-		med_release_module_extras(m);
+		libxmp_med_release_module_extras(m);
 	else if (HAS_HMN_MODULE_EXTRAS(*m))
-		hmn_release_module_extras(m);
+		libxmp_hmn_release_module_extras(m);
 }
 
 /*
  * Channel extras
  */
 
-int new_channel_extras(struct context_data *ctx, struct channel_data *xc)
+int libxmp_new_channel_extras(struct context_data *ctx, struct channel_data *xc)
 {
 	struct module_data *m = &ctx->m;
 
 	if (HAS_MED_MODULE_EXTRAS(*m)) {
-		if (med_new_channel_extras(xc) < 0)
+		if (libxmp_med_new_channel_extras(xc) < 0)
 			return -1;
 	} else if (HAS_HMN_MODULE_EXTRAS(*m)) {
-		if (hmn_new_channel_extras(xc) < 0)
+		if (libxmp_hmn_new_channel_extras(xc) < 0)
 			return -1;
 	}
 
 	return 0;
 }
 
-void release_channel_extras(struct context_data *ctx, struct channel_data *xc)
+void libxmp_release_channel_extras(struct context_data *ctx, struct channel_data *xc)
 {
 	struct module_data *m = &ctx->m;
 
 	if (HAS_MED_CHANNEL_EXTRAS(*m))
-		med_release_channel_extras(xc);
+		libxmp_med_release_channel_extras(xc);
 	else if (HAS_HMN_CHANNEL_EXTRAS(*m))
-		hmn_release_channel_extras(xc);
+		libxmp_hmn_release_channel_extras(xc);
 }
 
-void reset_channel_extras(struct context_data *ctx, struct channel_data *xc)
+void libxmp_reset_channel_extras(struct context_data *ctx, struct channel_data *xc)
 {
 	struct module_data *m = &ctx->m;
 
 	if (HAS_MED_CHANNEL_EXTRAS(*m))
-		med_reset_channel_extras(xc);
+		libxmp_med_reset_channel_extras(xc);
 	else if (HAS_HMN_CHANNEL_EXTRAS(*m))
-		hmn_reset_channel_extras(xc);
+		libxmp_hmn_reset_channel_extras(xc);
 }
 
 /*
  * Player extras
  */
 
-void play_extras(struct context_data *ctx, struct channel_data *xc, int chn)
+void libxmp_play_extras(struct context_data *ctx, struct channel_data *xc, int chn)
 {
 	struct module_data *m = &ctx->m;
 
@@ -92,12 +92,12 @@ void play_extras(struct context_data *ctx, struct channel_data *xc, int chn)
 		return;
 
         if (HAS_MED_INSTRUMENT_EXTRAS(m->mod.xxi[xc->ins]))
-		med_play_extras(ctx, xc, chn);
+		libxmp_med_play_extras(ctx, xc, chn);
         else if (HAS_HMN_INSTRUMENT_EXTRAS(m->mod.xxi[xc->ins]))
-		hmn_play_extras(ctx, xc, chn);
+		libxmp_hmn_play_extras(ctx, xc, chn);
 }
 
-int extras_get_volume(struct context_data *ctx, struct channel_data *xc)
+int libxmp_extras_get_volume(struct context_data *ctx, struct channel_data *xc)
 {
 	struct module_data *m = &ctx->m;
 	int vol;
@@ -114,36 +114,36 @@ int extras_get_volume(struct context_data *ctx, struct channel_data *xc)
 	return vol;
 }
 
-int extras_get_period(struct context_data *ctx, struct channel_data *xc)
+int libxmp_extras_get_period(struct context_data *ctx, struct channel_data *xc)
 {
 	int period;
 
 	if (HAS_MED_CHANNEL_EXTRAS(*xc))
-		period = med_change_period(ctx, xc);
+		period = libxmp_med_change_period(ctx, xc);
 	else period = 0;
 
 	return period;
 }
 
-int extras_get_linear_bend(struct context_data *ctx, struct channel_data *xc)
+int libxmp_extras_get_linear_bend(struct context_data *ctx, struct channel_data *xc)
 {
 	int linear_bend;
 
 	if (HAS_MED_CHANNEL_EXTRAS(*xc))
-		linear_bend = med_linear_bend(ctx, xc);
+		linear_bend = libxmp_med_linear_bend(ctx, xc);
 	else if (HAS_HMN_CHANNEL_EXTRAS(*xc))
-		linear_bend = hmn_linear_bend(ctx, xc);
+		linear_bend = libxmp_hmn_linear_bend(ctx, xc);
 	else
 		linear_bend = 0;
 
 	return linear_bend;
 }
 
-void extras_process_fx(struct context_data *ctx, struct channel_data *xc,
+void libxmp_extras_process_fx(struct context_data *ctx, struct channel_data *xc,
 			int chn, uint8 note, uint8 fxt, uint8 fxp, int fnum)
 {
 	if (HAS_MED_CHANNEL_EXTRAS(*xc))
-		med_extras_process_fx(ctx, xc, chn, note, fxt, fxp, fnum);
+		libxmp_med_extras_process_fx(ctx, xc, chn, note, fxt, fxp, fnum);
 	else if (HAS_HMN_CHANNEL_EXTRAS(*xc))
-		hmn_extras_process_fx(ctx, xc, chn, note, fxt, fxp, fnum);
+		libxmp_hmn_extras_process_fx(ctx, xc, chn, note, fxt, fxp, fnum);
 }
