@@ -17,6 +17,7 @@ typedef struct {
 		FILE *file;
 		MFILE *mem;
 	} handle;
+	int error;
 } HIO_HANDLE;
 
 int8	hio_read8s	(HIO_HANDLE *);
@@ -31,6 +32,7 @@ size_t	hio_read	(void *, size_t, size_t, HIO_HANDLE *);
 int	hio_seek	(HIO_HANDLE *, long, int);
 long	hio_tell	(HIO_HANDLE *);
 int	hio_eof		(HIO_HANDLE *);
+int	hio_error	(HIO_HANDLE *);
 HIO_HANDLE *hio_open	(void *, char *);
 HIO_HANDLE *hio_open_mem  (void *, long);
 HIO_HANDLE *hio_open_file (FILE *);
