@@ -47,9 +47,9 @@
 
 extern struct format_loader *format_loader[];
 
-void load_prologue(struct context_data *);
-void load_epilogue(struct context_data *);
-int prepare_scan(struct context_data *);
+void libxmp_load_prologue(struct context_data *);
+void libxmp_load_epilogue(struct context_data *);
+int  libxmp_prepare_scan(struct context_data *);
 
 #ifndef LIBXMP_CORE_PLAYER
 
@@ -57,22 +57,22 @@ int prepare_scan(struct context_data *);
 
 static struct depacker *depacker_list[] = {
 #if defined __AMIGA__ && !defined __AROS__
-	&xfd_depacker,
+	&libxmp_depacker_xfd,
 #endif
-	&zip_depacker,
-	&lha_depacker,
-	&gzip_depacker,
-	&bzip2_depacker,
-	&xz_depacker,
-	&compress_depacker,
-	&pp_depacker,
-	&sqsh_depacker,
-	&arcfs_depacker,
-	&mmcmp_depacker,
-	&muse_depacker,
-	&lzx_depacker,
-	&s404_depacker,
-	&arc_depacker,
+	&libxmp_depacker_zip,
+	&libxmp_depacker_lha,
+	&libxmp_depacker_gzip,
+	&libxmp_depacker_bzip2,
+	&libxmp_depacker_xz,
+	&libxmp_depacker_compress,
+	&libxmp_depacker_pp,
+	&libxmp_depacker_sqsh,
+	&libxmp_depacker_arcfs,
+	&libxmp_depacker_mmcmp,
+	&libxmp_depacker_muse,
+	&libxmp_depacker_lzx,
+	&libxmp_depacker_s404,
+	&libxmp_depacker_arc,
 	NULL
 };
 
@@ -158,7 +158,7 @@ static int decrunch(HIO_HANDLE **h, char *filename, char **temp)
 		} else if (test_oxm(f) == 0) {
 			/* oggmod */
 			D_(D_INFO "oggmod");
-			depacker = &oxm_depacker;
+			depacker = &libxmp_depacker_oxm;
 		}
 	}
 
@@ -171,7 +171,7 @@ static int decrunch(HIO_HANDLE **h, char *filename, char **temp)
 		return 0;
 	}
 
-#if defined ANDROID || defined __native_client__
+#if defined __ANDROID__ || defined __native_client__
 	/* Don't use external helpers in android */
 	if (cmd) {
 		return 0;
@@ -358,7 +358,7 @@ static int load_module(xmp_context opaque, HIO_HANDLE *h)
 	int i, j, ret;
 	int test_result, load_result;
 
-	load_prologue(ctx);
+	libxmp_load_prologue(ctx);
 
 	D_(D_WARN "load");
 	test_result = load_result = -1;
@@ -425,16 +425,23 @@ static int load_module(xmp_context opaque, HIO_HANDLE *h)
 		}
 	}
 
-	adjust_string(mod->name);
-	load_epilogue(ctx);
+	libxmp_adjust_string(mod->name);
+	for (i = 0; i < mod->ins; i++) {
+		libxmp_adjust_string(mod->xxi[i].name);
+	}
+	for (i = 0; i < mod->smp; i++) {
+		libxmp_adjust_string(mod->xxs[i].name);
+	}
 
-	ret = prepare_scan(ctx);
+	libxmp_load_epilogue(ctx);
+
+	ret = libxmp_prepare_scan(ctx);
 	if (ret < 0) {
 		xmp_release_module(opaque);
 		return ret;
 	}
 
-	scan_sequences(ctx);
+	libxmp_scan_sequences(ctx);
 
 	ctx->state = XMP_STATE_LOADED;
 
@@ -601,7 +608,7 @@ void xmp_release_module(xmp_context opaque)
 	D_(D_INFO "Freeing memory");
 
 #ifndef LIBXMP_CORE_PLAYER
-	release_module_extras(ctx);
+	libxmp_release_module_extras(ctx);
 #endif
 
 	if (mod->xxt != NULL) {
@@ -633,8 +640,20 @@ void xmp_release_module(xmp_context opaque)
 			}
 		}
 		free(mod->xxs);
+		free(m->xtra);
 	}
 
+#ifndef LIBXMP_CORE_DISABLE_IT
+	if (m->xsmp != NULL) {
+		for (i = 0; i < mod->smp; i++) {
+			if (m->xsmp[i].data != NULL) {
+				free(m->xsmp[i].data - 4);
+			}
+		}
+		free(m->xsmp);
+	}
+#endif
+
 	if (m->scan_cnt) {
 		for (i = 0; i < mod->len; i++)
 			free(m->scan_cnt[i]);
@@ -646,7 +665,6 @@ void xmp_release_module(xmp_context opaque)
 	D_("free dirname/basename");
 	free(m->dirname);
 	free(m->basename);
-
 }
 
 void xmp_scan_module(xmp_context opaque)
@@ -656,5 +674,5 @@ void xmp_scan_module(xmp_context opaque)
 	if (ctx->state < XMP_STATE_LOADED)
 		return;
 
-	scan_sequences(ctx);
+	libxmp_scan_sequences(ctx);
 }
