@@ -30,7 +30,7 @@
 
 #ifndef LIBXMP_CORE_PLAYER
 
-#ifdef ANDROID
+#ifdef __ANDROID__
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <unistd.h>
@@ -103,6 +103,13 @@ const struct module_quirk mq[] = {
 		0, XMP_MODE_ST3
 	},
 
+	/* Asle's Ode to Protracker */
+	{
+		{ 0x97, 0xa3, 0x7d, 0x30, 0xd7, 0xae, 0x6d, 0x50,
+		  0xc9, 0x62, 0xe9, 0xd8, 0x87, 0x1b, 0x7e, 0x8a },
+		0, XMP_MODE_PROTRACKER
+	},
+
 	{
 		{ 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
 		  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 },
@@ -128,7 +135,7 @@ static void module_quirks(struct context_data *ctx)
  * Check whether the given string matches one of the blacklisted glob
  * patterns. Used to filter file names stored in archive files.
  */
-int exclude_match(char *name)
+int libxmp_exclude_match(char *name)
 {
 	int i;
 
@@ -156,16 +163,18 @@ int exclude_match(char *name)
 
 #endif /* LIBXMP_CORE_PLAYER */
 
-char *adjust_string(char *s)
+char *libxmp_adjust_string(char *s)
 {
 	int i;
 
-	for (i = 0; i < strlen(s); i++)
+	for (i = 0; i < strlen(s); i++) {
 		if (!isprint((int)s[i]) || ((uint8) s[i] > 127))
 			s[i] = ' ';
+	}
 
-	while (*s && (s[strlen(s) - 1] == ' '))
+	while (*s && (s[strlen(s) - 1] == ' ')) {
 		s[strlen(s) - 1] = 0;
+	}
 
 	return s;
 }
@@ -188,7 +197,7 @@ static void check_envelope(struct xmp_envelope *env)
 	}
 }
 
-void load_prologue(struct context_data *ctx)
+void libxmp_load_prologue(struct context_data *ctx)
 {
 	struct module_data *m = &ctx->m;
 	int i;
@@ -234,7 +243,7 @@ void load_prologue(struct context_data *ctx)
 	}
 }
 
-void load_epilogue(struct context_data *ctx)
+void libxmp_load_epilogue(struct context_data *ctx)
 {
 	struct player_data *p = &ctx->p;
 	struct module_data *m = &ctx->m;
@@ -245,7 +254,7 @@ void load_epilogue(struct context_data *ctx)
 
 	/* Sanity check for module parameters */
 	CLAMP(mod->len, 0, XMP_MAX_MOD_LENGTH);
-	CLAMP(mod->pat, 0, 256);
+	CLAMP(mod->pat, 0, 257);   /* some formats have an extra pattern */
 	CLAMP(mod->ins, 0, 255);
 	CLAMP(mod->smp, 0, MAX_SAMPLES);
 	CLAMP(mod->chn, 0, XMP_MAX_CHANNELS);
@@ -294,10 +303,10 @@ void load_epilogue(struct context_data *ctx)
 #ifndef LIBXMP_CORE_PLAYER
 	module_quirks(ctx);
 #endif
-	set_player_mode(ctx);
+	libxmp_set_player_mode(ctx);
 }
 
-int prepare_scan(struct context_data *ctx)
+int libxmp_prepare_scan(struct context_data *ctx)
 {
 	struct module_data *m = &ctx->m;
 	struct xmp_module *mod = &m->mod;
@@ -325,8 +334,9 @@ int prepare_scan(struct context_data *ctx)
 
 		/* Add pattern if referenced in orders */
 		if (pat_idx < mod->pat && !mod->xxp[pat_idx]) {
-			if (pattern_alloc(mod, pat_idx) < 0)
+			if (libxmp_alloc_pattern(mod, pat_idx) < 0) {
 				return -XMP_ERROR_SYSTEM;
+			}
 		}
 
 		pat = pat_idx >= mod->pat ? NULL : mod->xxp[pat_idx];
@@ -339,7 +349,7 @@ int prepare_scan(struct context_data *ctx)
 }
 
 /* Process player personality flags */
-int set_player_mode(struct context_data *ctx)
+int libxmp_set_player_mode(struct context_data *ctx)
 {
 	struct player_data *p = &ctx->p;
 	struct module_data *m = &ctx->m;
@@ -349,49 +359,59 @@ int set_player_mode(struct context_data *ctx)
 	case XMP_MODE_AUTO:
 		break;
 	case XMP_MODE_MOD:
+		m->c4rate = C4_PAL_RATE;
 		m->quirk = 0;
 		m->read_event_type = READ_EVENT_MOD;
 		m->period_type = PERIOD_AMIGA;
 		break;
 	case XMP_MODE_NOISETRACKER:
+		m->c4rate = C4_PAL_RATE;
 		m->quirk = QUIRK_NOBPM;
 		m->read_event_type = READ_EVENT_MOD;
 		m->period_type = PERIOD_MODRNG;
 		break;
 	case XMP_MODE_PROTRACKER:
+		m->c4rate = C4_PAL_RATE;
 		m->quirk = QUIRK_PROTRACK;
 		m->read_event_type = READ_EVENT_MOD;
 		m->period_type = PERIOD_MODRNG;
 		break;
 	case XMP_MODE_S3M:
 		q = m->quirk & (QUIRK_VSALL | QUIRK_ARPMEM);
+		m->c4rate = C4_NTSC_RATE;
 		m->quirk = QUIRKS_ST3 | q;
 		m->read_event_type = READ_EVENT_ST3;
 		break;
 	case XMP_MODE_ST3:
 		q = m->quirk & (QUIRK_VSALL | QUIRK_ARPMEM);
+		m->c4rate = C4_NTSC_RATE;
 		m->quirk = QUIRKS_ST3 | QUIRK_ST3BUGS | q;
 		m->read_event_type = READ_EVENT_ST3;
 		break;
 	case XMP_MODE_ST3GUS:
 		q = m->quirk & (QUIRK_VSALL | QUIRK_ARPMEM);
+		m->c4rate = C4_NTSC_RATE;
 		m->quirk = QUIRKS_ST3 | QUIRK_ST3BUGS | q;
 		m->quirk &= ~QUIRK_RSTCHN;
 		m->read_event_type = READ_EVENT_ST3;
 		break;
 	case XMP_MODE_XM:
+		m->c4rate = C4_NTSC_RATE;
 		m->quirk = QUIRKS_FT2;
 		m->read_event_type = READ_EVENT_FT2;
 		break;
 	case XMP_MODE_FT2:
+		m->c4rate = C4_NTSC_RATE;
 		m->quirk = QUIRKS_FT2 | QUIRK_FT2BUGS;
 		m->read_event_type = READ_EVENT_FT2;
 		break;
 	case XMP_MODE_IT:
+		m->c4rate = C4_NTSC_RATE;
 		m->quirk = QUIRKS_IT | QUIRK_VIBHALF | QUIRK_VIBINV;
 		m->read_event_type = READ_EVENT_IT;
 		break;
 	case XMP_MODE_ITSMP:
+		m->c4rate = C4_NTSC_RATE;
 		m->quirk = QUIRKS_IT | QUIRK_VIBHALF | QUIRK_VIBINV;
 		m->quirk &= ~(QUIRK_VIRTUAL | QUIRK_RSTCHN);
 		m->read_event_type = READ_EVENT_IT;
