@@ -23,16 +23,16 @@
 #include "loader.h"
 
 
-static int ssn_test (HIO_HANDLE *, char *, const int);
-static int ssn_load (struct module_data *, HIO_HANDLE *, const int);
+static int c669_test (HIO_HANDLE *, char *, const int);
+static int c669_load (struct module_data *, HIO_HANDLE *, const int);
 
-const struct format_loader ssn_loader = {
+const struct format_loader libxmp_loader_669 = {
     "Composer 669",
-    ssn_test,
-    ssn_load
+    c669_test,
+    c669_load
 };
 
-static int ssn_test(HIO_HANDLE *f, char *t, const int start)
+static int c669_test(HIO_HANDLE *f, char *t, const int start)
 {
     uint16 id;
 
@@ -51,13 +51,13 @@ static int ssn_test(HIO_HANDLE *f, char *t, const int start)
 	return -1;
 
     hio_seek(f, start + 2, SEEK_SET);
-    read_title(f, t, 36);
+    libxmp_read_title(f, t, 36);
 
     return 0;
 }
 
 
-struct ssn_file_header {
+struct c669_file_header {
     uint8 marker[2];		/* 'if'=standard, 'JN'=extended */
     uint8 message[108];		/* Song message */
     uint8 nos;			/* Number of samples (0-64) */
@@ -68,7 +68,7 @@ struct ssn_file_header {
     uint8 pbrk[128];		/* Break list for patterns */
 };
 
-struct ssn_instrument_header {
+struct c669_instrument_header {
     uint8 name[13];		/* ASCIIZ instrument name */
     uint32 length;		/* Instrument length */
     uint32 loop_start;		/* Instrument loop start */
@@ -81,22 +81,22 @@ struct ssn_instrument_header {
 /* Effects bug fixed by Miod Vallat <miodrag@multimania.com> */
 
 static const uint8 fx[] = {
-    FX_PER_PORTA_UP,
-    FX_PER_PORTA_DN,
-    FX_PER_TPORTA,
-    FX_FINETUNE,
-    FX_PER_VIBRATO,
+    FX_669_PORTA_UP,
+    FX_669_PORTA_DN,
+    FX_669_TPORTA,
+    FX_669_FINETUNE,
+    FX_669_VIBRATO,
     FX_SPEED_CP
 };
 
 
-static int ssn_load(struct module_data *m, HIO_HANDLE *f, const int start)
+static int c669_load(struct module_data *m, HIO_HANDLE *f, const int start)
 {
     struct xmp_module *mod = &m->mod;
     int i, j;
     struct xmp_event *event;
-    struct ssn_file_header sfh;
-    struct ssn_instrument_header sih;
+    struct c669_file_header sfh;
+    struct c669_instrument_header sih;
     uint8 ev[3];
 
     LOAD_INIT();
@@ -129,13 +129,14 @@ static int ssn_load(struct module_data *m, HIO_HANDLE *f, const int start)
     mod->len = i;
     memcpy (mod->xxo, sfh.order, mod->len);
     mod->spd = 6;
-    mod->bpm = 76;		/* adjusted using Flux/sober.669 */
+    mod->bpm = 78;
     mod->smp = mod->ins;
 
-    m->quirk |= QUIRK_LINEAR;
+    m->period_type = PERIOD_CSPD;
+    m->c4rate = C4_NTSC_RATE;
 
-    copy_adjust(mod->name, sfh.message, 36);
-    set_type(m, strncmp((char *)sfh.marker, "if", 2) ?
+    libxmp_copy_adjust(mod->name, sfh.message, 36);
+    libxmp_set_type(m, strncmp((char *)sfh.marker, "if", 2) ?
 				"UNIS 669" : "Composer 669");
 
     MODULE_INFO();
@@ -146,7 +147,7 @@ static int ssn_load(struct module_data *m, HIO_HANDLE *f, const int start)
     
     /* Read and convert instruments and samples */
 
-    if (instrument_init(mod) < 0)
+    if (libxmp_init_instrument(m) < 0)
 	return -1;
 
     D_(D_INFO "Instruments: %d", mod->pat);
@@ -156,7 +157,7 @@ static int ssn_load(struct module_data *m, HIO_HANDLE *f, const int start)
 	struct xmp_sample *xxs = &mod->xxs[i];
 	struct xmp_subinstrument *sub;
 
-	if (subinstrument_alloc(mod, i, 1) < 0)
+	if (libxmp_alloc_subinstrument(mod, i, 1) < 0)
 	    return -1;
 
 	sub = &xxi->sub[0];
@@ -182,14 +183,14 @@ static int ssn_load(struct module_data *m, HIO_HANDLE *f, const int start)
 	if (xxs->len > 0)
 		xxi->nsm = 1;
 
-	instrument_name(mod, i, sih.name, 13);
+	libxmp_instrument_name(mod, i, sih.name, 13);
 
 	D_(D_INFO "[%2X] %-14.14s %04x %04x %04x %c", i,
 		xxi->name, xxs->len, xxs->lps, xxs->lpe,
 		xxs->flg & XMP_SAMPLE_LOOP ? 'L' : ' ');
     }
 
-    if (pattern_init(mod) < 0)
+    if (libxmp_init_pattern(mod) < 0)
 	return -1;
 
     /* Read and convert patterns */
@@ -197,7 +198,7 @@ static int ssn_load(struct module_data *m, HIO_HANDLE *f, const int start)
     for (i = 0; i < mod->pat; i++) {
 	int pbrk;
 
-	if (pattern_tracks_alloc(mod, i, 64) < 0)
+	if (libxmp_alloc_pattern_tracks(mod, i, 64) < 0)
 	    return -1;
 
 	event = &EVENT(i, 0, 0);
@@ -228,31 +229,11 @@ static int ssn_load(struct module_data *m, HIO_HANDLE *f, const int start)
 		if (MSN(ev[2]) > 5)
 		    continue;
 
-		/* If no instrument is playing on the channel where the
-		 * command was encountered, there will be no effect (except
-		 * for command 'f', it always changes the speed). 
-		 */
-		if (MSN(ev[2]) < 5 && !event->ins)
-		    continue;
-
 		event->fxt = fx[MSN(ev[2])];
+		event->fxp = LSN(ev[2]);
 
-		switch (event->fxt) {
-		case FX_PER_PORTA_UP:
-		case FX_PER_PORTA_DN:
-		case FX_PER_TPORTA:
-		    event->fxp = LSN(ev[2]);
-		    break;
-		case FX_PER_VIBRATO:
-		    event->fxp = 0x40 | LSN(ev[2]);
-		    break;
-		case FX_FINETUNE:
-		    event->fxp = 0x80 + (LSN(ev[2]) << 4);
-		    break;
-		case FX_SPEED_CP:
-		    event->fxp = LSN(ev[2]);
+		if (event->fxt == FX_SPEED_CP) {
 		    event->f2t = FX_PER_CANCEL;
-		    break;
 		}
 	    }
 	}
@@ -264,7 +245,7 @@ static int ssn_load(struct module_data *m, HIO_HANDLE *f, const int start)
     for (i = 0; i < mod->ins; i++) {
 	if (mod->xxs[i].len <= 2)
 	    continue;
-	if (load_sample(m, f, SAMPLE_FLAG_UNS, &mod->xxs[i], NULL) < 0)
+	if (libxmp_load_sample(m, f, SAMPLE_FLAG_UNS, &mod->xxs[i], NULL) < 0)
 	    return -1;
     }
 
@@ -272,7 +253,7 @@ static int ssn_load(struct module_data *m, HIO_HANDLE *f, const int start)
 	mod->xxc[i].pan = DEFPAN((i % 2) * 0xff);
     }
 
-    m->quirk |= QUIRK_PERPAT;	    /* Cancel persistent fx at each new pat */
+    m->quirk |= QUIRK_PBALL|QUIRK_PERPAT;
 
     return 0;
 }
