@@ -1,5 +1,5 @@
 /* Extended Module Player
- * Copyright (C) 1996-2015 Claudio Matsuoka and Hipolito Carraro Jr
+ * Copyright (C) 1996-2016 Claudio Matsuoka and Hipolito Carraro Jr
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -37,7 +37,7 @@ static int arch_test (HIO_HANDLE *, char *, const int);
 static int arch_load (struct module_data *, HIO_HANDLE *, const int);
 
 
-const struct format_loader arch_loader = {
+const struct format_loader libxmp_loader_arch = {
 	"Archimedes Tracker",
 	arch_test,
 	arch_load
@@ -86,14 +86,14 @@ static int arch_test(HIO_HANDLE *f, char *t, const int start)
 		}
 
 		if (id == MAGIC_MNAM) {
-			read_title(f, t, 32);
+			libxmp_read_title(f, t, 32);
 			return 0;
 		}
 
 		hio_seek(f, len, SEEK_CUR);
 	}
 
-	read_title(f, t, 0);
+	libxmp_read_title(f, t, 0);
 
 	return 0;
 }
@@ -283,7 +283,7 @@ static int get_sequ(struct module_data *m, int size, HIO_HANDLE *f, void *parm)
 	struct xmp_module *mod = &m->mod;
 
 	hio_read(mod->xxo, 1, 128, f);
-	set_type(m, "Archimedes Tracker");
+	libxmp_set_type(m, "Archimedes Tracker");
 	MODULE_INFO();
 
 	return 0;
@@ -302,7 +302,7 @@ static int get_patt(struct module_data *m, int size, HIO_HANDLE *f, void *parm)
 		data->max_pat = 0;
 		mod->trk = mod->pat * mod->chn;
 
-		if (pattern_init(mod) < 0)
+		if (libxmp_init_pattern(mod) < 0)
 			return -1;
 	}
 
@@ -312,7 +312,7 @@ static int get_patt(struct module_data *m, int size, HIO_HANDLE *f, void *parm)
 
         i = data->max_pat;
 
-	if (pattern_tracks_alloc(mod, i, data->rows[i]) < 0)
+	if (libxmp_alloc_pattern_tracks(mod, i, data->rows[i]) < 0)
 		return -1;
 
 	for (j = 0; j < data->rows[i]; j++) {
@@ -344,7 +344,7 @@ static int get_samp(struct module_data *m, int size, HIO_HANDLE *f, void *parm)
 
 	if (!data->sflag) {
 		mod->smp = mod->ins = 36;
-		if (instrument_init(mod) < 0)
+		if (libxmp_init_instrument(m) < 0)
 			return -1;
 
 		D_(D_INFO "Instruments: %d", mod->ins);
@@ -363,7 +363,7 @@ static int get_samp(struct module_data *m, int size, HIO_HANDLE *f, void *parm)
 	i = data->max_ins;
 
 	mod->xxi[i].nsm = 1;
-	if (subinstrument_alloc(mod, i, 1) < 0)
+	if (libxmp_alloc_subinstrument(mod, i, 1) < 0)
 		return -1;
 
 	if (hio_read32b(f) != MAGIC_SNAM)	/* SNAM */
@@ -409,7 +409,7 @@ static int get_samp(struct module_data *m, int size, HIO_HANDLE *f, void *parm)
 	mod->xxi[i].sub[0].sid = i;
 	mod->xxi[i].sub[0].pan = 0x80;
 
-	m->vol_table = (int *)arch_vol_table;
+	m->vol_table = (int *)libxmp_arch_vol_table;
 	m->volbase = 0xff;
 
 	if (mod->xxs[i].lpe > 2) {
@@ -422,7 +422,7 @@ static int get_samp(struct module_data *m, int size, HIO_HANDLE *f, void *parm)
 		mod->xxs[i].lpe = mod->xxs[i].len;
 	}
 
-	if (load_sample(m, f, SAMPLE_FLAG_VIDC, &mod->xxs[i], NULL) < 0)
+	if (libxmp_load_sample(m, f, SAMPLE_FLAG_VIDC, &mod->xxs[i], NULL) < 0)
 		return -1;
 
 	D_(D_INFO "[%2X] %-20.20s %05x %05x %05x %c V%02x",
@@ -453,32 +453,32 @@ static int arch_load(struct module_data *m, HIO_HANDLE *f, const int start)
 	data.pflag = data.sflag = 0;
 	data.year = data.month = data.day = 0;
 
-	handle = iff_new();
+	handle = libxmp_iff_new();
 	if (handle == NULL)
 		return -1;
 
 	/* IFF chunk IDs */
-	iff_register(handle, "TINF", get_tinf);
-	iff_register(handle, "MVOX", get_mvox);
-	iff_register(handle, "STER", get_ster);
-	iff_register(handle, "MNAM", get_mnam);
-	iff_register(handle, "ANAM", get_anam);
-	iff_register(handle, "MLEN", get_mlen);
-	iff_register(handle, "PNUM", get_pnum);
-	iff_register(handle, "PLEN", get_plen);
-	iff_register(handle, "SEQU", get_sequ);
-	iff_register(handle, "PATT", get_patt);
-	iff_register(handle, "SAMP", get_samp);
+	libxmp_iff_register(handle, "TINF", get_tinf);
+	libxmp_iff_register(handle, "MVOX", get_mvox);
+	libxmp_iff_register(handle, "STER", get_ster);
+	libxmp_iff_register(handle, "MNAM", get_mnam);
+	libxmp_iff_register(handle, "ANAM", get_anam);
+	libxmp_iff_register(handle, "MLEN", get_mlen);
+	libxmp_iff_register(handle, "PNUM", get_pnum);
+	libxmp_iff_register(handle, "PLEN", get_plen);
+	libxmp_iff_register(handle, "SEQU", get_sequ);
+	libxmp_iff_register(handle, "PATT", get_patt);
+	libxmp_iff_register(handle, "SAMP", get_samp);
 
-	iff_set_quirk(handle, IFF_LITTLE_ENDIAN);
+	libxmp_iff_set_quirk(handle, IFF_LITTLE_ENDIAN);
 
 	/* Load IFF chunks */
-	if (iff_load(handle, m, f, &data) < 0) {
-		iff_release(handle);
+	if (libxmp_iff_load(handle, m, f, &data) < 0) {
+		libxmp_iff_release(handle);
 		return -1;
 	}
 
-	iff_release(handle);
+	libxmp_iff_release(handle);
 
 	for (i = 0; i < mod->chn; i++) {
 		mod->xxc[i].pan = DEFPAN((((i + 3) / 2) % 2) * 0xff);
