@@ -34,7 +34,7 @@
 static int dbm_test(HIO_HANDLE *, char *, const int);
 static int dbm_load (struct module_data *, HIO_HANDLE *, const int);
 
-const struct format_loader dbm_loader = {
+const struct format_loader libxmp_loader_dbm = {
 	"DigiBooster Pro",
 	dbm_test,
 	dbm_load
@@ -46,7 +46,7 @@ static int dbm_test(HIO_HANDLE * f, char *t, const int start)
 		return -1;
 
 	hio_seek(f, 12, SEEK_CUR);
-	read_title(f, t, 44);
+	libxmp_read_title(f, t, 44);
 
 	return 0;
 }
@@ -99,7 +99,7 @@ static int get_info(struct module_data *m, int size, HIO_HANDLE *f, void *parm)
 
 	mod->trk = mod->pat * mod->chn;
 
-	if (instrument_init(mod) < 0)
+	if (libxmp_init_instrument(m) < 0)
 		return -1;
 
 	return 0;
@@ -154,11 +154,11 @@ static int get_inst(struct module_data *m, int size, HIO_HANDLE *f, void *parm)
 
 	for (i = 0; i < mod->ins; i++) {
 		mod->xxi[i].nsm = 1;
-		if (subinstrument_alloc(mod, i, 1) < 0)
+		if (libxmp_alloc_subinstrument(mod, i, 1) < 0)
 			return -1;
 
 		hio_read(buffer, 30, 1, f);
-		instrument_name(mod, i, buffer, 30);
+		libxmp_instrument_name(mod, i, buffer, 30);
 		snum = hio_read16b(f);
 		if (snum == 0 || snum > mod->smp)
 			continue;
@@ -175,7 +175,7 @@ static int get_inst(struct module_data *m, int size, HIO_HANDLE *f, void *parm)
 		mod->xxs[snum].flg = flags & 0x03 ? XMP_SAMPLE_LOOP : 0;
 		mod->xxs[snum].flg |= flags & 0x02 ? XMP_SAMPLE_LOOP_BIDIR : 0;
 
-		c2spd_to_note(c2spd, &mod->xxi[i].sub[0].xpo, &mod->xxi[i].sub[0].fin);
+		libxmp_c2spd_to_note(c2spd, &mod->xxi[i].sub[0].xpo, &mod->xxi[i].sub[0].fin);
 
 		D_(D_INFO "[%2X] %-30.30s #%02X V%02x P%02x %5d",
 			i, mod->xxi[i].name, snum,
@@ -192,7 +192,7 @@ static int get_patt(struct module_data *m, int size, HIO_HANDLE *f, void *parm)
 	struct xmp_event *event, dummy;
 	uint8 x;
 
-	if (pattern_init(mod) < 0)
+	if (libxmp_init_pattern(mod) < 0)
 		return -1;
 
 	D_(D_INFO "Stored patterns: %d ", mod->pat);
@@ -203,7 +203,7 @@ static int get_patt(struct module_data *m, int size, HIO_HANDLE *f, void *parm)
 	 */
 
 	for (i = 0; i < mod->pat; i++) {
-		if (pattern_tracks_alloc(mod, i, hio_read16b(f)) < 0)
+		if (libxmp_alloc_pattern_tracks(mod, i, hio_read16b(f)) < 0)
 			return -1;
 
 		sz = hio_read32b(f);
@@ -300,7 +300,7 @@ static int get_smpl(struct module_data *m, int size, HIO_HANDLE *f, void *parm)
 			continue;
 		}
 		
-		if (load_sample(m, f, SAMPLE_FLAG_BIGEND, &mod->xxs[i], NULL) < 0)
+		if (libxmp_load_sample(m, f, SAMPLE_FLAG_BIGEND, &mod->xxs[i], NULL) < 0)
 			return -1;
 
 		if (mod->xxs[i].len == 0)
@@ -365,17 +365,19 @@ static int dbm_load(struct module_data *m, HIO_HANDLE *f, const int start)
 	hio_seek(f, 10, SEEK_CUR);
 	hio_read(name, 1, 44, f);
 
-	handle = iff_new();
+	handle = libxmp_iff_new();
 	if (handle == NULL)
 		return -1;
 
+	m->c4rate = C4_NTSC_RATE;
+
 	/* IFF chunk IDs */
-	ret = iff_register(handle, "INFO", get_info);
-	ret |= iff_register(handle, "SONG", get_song);
-	ret |= iff_register(handle, "INST", get_inst);
-	ret |= iff_register(handle, "PATT", get_patt);
-	ret |= iff_register(handle, "SMPL", get_smpl);
-	ret |= iff_register(handle, "VENV", get_venv);
+	ret = libxmp_iff_register(handle, "INFO", get_info);
+	ret |= libxmp_iff_register(handle, "SONG", get_song);
+	ret |= libxmp_iff_register(handle, "INST", get_inst);
+	ret |= libxmp_iff_register(handle, "PATT", get_patt);
+	ret |= libxmp_iff_register(handle, "SMPL", get_smpl);
+	ret |= libxmp_iff_register(handle, "VENV", get_venv);
 
 	if (ret != 0)
 		return -1;
@@ -383,15 +385,16 @@ static int dbm_load(struct module_data *m, HIO_HANDLE *f, const int start)
 	strncpy(mod->name, name, XMP_NAME_SIZE);
 	snprintf(mod->type, XMP_NAME_SIZE, "DigiBooster Pro %d.%02x DBM0",
 					version >> 8, version & 0xff);
+
 	MODULE_INFO();
 
 	/* Load IFF chunks */
-	if (iff_load(handle, m, f, &data) < 0) {
-		iff_release(handle);
+	if (libxmp_iff_load(handle, m, f, &data) < 0) {
+		libxmp_iff_release(handle);
 		return -1;
 	}
 
-	iff_release(handle);
+	libxmp_iff_release(handle);
 
 	for (i = 0; i < mod->chn; i++)
 		mod->xxc[i].pan = 0x80;
