@@ -35,7 +35,7 @@
 static int it_test(HIO_HANDLE *, char *, const int);
 static int it_load(struct module_data *, HIO_HANDLE *, const int);
 
-const struct format_loader it_loader = {
+const struct format_loader libxmp_loader_it = {
 	"Impulse Tracker",
 	it_test,
 	it_load
@@ -55,7 +55,7 @@ static int it_test(HIO_HANDLE * f, char *t, const int start)
 	if (hio_read32b(f) != MAGIC_IMPM)
 		return -1;
 
-	read_title(f, t, 26);
+	libxmp_read_title(f, t, 26);
 
 	return 0;
 }
@@ -196,13 +196,6 @@ static void xlat_fx(int c, struct xmp_event *e, uint8 *last_fxp, int new_fx)
 		e->fxt = e->fxp = 0;
 		break;
 	}
-
-	/* Impulse Tracker ignores the portamento command if there is an
-	 * portamento command next to an offset command
-	 */
-	if (e->fxt == FX_OFFSET && e->f2t == FX_TONEPORTA) {
-		e->f2t = e->f2p = 0;
-	}
 }
 
 
@@ -235,13 +228,18 @@ static void xlat_volfx(struct xmp_event *event)
 		event->f2p = (b - 115) << 2;
 	} else if (b >= 128 && b <= 192) {	/* pan */
 		if (b == 192) {
-			b = 191;
+			event->f2p = 0xff;
+		} else {
+			event->f2p = (b - 128) << 2;
 		}
 		event->f2t = FX_SETPAN;
-		event->f2p = (b - 128) << 2;
 	} else if (b >= 193 && b <= 202) {	/* G */
+		uint8 val[10] = {
+			0x00, 0x01, 0x04, 0x08, 0x10,
+			0x20, 0x40, 0x60, 0x80, 0xff
+		};
 		event->f2t = FX_TONEPORTA;
-		event->f2p = (b - 193) << 2;
+		event->f2p = val[b - 193];
 	} else if (b >= 203 && b <= 212) {	/* H */
 		event->f2t = FX_VIBRATO;
 		event->f2p = b - 203;
@@ -312,7 +310,7 @@ static void read_envelope(struct xmp_envelope *ei, struct it_envelope *env,
 	ei->lps = env->lpb;
 	ei->lpe = env->lpe;
 
-	if (ei->npt > 0 && ei->npt < 25 /* XMP_MAX_ENV_POINTS */ ) {
+	if (ei->npt > 0 && ei->npt <= 25 /* XMP_MAX_ENV_POINTS */ ) {
 		for (j = 0; j < ei->npt; j++) {
 			ei->data[j * 2] = env->node[j].x;
 			ei->data[j * 2 + 1] = env->node[j].y;
@@ -325,86 +323,88 @@ static void read_envelope(struct xmp_envelope *ei, struct it_envelope *env,
 static void identify_tracker(struct module_data *m, struct it_file_header *ifh)
 {
 #ifndef LIBXMP_CORE_PLAYER
-    char tracker_name[40];
-    int sample_mode = ~ifh->flags & IT_USE_INST;
+	char tracker_name[40];
+	int sample_mode = ~ifh->flags & IT_USE_INST;
 
-    switch (ifh->cwt >> 8) {
-    case 0x00:
-	strcpy(tracker_name, "unmo3");
-	break;
-    case 0x01:
-    case 0x02:		/* test from Schism Tracker sources */
-	if (ifh->cmwt == 0x0200 && ifh->cwt == 0x0214
-		&& ifh->flags == 9 && ifh->special == 0
-		&& ifh->hilite_maj == 0 && ifh->hilite_min == 0
-		&& ifh->insnum == 0 && ifh->patnum + 1 == ifh->ordnum
-		&& ifh->gv == 128 && ifh->mv == 100 && ifh->is == 1
-		&& ifh->sep == 128 && ifh->pwd == 0
-		&& ifh->msglen == 0 && ifh->msgofs == 0 && ifh->rsvd == 0)
-	{
-                strcpy(tracker_name, "OpenSPC conversion");
-	} else if (ifh->cmwt == 0x0200 && ifh->cwt == 0x0217) {
-	    strcpy(tracker_name, "ModPlug Tracker 1.16");
-	    /* ModPlug Tracker files aren't really IMPM 2.00 */
-	    ifh->cmwt = sample_mode ? 0x100 : 0x214;	
-	} else if (ifh->cwt == 0x0216) {
-	    strcpy(tracker_name, "Impulse Tracker 2.14v3");
-	} else if (ifh->cwt == 0x0217) {
-	    strcpy(tracker_name, "Impulse Tracker 2.14v5");
-	} else if (ifh->cwt == 0x0214 && !memcmp(&ifh->rsvd, "CHBI", 4)) {
-	    strcpy(tracker_name, "Chibi Tracker");
-	} else {
-	    snprintf(tracker_name, 40, "Impulse Tracker %d.%02x",
-			(ifh->cwt & 0x0f00) >> 8, ifh->cwt & 0xff);
-	}
-	break;
-    case 0x08:
-    case 0x7f:
-	if (ifh->cwt == 0x0888) {
-	    strcpy(tracker_name, "OpenMPT 1.17");
-	} else if (ifh->cwt == 0x7fff) {
-	    strcpy(tracker_name, "munch.py");
-	} else {
-	    snprintf(tracker_name, 40, "unknown (%04x)", ifh->cwt);
-	}
-	break;
-    default:
-	switch (ifh->cwt >> 12) {
-	case 0x1: {
-	    uint16 cwtv = ifh->cwt & 0x0fff;
-	    struct tm version;
-	    time_t version_sec;
-
-	    if (cwtv > 0x50) {
-		version_sec = ((cwtv - 0x050) * 86400) + 1254355200;
-		if (localtime_r(&version_sec, &version)) {
-		    snprintf(tracker_name, 40, "Schism Tracker %04d-%02d-%02d",
-				version.tm_year + 1900, version.tm_mon + 1,
-				version.tm_mday);
-                }
-	    } else {
-	    	snprintf(tracker_name, 40, "Schism Tracker 0.%x", cwtv);
-	    }
-	    break; }
-	case 0x5:
-	    snprintf(tracker_name, 40, "OpenMPT %d.%02x",
-			(ifh->cwt & 0x0f00) >> 8, ifh->cwt & 0xff);
-	    if (memcmp(&ifh->rsvd, "OMPT", 4))
-			strncat(tracker_name, " (compat.)", 39);
-	    break;
-	case 0x06:
-	    snprintf(tracker_name, 40, "BeRoTracker %d.%02x",
-			(ifh->cwt & 0x0f00) >> 8, ifh->cwt & 0xff);
-	    break;
+	switch (ifh->cwt >> 8) {
+	case 0x00:
+		strcpy(tracker_name, "unmo3");
+		break;
+	case 0x01:
+	case 0x02:		/* test from Schism Tracker sources */
+		if (ifh->cmwt == 0x0200 && ifh->cwt == 0x0214
+		    && ifh->flags == 9 && ifh->special == 0
+		    && ifh->hilite_maj == 0 && ifh->hilite_min == 0
+		    && ifh->insnum == 0 && ifh->patnum + 1 == ifh->ordnum
+		    && ifh->gv == 128 && ifh->mv == 100 && ifh->is == 1
+		    && ifh->sep == 128 && ifh->pwd == 0
+		    && ifh->msglen == 0 && ifh->msgofs == 0 && ifh->rsvd == 0) {
+			strcpy(tracker_name, "OpenSPC conversion");
+		} else if (ifh->cmwt == 0x0200 && ifh->cwt == 0x0217) {
+			strcpy(tracker_name, "ModPlug Tracker 1.16");
+			/* ModPlug Tracker files aren't really IMPM 2.00 */
+			ifh->cmwt = sample_mode ? 0x100 : 0x214;
+		} else if (ifh->cwt == 0x0216) {
+			strcpy(tracker_name, "Impulse Tracker 2.14v3");
+		} else if (ifh->cwt == 0x0217) {
+			strcpy(tracker_name, "Impulse Tracker 2.14v5");
+		} else if (ifh->cwt == 0x0214 && !memcmp(&ifh->rsvd, "CHBI", 4)) {
+			strcpy(tracker_name, "Chibi Tracker");
+		} else {
+			snprintf(tracker_name, 40, "Impulse Tracker %d.%02x",
+				 (ifh->cwt & 0x0f00) >> 8, ifh->cwt & 0xff);
+		}
+		break;
+	case 0x08:
+	case 0x7f:
+		if (ifh->cwt == 0x0888) {
+			strcpy(tracker_name, "OpenMPT 1.17");
+		} else if (ifh->cwt == 0x7fff) {
+			strcpy(tracker_name, "munch.py");
+		} else {
+			snprintf(tracker_name, 40, "unknown (%04x)", ifh->cwt);
+		}
+		break;
 	default:
-	    snprintf(tracker_name, 40, "unknown (%04x)", ifh->cwt);
-	}
-    }
+		switch (ifh->cwt >> 12) {
+		case 0x1:{
+			uint16 cwtv = ifh->cwt & 0x0fff;
+			struct tm version;
+			time_t version_sec;
 
-    set_type(m, "%s IT %d.%02x", tracker_name,
-			ifh->cmwt >> 8, ifh->cmwt & 0xff);
+			if (cwtv > 0x50) {
+				version_sec = ((cwtv - 0x050) * 86400) + 1254355200;
+				if (localtime_r(&version_sec, &version)) {
+					snprintf(tracker_name, 40,
+						 "Schism Tracker %04d-%02d-%02d",
+						 version.tm_year + 1900,
+						 version.tm_mon + 1,
+						 version.tm_mday);
+				}
+			} else {
+				snprintf(tracker_name, 40,
+					 "Schism Tracker 0.%x", cwtv);
+			}
+			break; }
+		case 0x5:
+			snprintf(tracker_name, 40, "OpenMPT %d.%02x",
+				 (ifh->cwt & 0x0f00) >> 8, ifh->cwt & 0xff);
+			if (memcmp(&ifh->rsvd, "OMPT", 4))
+				strncat(tracker_name, " (compat.)", 39);
+			break;
+		case 0x06:
+			snprintf(tracker_name, 40, "BeRoTracker %d.%02x",
+				 (ifh->cwt & 0x0f00) >> 8, ifh->cwt & 0xff);
+			break;
+		default:
+			snprintf(tracker_name, 40, "unknown (%04x)", ifh->cwt);
+		}
+	}
+
+	libxmp_set_type(m, "%s IT %d.%02x", tracker_name, ifh->cmwt >> 8,
+						ifh->cmwt & 0xff);
 #else
-    set_type(m, "Impulse Tracker");
+	libxmp_set_type(m, "Impulse Tracker");
 #endif
 }
 
@@ -451,7 +451,7 @@ static int load_old_it_instrument(struct xmp_instrument *xxi, HIO_HANDLE *f)
 	if (hio_read(&i1h.enode, 1, 50, f) != 50)
 		return -1;
 
-	copy_adjust(xxi->name, i1h.name, 25);
+	libxmp_copy_adjust(xxi->name, i1h.name, 25);
 
 	xxi->rls = i1h.fadeout << 7;
 
@@ -526,8 +526,8 @@ static int load_old_it_instrument(struct xmp_instrument *xxi, HIO_HANDLE *f)
 		}
 	}
 
-	D_(D_INFO "[%2X] %-26.26s %d %-4.4s %4d %2d %c%c%c %3d",
-	   i, i1h.name,
+	D_(D_INFO "[  ] %-26.26s %d %-4.4s %4d %2d %c%c%c %3d",
+	   /*i,*/ i1h.name,
 	   i1h.nna,
 	   i1h.dnc ? "on" : "off",
 	   i1h.fadeout,
@@ -549,6 +549,7 @@ static int load_new_it_instrument(struct xmp_instrument *xxi, HIO_HANDLE *f)
 
 	i2h.magic = hio_read32b(f);
 	if (i2h.magic != MAGIC_IMPI) {
+		D_(D_CRIT "bad instrument magic");
 		return -1;
 	}
 	hio_read(&i2h.dosname, 12, 1, f);
@@ -558,8 +559,10 @@ static int load_new_it_instrument(struct xmp_instrument *xxi, HIO_HANDLE *f)
 	i2h.dca = hio_read8(f);
 
 	/* Sanity check */
-	if (i2h.dca > 2) {
-		return -1;
+	if (i2h.dca > 3) {
+		/* Northern Sky has an instrument with DCA 3 */
+		D_(D_WARN "bad instrument dca: %d", i2h.dca);
+		i2h.dca = 0;
 	}
 
 	i2h.fadeout = hio_read16l(f);
@@ -576,10 +579,12 @@ static int load_new_it_instrument(struct xmp_instrument *xxi, HIO_HANDLE *f)
 	i2h.rsvd1 = hio_read8(f);
 
 	if (hio_error(f)) {
+		D_(D_CRIT "read error");
 		return -1;
 	}
 
 	if (hio_read(&i2h.name, 1, 26, f) != 26) {
+		D_(D_CRIT "name read error");
 		return -1;
 	}
 
@@ -592,10 +597,11 @@ static int load_new_it_instrument(struct xmp_instrument *xxi, HIO_HANDLE *f)
 	i2h.mbnk = hio_read16l(f);
 
 	if (hio_read(&i2h.keys, 1, 240, f) != 240) {
+		D_(D_CRIT "key map read error");
 		return -1;
 	}
 
-	copy_adjust(xxi->name, i2h.name, 25);
+	libxmp_copy_adjust(xxi->name, i2h.name, 25);
 	xxi->rls = i2h.fadeout << 6;
 
 	/* Envelopes */
@@ -662,7 +668,7 @@ static int load_new_it_instrument(struct xmp_instrument *xxi, HIO_HANDLE *f)
 			sub->sid = inst_rmap[j];
 			sub->nna = i2h.nna;
 			sub->dct = i2h.dct;
-			sub->dca = dca2nna[i2h.dca & 0x03];
+			sub->dca = dca2nna[i2h.dca];
 			sub->pan = i2h.dfp & 0x80 ? -1 : i2h.dfp * 4;
 			sub->ifc = i2h.ifc;
 			sub->ifr = i2h.ifr;
@@ -670,9 +676,9 @@ static int load_new_it_instrument(struct xmp_instrument *xxi, HIO_HANDLE *f)
 		}
 	}
 
-	D_(D_INFO "[%2X] %-26.26s %d %d %d %4d %4d  %2x "
+	D_(D_INFO "[  ] %-26.26s %d %d %d %4d %4d  %2x "
 	   "%02x %c%c%c %3d %02x %02x",
-	   i, i2h.name,
+	   /*i,*/ i2h.name,
 	   i2h.nna, i2h.dct, i2h.dca,
 	   i2h.fadeout,
 	   i2h.gbv,
@@ -691,7 +697,7 @@ static int load_it_sample(struct module_data *m, int i, int start,
 {
 	struct it_sample_header ish;
 	struct xmp_module *mod = &m->mod;
-	struct xmp_sample *xxs;
+	struct xmp_sample *xxs, *xsmp;
 	int j, k;
 
 	if (sample_mode) {
@@ -707,6 +713,7 @@ static int load_it_sample(struct module_data *m, int i, int start,
 	}
 
 	xxs = &mod->xxs[i];
+	xsmp = &m->xsmp[i];
 
 	hio_read(&ish.dosname, 12, 1, f);
 	ish.zero = hio_read8(f);
@@ -757,9 +764,21 @@ static int load_it_sample(struct module_data *m, int i, int start,
 
 	xxs->lps = ish.loopbeg;
 	xxs->lpe = ish.loopend;
-
 	xxs->flg |= ish.flags & IT_SMP_LOOP ? XMP_SAMPLE_LOOP : 0;
 	xxs->flg |= ish.flags & IT_SMP_BLOOP ? XMP_SAMPLE_LOOP_BIDIR : 0;
+	xxs->flg |= ish.flags & IT_SMP_SLOOP ? XMP_SAMPLE_SLOOP : 0;
+	xxs->flg |= ish.flags & IT_SMP_BSLOOP ? XMP_SAMPLE_SLOOP_BIDIR : 0;
+
+	if (ish.flags & IT_SMP_SLOOP) {
+		memcpy(xsmp, xxs, sizeof (struct xmp_sample));
+		xsmp->lps = ish.sloopbeg;
+		xsmp->lpe = ish.sloopend;
+		xsmp->flg |= XMP_SAMPLE_LOOP;
+		xsmp->flg &= ~XMP_SAMPLE_LOOP_BIDIR;
+		if (ish.flags & IT_SMP_BSLOOP) {
+			xsmp->flg |= XMP_SAMPLE_LOOP_BIDIR;
+		}
+	}
 
 	if (sample_mode) {
 		/* Create an instrument for each sample */
@@ -767,9 +786,9 @@ static int load_it_sample(struct module_data *m, int i, int start,
 		mod->xxi[i].sub[0].pan = 0x80;
 		mod->xxi[i].sub[0].sid = i;
 		mod->xxi[i].nsm = !!(xxs->len);
-		instrument_name(mod, i, ish.name, 25);
+		libxmp_instrument_name(mod, i, ish.name, 25);
 	} else {
-		copy_adjust(xxs->name, ish.name, 25);
+		libxmp_copy_adjust(xxs->name, ish.name, 25);
 	}
 
 	D_(D_INFO "\n[%2X] %-26.26s %05x%c%05x %05x %05x %05x "
@@ -799,7 +818,7 @@ static int load_it_sample(struct module_data *m, int i, int start,
 				sub->vwf = ish.vit;
 				sub->vsw = (0xff - ish.vir) >> 1;
 
-				c2spd_to_note(ish.c5spd,
+				libxmp_c2spd_to_note(ish.c5spd,
 					      &mod->xxi[j].sub[k].xpo,
 					      &mod->xxi[j].sub[k].fin);
 
@@ -849,15 +868,41 @@ static int load_it_sample(struct module_data *m, int i, int start,
 						  ish.convert & IT_CVT_DIFF);
 			}
 
-			ret = load_sample(m, NULL, SAMPLE_FLAG_NOLOAD | cvt,
+			if (ish.flags & IT_SMP_SLOOP) {
+				long pos = hio_tell(f);
+				if (pos < 0) {
+					free(buf);
+					return -1;
+				}
+				ret = libxmp_load_sample(m, NULL, SAMPLE_FLAG_NOLOAD |
+							cvt, &m->xsmp[i], buf);
+				if (ret < 0) {
+					free(buf);
+					return -1;
+				}
+				hio_seek(f, pos, SEEK_SET);
+			}
+
+			ret = libxmp_load_sample(m, NULL, SAMPLE_FLAG_NOLOAD | cvt,
 					  &mod->xxs[i], buf);
 			if (ret < 0) {
 				free(buf);
 				return -1;
 			}
+
 			free(buf);
 		} else {
-			if (load_sample(m, f, cvt, &mod->xxs[i], NULL) < 0)
+			if (ish.flags & IT_SMP_SLOOP) {
+				long pos = hio_tell(f);
+				if (pos < 0) {
+					return -1;
+				}
+				if (libxmp_load_sample(m, f, cvt, &m->xsmp[i], NULL) < 0)
+					return -1;
+				hio_seek(f, pos, SEEK_SET);
+			}
+
+			if (libxmp_load_sample(m, f, cvt, &mod->xxs[i], NULL) < 0)
 				return -1;
 		}
 	}
@@ -885,7 +930,7 @@ static int load_it_pattern(struct module_data *m, int i, int new_fx,
 	pat_len = hio_read16l(f) /* - 4 */ ;
 	mod->xxp[i]->rows = hio_read16l(f);
 
-	if (tracks_in_pattern_alloc(mod, i) < 0)
+	if (libxmp_alloc_tracks_in_pattern(mod, i) < 0)
 		return -1;
 
 	memset(mask, 0, L_CHANNELS);
@@ -1069,7 +1114,7 @@ static int it_load(struct module_data *m, HIO_HANDLE *f, const int start)
 	sample_mode = ~ifh.flags & IT_USE_INST;
 
 	if (ifh.flags & IT_LINEAR_FREQ) {
-		m->quirk |= QUIRK_LINEAR;
+		m->period_type = PERIOD_LINEAR;
 	}
 
 	if (!sample_mode && ifh.cmwt >= 0x200) {
@@ -1128,9 +1173,17 @@ static int it_load(struct module_data *m, HIO_HANDLE *f, const int start)
 	if (sample_mode)
 		mod->ins = mod->smp;
 
-	if (instrument_init(mod) < 0)
+	if (libxmp_init_instrument(m) < 0)
 		goto err4;
 
+	/* Alloc extra samples for sustain loop */
+	if (mod->smp > 0) {
+		m->xsmp = calloc(sizeof (struct xmp_sample), mod->smp);
+		if (m->xsmp == NULL) {
+			goto err4;
+		}
+	}
+
 	D_(D_INFO "Instruments: %d", mod->ins);
 
 	for (i = 0; i < mod->ins; i++) {
@@ -1238,13 +1291,13 @@ static int it_load(struct module_data *m, HIO_HANDLE *f, const int start)
 	mod->chn = max_ch + 1;
 	mod->trk = mod->pat * mod->chn;
 
-	if (pattern_init(mod) < 0)
+	if (libxmp_init_pattern(mod) < 0)
 		goto err4;
 
 	/* Read patterns */
 	for (i = 0; i < mod->pat; i++) {
 
-		if (pattern_alloc(mod, i) < 0)
+		if (libxmp_alloc_pattern(mod, i) < 0)
 			goto err4;
 
 		/* If the offset to a pattern is 0, the pattern is empty */
@@ -1252,7 +1305,7 @@ static int it_load(struct module_data *m, HIO_HANDLE *f, const int start)
 			mod->xxp[i]->rows = 64;
 			for (j = 0; j < mod->chn; j++) {
 				int tnum = i * mod->chn + j;
-				if (track_alloc(mod, tnum, 64) < 0)
+				if (libxmp_alloc_track(mod, tnum, 64) < 0)
 					goto err4;
 				mod->xxp[i]->index[j] = tnum;
 			}
@@ -1296,7 +1349,7 @@ static int it_load(struct module_data *m, HIO_HANDLE *f, const int start)
 
 	/* Format quirks */
 
-	m->quirk |= QUIRKS_IT;
+	m->quirk |= QUIRKS_IT | QUIRK_ARPMEM;
 
 	if (ifh.flags & IT_LINK_GXX) {
 		m->quirk |= QUIRK_PRENV;
