@@ -1,5 +1,5 @@
 /* Extended Module Player
- * Copyright (C) 1996-2015 Claudio Matsuoka and Hipolito Carraro Jr
+ * Copyright (C) 1996-2016 Claudio Matsuoka and Hipolito Carraro Jr
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -34,7 +34,7 @@
 static int mdl_test (HIO_HANDLE *, char *, const int);
 static int mdl_load (struct module_data *, HIO_HANDLE *, const int);
 
-const struct format_loader mdl_loader = {
+const struct format_loader libxmp_loader_mdl = {
     "Digitrakker",
     mdl_test,
     mdl_load
@@ -52,9 +52,9 @@ static int mdl_test(HIO_HANDLE *f, char *t, const int start)
 
     if (id == 0x494e) {		/* IN */
 	hio_read32b(f);
-	read_title(f, t, 32);
+	libxmp_read_title(f, t, 32);
     } else {
-	read_title(f, t, 0);
+	libxmp_read_title(f, t, 0);
     }
 
     return 0;
@@ -82,7 +82,6 @@ struct local_data {
     int *v_index;	/* volume envelope */
     int *p_index;	/* pan envelope */
     int *f_index;	/* pitch envelope */
-    int *c2spd;
     int *packinfo;
     int v_envnum;
     int p_envnum;
@@ -100,7 +99,7 @@ static void fix_env(int i, struct xmp_envelope *ei, struct mdl_envelope *env,
 
     if (index[i] >= 0) {
 	ei->flg = XMP_ENVELOPE_ON;
-	ei->npt = 16;
+	ei->npt = 15;
 
 	for (j = 0; j < envnum; j++) {
     	    if (index[i] == env[j].num) {
@@ -281,6 +280,7 @@ static int unpack_sample8(uint8 *t, uint8 *f, int len, int l)
     get_bits(0, &f, &len, &bits);
 
     for (i = b = d = 0; i < l; i++) {
+
 	/* Sanity check */
         if (len < 0)
             return -1;
@@ -290,13 +290,17 @@ static int unpack_sample8(uint8 *t, uint8 *f, int len, int l)
 	    b = get_bits(3, &f, &len, &bits);
 	} else {
             b = 8;
-	    while (len >= 0 && get_bits(1, &f, &len, &bits) == 0)
+	    while (len >= 0 && get_bits(1, &f, &len, &bits) == 0) {
+		/* Sanity check */
+                if (b >= 240) { return -1; }
 		b += 16;
+            }
 	    b += get_bits(4, &f, &len, &bits);
 	}
 
-	if (s)
+	if (s) {
 	    b ^= 0xff;
+	}
 
 	d += b;
 	*t++ = d;
@@ -337,8 +341,11 @@ static int unpack_sample16(uint8 *t, uint8 *f, int len, int l)
 	    b = get_bits(3, &f, &len, &bits);
 	} else {
             b = 8;
-	    while (len >= 0 && get_bits(1, &f, &len, &bits) == 0)
+	    while (len >= 0 && get_bits(1, &f, &len, &bits) == 0) {
+		/* Sanity check */
+                if (b >= 240) { return -1; }
 		b += 16;
+            }
 	    b += get_bits(4, &f, &len, &bits);
 	}
 
@@ -411,7 +418,7 @@ static int get_chunk_pa(struct module_data *m, int size, HIO_HANDLE *f, void *pa
     D_(D_INFO "Stored patterns: %d", mod->pat);
 
     for (i = 0; i < mod->pat; i++) {
-	if (pattern_alloc(mod, i) < 0)
+	if (libxmp_alloc_pattern(mod, i) < 0)
 	    return -1;
 
 	chn = hio_read8(f);
@@ -447,7 +454,7 @@ static int get_chunk_p0(struct module_data *m, int size, HIO_HANDLE *f, void *pa
     D_(D_INFO "Stored patterns: %d", mod->pat);
 
     for (i = 0; i < mod->pat; i++) {
-	if (pattern_alloc(mod, i) < 0)
+	if (libxmp_alloc_pattern(mod, i) < 0)
 	    return -1;
 	mod->xxp[i]->rows = 64;
 
@@ -493,7 +500,7 @@ static int get_chunk_tr(struct module_data *m, int size, HIO_HANDLE *f, void *pa
 	goto err;
 
     /* Empty track 0 is not stored in the file */
-    if (track_alloc(mod, 0, 256) < 0)
+    if (libxmp_alloc_track(mod, 0, 256) < 0)
 	goto err2;
 
     for (i = 1; i < mod->trk; i++) {
@@ -504,13 +511,15 @@ static int get_chunk_tr(struct module_data *m, int size, HIO_HANDLE *f, void *pa
             			sizeof (struct xmp_event) * 255);
 
 	for (row = 0; len;) {
-	    struct xmp_event *ev = &track->event[row];
+	    struct xmp_event *ev;
 
 	    /* Sanity check */
 	    if (row > 255) {
 		goto err2;
 	    }
 
+            ev = &track->event[row];
+
 	    j = hio_read8(f);
 
 	    len--;
@@ -565,7 +574,7 @@ static int get_chunk_tr(struct module_data *m, int size, HIO_HANDLE *f, void *pa
 	    row = 128;
 	else row = 256;
 
-	if (track_alloc(mod, i, row) < 0)
+	if (libxmp_alloc_track(mod, i, row) < 0)
 	    goto err2;
 
 	memcpy(mod->xxt[i], track, sizeof (struct xmp_track) +
@@ -602,7 +611,7 @@ static int get_chunk_ii(struct module_data *m, int size, HIO_HANDLE *f, void *pa
     mod->ins = hio_read8(f);
     D_(D_INFO "Instruments: %d", mod->ins);
 
-    if (instrument_init(mod) < 0)
+    if (libxmp_init_instrument(m) < 0)
 	return -1;
 
     for (i = 0; i < mod->ins; i++) {
@@ -612,12 +621,11 @@ static int get_chunk_ii(struct module_data *m, int size, HIO_HANDLE *f, void *pa
 	xxi->nsm = hio_read8(f);
 	hio_read(buf, 1, 32, f);
 	buf[32] = 0;
-	adjust_string(buf);
-	strncpy((char *)xxi->name, buf, 32);
+	strncpy(xxi->name, buf, 31);
 
 	D_(D_INFO "[%2X] %-32.32s %2d", data->i_index[i], xxi->name, xxi->nsm);
 
-	if (subinstrument_alloc(mod, i, xxi->nsm) < 0)
+	if (libxmp_alloc_subinstrument(mod, i, xxi->nsm) < 0)
 	    return -1;
 
 	for (j = 0; j < XMP_MAX_KEYS; j++)
@@ -655,7 +663,7 @@ static int get_chunk_ii(struct module_data *m, int size, HIO_HANDLE *f, void *pa
 		xxi->rls = x;
 
 	    sub->vra = hio_read8(f);	/* vibrato rate */
-	    sub->vde = hio_read8(f) >> 1;	/* vibrato depth */
+	    sub->vde = hio_read8(f) << 1;	/* vibrato depth */
 	    sub->vsw = hio_read8(f);	/* vibrato sweep */
 	    sub->vwf = hio_read8(f);	/* vibrato waveform */
 	    hio_read8(f);		/* Reserved */
@@ -684,6 +692,8 @@ static int get_chunk_is(struct module_data *m, int size, HIO_HANDLE *f, void *pa
     mod->smp = hio_read8(f);
     if ((mod->xxs = calloc(sizeof (struct xmp_sample), mod->smp)) == NULL)
 	return -1;
+    if ((m->xtra = calloc(sizeof (struct extra_sample_data), mod->smp)) == NULL)
+        return -1;
 
     data->packinfo = calloc(sizeof (int), mod->smp);
     if (data->packinfo == NULL)
@@ -693,16 +703,16 @@ static int get_chunk_is(struct module_data *m, int size, HIO_HANDLE *f, void *pa
 
     for (i = 0; i < mod->smp; i++) {
 	struct xmp_sample *xxs = &mod->xxs[i];
+	int c5spd;
 
 	data->s_index[i] = hio_read8(f);	/* Sample number */
 	hio_read(buf, 1, 32, f);
 	buf[32] = 0;
-	adjust_string(buf);
-	strncpy(xxs->name, buf, 32);
+	strncpy(xxs->name, buf, 31);
 
 	hio_seek(f, 8, SEEK_CUR);		/* Sample filename */
 
-	data->c2spd[i] = hio_read32l(f);
+	c5spd = hio_read32l(f);
 
 	xxs->len = hio_read32l(f);
 	xxs->lps = hio_read32l(f);
@@ -711,6 +721,8 @@ static int get_chunk_is(struct module_data *m, int size, HIO_HANDLE *f, void *pa
 	xxs->flg = xxs->lpe > 0 ? XMP_SAMPLE_LOOP : 0;
 	xxs->lpe = xxs->lps + xxs->lpe;
 
+        m->xtra[i].c5spd = (double)c5spd;
+
 	hio_read8(f);				/* Volume in DMDL 0.0 */
 	x = hio_read8(f);
 	if (x & 0x01) {
@@ -727,7 +739,7 @@ static int get_chunk_is(struct module_data *m, int size, HIO_HANDLE *f, void *pa
 			xxs->flg & XMP_SAMPLE_16BIT ? '+' : ' ',
 			xxs->lps, xxs->lpe,
 			xxs->flg & XMP_SAMPLE_LOOP ? 'L' : ' ',
-			data->c2spd[i], data->packinfo[i]);
+			c5spd, data->packinfo[i]);
     }
 
     return 0;
@@ -745,7 +757,7 @@ static int get_chunk_i0(struct module_data *m, int size, HIO_HANDLE *f, void *pa
 
     D_(D_INFO "Instruments: %d", mod->ins);
 
-    if (instrument_init(mod) < 0)
+    if (libxmp_init_instrument(m) < 0)
 	return -1;
 
     if ((data->packinfo = calloc(sizeof (int), mod->smp)) == NULL)
@@ -754,9 +766,10 @@ static int get_chunk_i0(struct module_data *m, int size, HIO_HANDLE *f, void *pa
     for (i = 0; i < mod->ins; i++) {
 	struct xmp_subinstrument *sub;
 	struct xmp_sample *xxs = &mod->xxs[i];
+	int c5spd;
 
 	mod->xxi[i].nsm = 1;
-	if (subinstrument_alloc(mod, i, 1) < 0)
+	if (libxmp_alloc_subinstrument(mod, i, 1) < 0)
 	    return -1;
 
 	sub = &mod->xxi[i].sub[0];
@@ -764,11 +777,10 @@ static int get_chunk_i0(struct module_data *m, int size, HIO_HANDLE *f, void *pa
 
 	hio_read(buf, 1, 32, f);
 	buf[32] = 0;
-	adjust_string(buf);			/* Sample name */
 	hio_seek(f, 8, SEEK_CUR);	/* Sample filename */
-	strncpy(mod->xxi[i].name, buf, 32);
+	strncpy(mod->xxi[i].name, buf, 31);
 
-	data->c2spd[i] = hio_read16l(f);
+	c5spd = hio_read16l(f);
 
 	xxs->len = hio_read32l(f);
 	xxs->lps = hio_read32l(f);
@@ -779,6 +791,8 @@ static int get_chunk_i0(struct module_data *m, int size, HIO_HANDLE *f, void *pa
 	sub->vol = hio_read8(f);	/* Volume */
 	sub->pan = 0x80;
 
+        m->xtra[i].c5spd = (double)c5spd;
+
 	x = hio_read8(f);
 	if (x & 0x01) {
 	    xxs->flg |= XMP_SAMPLE_16BIT;
@@ -790,7 +804,7 @@ static int get_chunk_i0(struct module_data *m, int size, HIO_HANDLE *f, void *pa
 	data->packinfo[i] = (x & 0x0c) >> 2;
 
 	D_(D_INFO "[%2X] %-32.32s %5d V%02x %05x%c %05x %05x %d",
-		data->i_index[i], buf, data->c2spd[i], sub->vol,
+		data->i_index[i], buf, c5spd, sub->vol,
 		xxs->len, xxs->flg & XMP_SAMPLE_16BIT ? '+' : ' ',
 		xxs->lps, xxs->lpe, data->packinfo[i]);
     }
@@ -856,7 +870,7 @@ static int get_chunk_sa(struct module_data *m, int size, HIO_HANDLE *f, void *pa
             goto err2;
 	}
 	
-	if (load_sample(m, NULL, SAMPLE_FLAG_NOLOAD, xxs, (char *)smpbuf) < 0)
+	if (libxmp_load_sample(m, NULL, SAMPLE_FLAG_NOLOAD, xxs, (char *)smpbuf) < 0)
 	    goto err2;
 
 	free(smpbuf);
@@ -955,35 +969,35 @@ static int mdl_load(struct module_data *m, HIO_HANDLE *f, const int start)
     hio_read32b(f);
     hio_read(buf, 1, 1, f);
 
-    handle = iff_new();
+    handle = libxmp_iff_new();
     if (handle == NULL)
 	return -1;
 
     /* IFFoid chunk IDs */
-    iff_register(handle, "IN", get_chunk_in);	/* Module info */
-    iff_register(handle, "TR", get_chunk_tr);	/* Tracks */
-    iff_register(handle, "SA", get_chunk_sa);	/* Sampled data */
-    iff_register(handle, "VE", get_chunk_ve);	/* Volume envelopes */
-    iff_register(handle, "PE", get_chunk_pe);	/* Pan envelopes */
-    iff_register(handle, "FE", get_chunk_fe);	/* Pitch envelopes */
+    libxmp_iff_register(handle, "IN", get_chunk_in);	/* Module info */
+    libxmp_iff_register(handle, "TR", get_chunk_tr);	/* Tracks */
+    libxmp_iff_register(handle, "SA", get_chunk_sa);	/* Sampled data */
+    libxmp_iff_register(handle, "VE", get_chunk_ve);	/* Volume envelopes */
+    libxmp_iff_register(handle, "PE", get_chunk_pe);	/* Pan envelopes */
+    libxmp_iff_register(handle, "FE", get_chunk_fe);	/* Pitch envelopes */
 
     if (MSN(*buf)) {
-	iff_register(handle, "II", get_chunk_ii);	/* Instruments */
-	iff_register(handle, "PA", get_chunk_pa);	/* Patterns */
-	iff_register(handle, "IS", get_chunk_is);	/* Sample info */
+	libxmp_iff_register(handle, "II", get_chunk_ii);	/* Instruments */
+	libxmp_iff_register(handle, "PA", get_chunk_pa);	/* Patterns */
+	libxmp_iff_register(handle, "IS", get_chunk_is);	/* Sample info */
     } else {
-	iff_register(handle, "PA", get_chunk_p0);	/* Old 0.0 patterns */
-	iff_register(handle, "IS", get_chunk_i0);	/* Old 0.0 Sample info */
+	libxmp_iff_register(handle, "PA", get_chunk_p0);	/* Old 0.0 patterns */
+	libxmp_iff_register(handle, "IS", get_chunk_i0);	/* Old 0.0 Sample info */
     }
 
     /* MDL uses a IFF-style file format with 16 bit IDs and little endian
      * 32 bit chunk size. There's only one chunk per data type (i.e. one
      * big chunk for all samples).
      */
-    iff_id_size(handle, 2);
-    iff_set_quirk(handle, IFF_LITTLE_ENDIAN);
+    libxmp_iff_id_size(handle, 2);
+    libxmp_iff_set_quirk(handle, IFF_LITTLE_ENDIAN);
 
-    set_type(m, "Digitrakker MDL %d.%d", MSN(*buf), LSN(*buf));
+    libxmp_set_type(m, "Digitrakker MDL %d.%d", MSN(*buf), LSN(*buf));
 
     m->volbase = 0xff;
     m->c4rate = C4_NTSC_RATE;
@@ -994,20 +1008,19 @@ static int mdl_load(struct module_data *m, HIO_HANDLE *f, const int start)
     data.v_index = malloc(256 * sizeof (int));
     data.p_index = malloc(256 * sizeof (int));
     data.f_index = malloc(256 * sizeof (int));
-    data.c2spd = calloc(256, sizeof (int));
 
     for (i = 0; i < 256; i++) {
 	data.v_index[i] = data.p_index[i] = data.f_index[i] = -1;
     }
 
     /* Load IFFoid chunks */
-    if (iff_load(handle, m, f, &data) < 0) {
-    	iff_release(handle);
+    if (libxmp_iff_load(handle, m, f, &data) < 0) {
+    	libxmp_iff_release(handle);
 	retval = -1;
 	goto err;
     }
 
-    iff_release(handle);
+    libxmp_iff_release(handle);
 
     /* Reindex instruments */
     for (i = 0; i < mod->trk; i++) {
@@ -1033,8 +1046,8 @@ static int mdl_load(struct module_data *m, HIO_HANDLE *f, const int start)
 	    for (k = 0; k < mod->smp; k++) {
 		if (mod->xxi[i].sub[j].sid == data.s_index[k]) {
 		    mod->xxi[i].sub[j].sid = k;
-		    c2spd_to_note(data.c2spd[k],
-			&mod->xxi[i].sub[j].xpo, &mod->xxi[i].sub[j].fin);
+		    /*libxmp_c2spd_to_note(data.c2spd[k],
+			&mod->xxi[i].sub[j].xpo, &mod->xxi[i].sub[j].fin);*/
 		    break;
 		}
 	    }
@@ -1042,7 +1055,6 @@ static int mdl_load(struct module_data *m, HIO_HANDLE *f, const int start)
     }
 
   err:
-    free(data.c2spd);
     free(data.f_index);
     free(data.p_index);
     free(data.v_index);
