@@ -1,5 +1,5 @@
 /* Extended Module Player
- * Copyright (C) 1996-2015 Claudio Matsuoka and Hipolito Carraro Jr
+ * Copyright (C) 1996-2016 Claudio Matsuoka and Hipolito Carraro Jr
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -27,7 +27,7 @@
 static int mmd3_test (HIO_HANDLE *, char *, const int);
 static int mmd3_load (struct module_data *, HIO_HANDLE *, const int);
 
-const struct format_loader mmd3_loader = {
+const struct format_loader libxmp_loader_mmd3 = {
 	"OctaMED",
 	mmd3_test,
 	mmd3_load
@@ -52,9 +52,9 @@ static int mmd3_test(HIO_HANDLE *f, char *t, const int start)
 		offset = hio_read32b(f);
 		len = hio_read32b(f);
 		hio_seek(f, start + offset, SEEK_SET);
-		read_title(f, t, len);
+		libxmp_read_title(f, t, len);
 	} else {
-		read_title(f, t, 0);
+		libxmp_read_title(f, t, 0);
 	}
 
 	return 0;
@@ -164,6 +164,11 @@ static int mmd3_load(struct module_data *m, HIO_HANDLE *f, const int start)
 	song.mastervol = hio_read8(f);
 	song.numsamples = hio_read8(f);
 
+	/* Sanity check */
+	if (song.numsamples > 63) {
+		return -1;
+	}
+
 	/*
 	 * read sequence
 	 */
@@ -265,6 +270,10 @@ static int mmd3_load(struct module_data *m, HIO_HANDLE *f, const int start)
 		hio_read32b(f);		/* dumps */
 		mmdinfo_offset = hio_read32b(f);
 
+		if (hio_error(f)) {
+			return -1;
+		}
+
 		hio_seek(f, start + songname_offset, SEEK_SET);
 		D_(D_INFO "expdata.songnamelen = %d", expdata.songnamelen);
 		for (i = 0; i < expdata.songnamelen; i++) {
@@ -295,10 +304,11 @@ static int mmd3_load(struct module_data *m, HIO_HANDLE *f, const int start)
 		hio_seek(f, start + block_offset, SEEK_SET);
 
 		block.numtracks = hio_read16b(f);
-		block.lines = hio_read16b(f);
+		/* block.lines = */ hio_read16b(f);
 
-		if (block.numtracks > mod->chn)
+		if (block.numtracks > mod->chn) {
 			mod->chn = block.numtracks;
+		}
 	}
 
 	/* Sanity check */
@@ -308,9 +318,9 @@ static int mmd3_load(struct module_data *m, HIO_HANDLE *f, const int start)
 	mod->trk = mod->pat * mod->chn;
 
 	if (ver == 2)
-		set_type(m, "OctaMED v5 MMD2");
+		libxmp_set_type(m, "OctaMED v5 MMD2");
 	else
-		set_type(m, "OctaMED Soundstudio MMD%c", '0' + ver);
+		libxmp_set_type(m, "OctaMED Soundstudio MMD%c", '0' + ver);
 
 	MODULE_INFO();
 
@@ -323,7 +333,7 @@ static int mmd3_load(struct module_data *m, HIO_HANDLE *f, const int start)
 	 */
 	D_(D_WARN "read patterns");
 
-	if (pattern_init(mod) < 0)
+	if (libxmp_init_pattern(mod) < 0)
 		return -1;
 
 	for (i = 0; i < mod->pat; i++) {
@@ -339,7 +349,7 @@ static int mmd3_load(struct module_data *m, HIO_HANDLE *f, const int start)
 		block.lines = hio_read16b(f);
 		hio_read32b(f);
 
-		if (pattern_tracks_alloc(mod, i, block.lines + 1) < 0)
+		if (libxmp_alloc_pattern_tracks(mod, i, block.lines + 1) < 0)
 			return -1;
 
 		for (j = 0; j < mod->xxp[i]->rows; j++) {
@@ -377,7 +387,7 @@ static int mmd3_load(struct module_data *m, HIO_HANDLE *f, const int start)
 		}
 	}
 
-	if (med_new_module_extras(m) != 0)
+	if (libxmp_med_new_module_extras(m) != 0)
 		return -1;
 
 	/*
@@ -385,7 +395,7 @@ static int mmd3_load(struct module_data *m, HIO_HANDLE *f, const int start)
 	 */
 	D_(D_WARN "read instruments");
 
-	if (instrument_init(mod) < 0)
+	if (libxmp_init_instrument(m) < 0)
 		return -1;
 
 	D_(D_INFO "Instruments: %d", mod->ins);
@@ -398,19 +408,25 @@ static int mmd3_load(struct module_data *m, HIO_HANDLE *f, const int start)
 
 		D_(D_INFO "sample %d smpl_offset = 0x%08x", i, smpl_offset);
 
-		if (smpl_offset == 0)
+		if (smpl_offset == 0) {
 			continue;
+		}
 
 		hio_seek(f, start + smpl_offset, SEEK_SET);
 		instr.length = hio_read32b(f);
 		instr.type = hio_read16b(f);
 
-		pos = hio_tell(f);
+		if ((pos = hio_tell(f)) < 0) {
+			return -1;
+		}
 
 		if (expdata_offset && i < expdata.i_ext_entries) {
 			struct xmp_instrument *xxi = &mod->xxi[i];
-			hio_seek(f, iinfo_offset + i * expdata.i_ext_entrsz,
-								SEEK_SET);
+			int offset = iinfo_offset + i * expdata.i_ext_entrsz;
+
+			if (offset < 0 || hio_seek(f, offset, SEEK_SET) < 0) {
+				return -1;
+			}
 			hio_read(&xxi->name, 40, 1, f);
 			D_(D_INFO "[%2x] %-40.40s %d", i, mod->xxi[i].name, instr.type);
 		}
@@ -418,8 +434,11 @@ static int mmd3_load(struct module_data *m, HIO_HANDLE *f, const int start)
 		memset(&exp_smp, 0, sizeof(struct InstrExt));
 
 		if (expdata_offset && i < expdata.s_ext_entries) {
-			hio_seek(f, expsmp_offset + i * expdata.s_ext_entrsz,
-							SEEK_SET);
+			int offset = expsmp_offset + i * expdata.s_ext_entrsz;
+
+			if (offset < 0 || hio_seek(f, offset, SEEK_SET) < 0) {
+				return -1;
+			}
 			exp_smp.hold = hio_read8(f);
 			exp_smp.decay = hio_read8(f);
 			exp_smp.suppress_midi_off = hio_read8(f);
@@ -477,11 +496,11 @@ static int mmd3_load(struct module_data *m, HIO_HANDLE *f, const int start)
 			smp_idx += oct;
 
 			continue;
-		} /* else if ((instr.type & ~(S_16 | STEREO)) != 0) {
+		} else if ((instr.type & ~(S_16 | STEREO)) != 0) {
 			D_(D_WARN "stereo sample unsupported");
 			mod->xxi[i].nsm = 0;
 			continue;
-		} */ else if ((instr.type & ~S_16) == 0) {	/* Sample */
+		} else if ((instr.type & ~S_16) == 0) {	/* Sample */
 			int ret;
 
 			hio_seek(f, start + smpl_offset + 6, SEEK_SET);
