@@ -41,10 +41,10 @@
 #include "mod.h"
 
 struct mod_magic {
-    char *magic;
-    int flag;
-    int id;
-    int ch;
+	char *magic;
+	int flag;
+	int id;
+	int ch;
 };
 
 #define TRACKER_PROTRACKER	0
@@ -68,30 +68,29 @@ struct mod_magic {
 #define TRACKER_PROBABLY_NOISETRACKER 20
 
 const struct mod_magic mod_magic[] = {
-    { "M.K.", 0, TRACKER_PROTRACKER, 4 },
-    { "M!K!", 1, TRACKER_PROTRACKER, 4 },
-    { "M&K!", 1, TRACKER_NOISETRACKER, 4 },
-    { "N.T.", 1, TRACKER_NOISETRACKER, 4 },
-    { "6CHN", 0, TRACKER_FASTTRACKER, 6 },
-    { "8CHN", 0, TRACKER_FASTTRACKER, 8 },
-    { "CD61", 1, TRACKER_OCTALYSER, 6 },	/* Atari STe/Falcon */
-    { "CD81", 1, TRACKER_OCTALYSER, 8 },	/* Atari STe/Falcon */
-    { "TDZ4", 1, TRACKER_TAKETRACKER, 4 },	/* see XModule SaveTracker.c */
-    { "FA04", 1, TRACKER_DIGITALTRACKER, 4 },	/* Atari Falcon */
-    { "FA06", 1, TRACKER_DIGITALTRACKER, 6 },	/* Atari Falcon */
-    { "FA08", 1, TRACKER_DIGITALTRACKER, 8 },	/* Atari Falcon */
-    { "NSMS", 1, TRACKER_UNKNOWN, 4 },		/* in Kingdom.mod */
-    { "", 0 }
+	{"M.K.", 0, TRACKER_PROTRACKER, 4},
+	{"M!K!", 1, TRACKER_PROTRACKER, 4},
+	{"M&K!", 1, TRACKER_NOISETRACKER, 4},
+	{"N.T.", 1, TRACKER_NOISETRACKER, 4},
+	{"6CHN", 0, TRACKER_FASTTRACKER, 6},
+	{"8CHN", 0, TRACKER_FASTTRACKER, 8},
+	{"CD61", 1, TRACKER_OCTALYSER, 6},	/* Atari STe/Falcon */
+	{"CD81", 1, TRACKER_OCTALYSER, 8},	/* Atari STe/Falcon */
+	{"TDZ4", 1, TRACKER_TAKETRACKER, 4},	/* see XModule SaveTracker.c */
+	{"FA04", 1, TRACKER_DIGITALTRACKER, 4},	/* Atari Falcon */
+	{"FA06", 1, TRACKER_DIGITALTRACKER, 6},	/* Atari Falcon */
+	{"FA08", 1, TRACKER_DIGITALTRACKER, 8},	/* Atari Falcon */
+	{"NSMS", 1, TRACKER_UNKNOWN, 4},	/* in Kingdom.mod */
+	{"", 0}
 };
 
+static int mod_test(HIO_HANDLE *, char *, const int);
+static int mod_load(struct module_data *, HIO_HANDLE *, const int);
 
-static int mod_test (HIO_HANDLE *, char *, const int);
-static int mod_load (struct module_data *, HIO_HANDLE *, const int);
-
-const struct format_loader mod_loader = {
-    "Amiga Protracker/Compatible",
-    mod_test,
-    mod_load
+const struct format_loader libxmp_loader_mod = {
+	"Amiga Protracker/Compatible",
+	mod_test,
+	mod_load
 };
 
 static int validate_pattern(uint8 *buf)
@@ -101,143 +100,285 @@ static int validate_pattern(uint8 *buf)
 	for (i = 0; i < 64; i++) {
 		for (j = 0; j < 4; j++) {
 			uint8 *d = buf + (i * 4 + j) * 4;
-			if ((d[0] >> 4) > 1)
+			if ((d[0] >> 4) > 1) {
 				return -1;
+			}
 		}
 	}
 
 	return 0;
 }
 
-static int mod_test(HIO_HANDLE *f, char *t, const int start)
+static int mod_test(HIO_HANDLE * f, char *t, const int start)
 {
-    int i;
-    char buf[4];
-    uint8 pat_buf[1024];
-    int smp_size, num_pat;
-    long size;
+	int i;
+	char buf[4];
+	uint8 pat_buf[1024];
+	int smp_size, num_pat;
+	long size;
 
-    hio_seek(f, start + 1080, SEEK_SET);
-    if (hio_read(buf, 1, 4, f) < 4)
-	return -1;
-
-    if (!strncmp(buf + 2, "CH", 2) && isdigit((int)buf[0]) && isdigit((int)buf[1])) {
-	i = (buf[0] - '0') * 10 + buf[1] - '0';
-	if (i > 0 && i <= 32) {
-	    goto found;
-	}
-    }
-
-    if (!strncmp(buf + 1, "CHN", 3) && isdigit((int)*buf)) {
-	if (*buf - '0') {
-	    goto found;
-	}
-    }
-
-    for (i = 0; mod_magic[i].ch; i++) {
-	if (!memcmp(buf, mod_magic[i].magic, 4))
-	    break;
-    }
-    if (mod_magic[i].ch == 0)
-	return -1;
-
-    /*
-     * Sanity check to prevent loading NoiseRunner and other module
-     * formats with valid magic at offset 1080
-     */
-
-    hio_seek(f, start + 20, SEEK_SET);
-    for (i = 0; i < 31; i++) {
-	uint8 x;
-
-	hio_seek(f, 22, SEEK_CUR);		/* Instrument name */
-
-	/* OpenMPT can create mods with large samples */
-	hio_read16b(f);				/* sample size */
-
-	/* Chris Spiegel tells me that sandman.mod can have 0x20 in finetune */
-	x = hio_read8(f);
-	if (x & 0xf0 && x != 0x20)		/* test finetune */
+	hio_seek(f, start + 1080, SEEK_SET);
+	if (hio_read(buf, 1, 4, f) < 4) {
 		return -1;
-	if (hio_read8(f) > 0x40)		/* test volume */
+	}
+
+	if (!strncmp(buf + 2, "CH", 2) && isdigit((int)buf[0])
+	    && isdigit((int)buf[1])) {
+		i = (buf[0] - '0') * 10 + buf[1] - '0';
+		if (i > 0 && i <= 32) {
+			goto found;
+		}
+	}
+
+	if (!strncmp(buf + 1, "CHN", 3) && isdigit((int)*buf)) {
+		if (*buf - '0') {
+			goto found;
+		}
+	}
+
+	for (i = 0; mod_magic[i].ch; i++) {
+		if (!memcmp(buf, mod_magic[i].magic, 4))
+			break;
+	}
+	if (mod_magic[i].ch == 0) {
 		return -1;
-	hio_read16b(f);				/* loop start */
-	hio_read16b(f);				/* loop size */
-    }
+	}
 
-    /* Test for UNIC tracker modules
-     *
-     * From Gryzor's Pro-Wizard PW_FORMATS-Engl.guide:
-     * ``The UNIC format is very similar to Protracker... At least in the
-     * heading... same length : 1084 bytes. Even the "M.K." is present,
-     * sometimes !! Maybe to disturb the rippers.. hehe but Pro-Wizard
-     * doesn't test this only!''
-     */
+	/*
+	 * Sanity check to prevent loading NoiseRunner and other module
+	 * formats with valid magic at offset 1080
+	 */
 
-    /* get file size */
-    size = hio_size(f);
-    smp_size = 0;
-    hio_seek(f, start + 20, SEEK_SET);
+	hio_seek(f, start + 20, SEEK_SET);
+	for (i = 0; i < 31; i++) {
+		uint8 x;
 
-    /* get samples size */
-    for (i = 0; i < 31; i++) {
-	hio_seek(f, 22, SEEK_CUR);
-	smp_size += 2 * hio_read16b(f);		/* Length in 16-bit words */
-	hio_seek(f, 6, SEEK_CUR);
-    } 
+		hio_seek(f, 22, SEEK_CUR);	/* Instrument name */
 
-    /* get number of patterns */
-    num_pat = 0;
-    hio_seek(f, start + 952, SEEK_SET);
-    for (i = 0; i < 128; i++) {
-	uint8 x = hio_read8(f);
-	if (x > 0x7f)
-		break;
-	if (x > num_pat)
-	    num_pat = x;
-    }
-    num_pat++;
+		/* OpenMPT can create mods with large samples */
+		hio_read16b(f);	/* sample size */
 
-    /* see if module size matches UNIC */
-    if (start + 1084 + num_pat * 0x300 + smp_size == size)
-	return -1;
+		/* Chris Spiegel tells me that sandman.mod has 0x20 in finetune */
+		x = hio_read8(f);
+		if (x & 0xf0 && x != 0x20)	/* test finetune */
+			return -1;
+		if (hio_read8(f) > 0x40)	/* test volume */
+			return -1;
+		hio_read16b(f);	/* loop start */
+		hio_read16b(f);	/* loop size */
+	}
 
-    /* validate pattern data in an attempt to catch UNICs with MOD size */
-    for (i = 0; i < num_pat; i++) {
-	hio_seek(f, start + 1084 + 1024 * i, SEEK_SET);
-	hio_read(pat_buf, 1024, 1, f);
-	if (validate_pattern(pat_buf) < 0)
-	    return -1;
-    }
+	/* Test for UNIC tracker modules
+	 *
+	 * From Gryzor's Pro-Wizard PW_FORMATS-Engl.guide:
+	 * ``The UNIC format is very similar to Protracker... At least in the
+	 * heading... same length : 1084 bytes. Even the "M.K." is present,
+	 * sometimes !! Maybe to disturb the rippers.. hehe but Pro-Wizard
+	 * doesn't test this only!''
+	 */
 
-  found:
-    hio_seek(f, start + 0, SEEK_SET);
-    read_title(f, t, 20);
+	/* get file size */
+	size = hio_size(f);
+	smp_size = 0;
+	hio_seek(f, start + 20, SEEK_SET);
 
-    return 0;
+	/* get samples size */
+	for (i = 0; i < 31; i++) {
+		hio_seek(f, 22, SEEK_CUR);
+		smp_size += 2 * hio_read16b(f);	/* Length in 16-bit words */
+		hio_seek(f, 6, SEEK_CUR);
+	}
+
+	/* get number of patterns */
+	num_pat = 0;
+	hio_seek(f, start + 952, SEEK_SET);
+	for (i = 0; i < 128; i++) {
+		uint8 x = hio_read8(f);
+		if (x > 0x7f)
+			break;
+		if (x > num_pat)
+			num_pat = x;
+	}
+	num_pat++;
+
+	/* see if module size matches UNIC */
+	if (start + 1084 + num_pat * 0x300 + smp_size == size)
+		return -1;
+
+	/* validate pattern data in an attempt to catch UNICs with MOD size */
+	for (i = 0; i < num_pat; i++) {
+		hio_seek(f, start + 1084 + 1024 * i, SEEK_SET);
+		hio_read(pat_buf, 1024, 1, f);
+		if (validate_pattern(pat_buf) < 0)
+			return -1;
+	}
+
+found:
+	hio_seek(f, start + 0, SEEK_SET);
+	libxmp_read_title(f, t, 20);
+
+	return 0;
 }
 
 
-static int is_st_ins (char *s)
+static int is_st_ins(char *s)
 {
-    if (s[0] != 's' && s[0] != 'S')
-	return 0;
-    if (s[1] != 't' && s[1] != 'T')
-	return 0;
-    if (s[2] != '-' || s[5] != ':')
-	return 0;
-    if (!isdigit((int)s[3]) || !isdigit((int)s[4]))
-	return 0;
+	if (s[0] != 's' && s[0] != 'S')
+		return 0;
+	if (s[1] != 't' && s[1] != 'T')
+		return 0;
+	if (s[2] != '-' || s[5] != ':')
+		return 0;
+	if (!isdigit((int)s[3]) || !isdigit((int)s[4]))
+		return 0;
 
-    return 1;
+	return 1;
 }
 
+static int get_tracker_id(struct module_data *m, struct mod_header *mh, int id)
+{
+	struct xmp_module *mod = &m->mod;
+	int has_loop_0 = 0;
+	int has_vol_in_empty_ins = 0;
+	int i;
+
+	/* Check if has instruments with loop size 0 */
+	for (i = 0; i < 31; i++) {
+		if (mh->ins[i].loop_size == 0) {
+			has_loop_0 = 1;
+			break;
+		}
+	}
+
+	/* Check if has instruments with size 0 and volume > 0 */
+	for (i = 0; i < 31; i++) {
+		if (mh->ins[i].size == 0 && mh->ins[i].volume > 0) {
+			has_vol_in_empty_ins = 1;
+			break;
+		}
+	}
+
+	/*
+	 * Test Protracker-like files
+	 */
+	if (mh->restart == mod->pat) {
+		if (mod->chn == 4) {
+			id = TRACKER_SOUNDTRACKER;
+		} else {
+			id = TRACKER_UNKNOWN;
+		}
+	} else if (mh->restart == 0x78) {
+		if (mod->chn == 4) {
+			/* Can't trust this for Noisetracker, MOD.Data City Remix
+			 * has Protracker effects and Noisetracker restart byte
+			 */
+			id = TRACKER_PROBABLY_NOISETRACKER;
+		} else {
+			id = TRACKER_UNKNOWN;
+		}
+		return id;
+	} else if (mh->restart < 0x7f) {
+		if (mod->chn == 4 && !has_vol_in_empty_ins) {
+			id = TRACKER_NOISETRACKER;
+		} else {
+			id = TRACKER_UNKNOWN; /* ? */
+		}
+		mod->rst = mh->restart;
+	} else if (mh->restart == 0x7f) {
+		if (mod->chn == 4) {
+			if (has_loop_0) {
+				id = TRACKER_CLONE;
+			}
+		} else {
+			id = TRACKER_SCREAMTRACKER3;
+		}
+		return id;
+	} else if (mh->restart > 0x7f) {
+		id = TRACKER_UNKNOWN; /* ? */
+		return id;
+	}
+
+	if (!has_loop_0) { /* All loops are size 2 or greater */
+
+		for (i = 0; i < 31; i++) {
+			if (mh->ins[i].size == 1 && mh->ins[i].volume == 0) {
+				return TRACKER_CONVERTED;
+			}
+		}
+
+		for (i = 0; i < 31; i++) {
+			if (is_st_ins((char *)mh->ins[i].name))
+				break;
+		}
+		if (i == 31) {	/* No st- instruments */
+			for (i = 0; i < 31; i++) {
+				if (mh->ins[i].size != 0
+				    || mh->ins[i].loop_size != 1) {
+					continue;
+				}
+
+				switch (mod->chn) {
+				case 4:
+					if (has_vol_in_empty_ins) {
+						id = TRACKER_OPENMPT;
+					} else {
+						id = TRACKER_NOISETRACKER;
+						/* or Octalyser */
+					}
+					break;
+				case 6:
+				case 8:
+					id = TRACKER_OCTALYSER;
+					break;
+				default:
+					id = TRACKER_UNKNOWN;
+				}
+				return id;
+			}
+
+			if (mod->chn == 4) {
+				id = TRACKER_PROTRACKER;
+			} else if (mod->chn == 6 || mod->chn == 8) {
+				/* FastTracker 1.01? */
+				id = TRACKER_FASTTRACKER;
+			} else {
+				id = TRACKER_UNKNOWN;
+			}
+		}
+	} else { /* Has loops with size 0 */
+		for (i = 15; i < 31; i++) {
+			if (strlen((char *)mh->ins[i].name)
+			    || mh->ins[i].size > 0)
+				break;
+		}
+		if (i == 31 && is_st_ins((char *)mh->ins[14].name)) {
+			return TRACKER_CONVERTEDST;
+		}
+
+		/* Assume that Fast Tracker modules won't have ST- instruments */
+		for (i = 0; i < 31; i++) {
+			if (is_st_ins((char *)mh->ins[i].name))
+				break;
+		}
+		if (i < 31) {
+			return TRACKER_UNKNOWN_CONV;
+		}
+
+		if (mod->chn == 4 || mod->chn == 6 || mod->chn == 8) {
+			return TRACKER_FASTTRACKER;
+		}
+
+		id = TRACKER_UNKNOWN;	/* ??!? */
+	}
+
+	return id;
+}
 
 static int mod_load(struct module_data *m, HIO_HANDLE *f, const int start)
 {
     struct xmp_module *mod = &m->mod;
     int i, j;
-    int smp_size, /*pat_size,*/ wow, ptsong = 0;
+    int smp_size, ptsong = 0;
     struct xmp_event *event;
     struct mod_header mh;
     uint8 mod_event[4];
@@ -246,8 +387,6 @@ static int mod_load(struct module_data *m, HIO_HANDLE *f, const int start)
     char magic[8], idbuffer[32];
     int ptkloop = 0;			/* Protracker loop */
     int tracker_id = TRACKER_PROTRACKER;
-    int has_loop_0 = 0;
-    int has_vol_in_empty_ins = 0;
     int out_of_range = 0;
 
     LOAD_INIT();
@@ -258,7 +397,7 @@ static int mod_load(struct module_data *m, HIO_HANDLE *f, const int start)
     smp_size = 0;
     /*pat_size = 0;*/
 
-    m->quirk |= QUIRK_MODRNG;
+    m->period_type = PERIOD_MODRNG;
 
     hio_read(&mh.name, 20, 1, f);
     for (i = 0; i < 31; i++) {
@@ -322,7 +461,7 @@ static int mod_load(struct module_data *m, HIO_HANDLE *f, const int start)
 
     /*pat_size = 256 * mod->chn * mod->pat;*/
 
-    if (instrument_init(mod) < 0)
+    if (libxmp_init_instrument(m) < 0)
 	return -1;
 
     for (i = 0; i < mod->ins; i++) {
@@ -330,7 +469,7 @@ static int mod_load(struct module_data *m, HIO_HANDLE *f, const int start)
 	struct xmp_subinstrument *sub;
 	struct xmp_sample *xxs;
 
-	if (subinstrument_alloc(mod, i, 1) < 0)
+	if (libxmp_alloc_subinstrument(mod, i, 1) < 0)
 	    return -1;
 
 	if (mh.ins[i].size >= 0x8000) {
@@ -354,7 +493,7 @@ static int mod_load(struct module_data *m, HIO_HANDLE *f, const int start)
 	sub->vol = mh.ins[i].volume;
 	sub->pan = 0x80;
 	sub->sid = i;
-	instrument_name(mod, i, mh.ins[i].name, 22);
+	libxmp_instrument_name(mod, i, mh.ins[i].name, 22);
 
 	if (xxs->len > 0) {
 		xxi->nsm = 1;
@@ -402,133 +541,20 @@ static int mod_load(struct module_data *m, HIO_HANDLE *f, const int start)
      * the module is an 8 channel WOW.
      */
 
-    if ((wow = (!strncmp(magic, "M.K.", 4) &&
-		(0x43c + mod->pat * 32 * 0x40 + smp_size == m->size)))) {
+    if ((!strncmp(magic, "M.K.", 4) &&
+		(0x43c + mod->pat * 32 * 0x40 + smp_size == m->size))) {
 	mod->chn = 8;
 	tracker_id = TRACKER_MODSGRAVE;
-	goto skip_test;
     }
-
-    /* Test for Protracker song files
-     */
+    /* Test for Protracker song files */
     else if ((ptsong = (!strncmp((char *)magic, "M.K.", 4) &&
 		(0x43c + mod->pat * 0x400 == m->size)))) {
 	tracker_id = TRACKER_PROTRACKER;
 	goto skip_test;
     }
-
-    /* Check if has instruments with loop size 0 */
-    for (i = 0; i < 31; i++) {
-	if (mh.ins[i].loop_size == 0) {
-            has_loop_0 = 1;
-	    break;
-	}
-    }
-
-    /* Check if has instruments with size 0 and volume > 0 */
-    for (i = 0; i < 31; i++) {
-	if (mh.ins[i].size == 0 && mh.ins[i].volume > 0) {
-	    has_vol_in_empty_ins = 1;
-	    break;
-	}
-    }
-
-    /* Test Protracker-like files
-     */
-    if (mod->chn == 4 && mh.restart == mod->pat) {
-	tracker_id = TRACKER_SOUNDTRACKER;
-    } else if (mod->chn == 4 && mh.restart == 0x78) {
-	/* Can't trust this for Noisetracker, MOD.Data City Remix has
-	 * Protracker effects and Noisetracker restart byte */
-        tracker_id = TRACKER_PROBABLY_NOISETRACKER;
-    } else if (mh.restart < 0x7f) {
-	if (mod->chn == 4 && !has_vol_in_empty_ins) {
-	    tracker_id = TRACKER_NOISETRACKER;
-	} else {
-	    tracker_id = TRACKER_UNKNOWN;
-	}
-	mod->rst = mh.restart;
-    }
-
-    if (mh.restart == 0x7f) {
-        if (mod->chn == 4) {
-	    if (has_loop_0) {
-	        tracker_id = TRACKER_CLONE;
-	    }
-        } else {
-	    tracker_id = TRACKER_SCREAMTRACKER3;
-	    m->read_event_type = READ_EVENT_ST3;
-        }
-    }
-
-    if (mh.restart != 0x78 && mh.restart < 0x7f) {
-	if (!has_loop_0) {	/* All loops are size 2 or greater */
-	    for (i = 0; i < 31; i++) {
-		if (mh.ins[i].size == 1 && mh.ins[i].volume == 0) {
-		    tracker_id = TRACKER_CONVERTED;
-		    goto skip_test;
-		}
-	    }
-
-	    for (i = 0; i < 31; i++) {
-	        if (is_st_ins((char *)mh.ins[i].name))
-		    break;
-	    }
-	    if (i == 31) {	/* No st- instruments */
-	        for (i = 0; i < 31; i++) {
-		    if (mh.ins[i].size == 0 && mh.ins[i].loop_size == 1) {
-			switch (mod->chn) {
-			case 4:
-			    tracker_id = has_vol_in_empty_ins ?
-				TRACKER_OPENMPT :
-				TRACKER_NOISETRACKER;	/* or Octalyser */
-			    break;
-			case 6:
-			case 8:
-		            tracker_id = TRACKER_OCTALYSER;
-			    break;
-			default:
-		            tracker_id = TRACKER_UNKNOWN;
-			}
-		        goto skip_test;
-		    }
-	        }
-
-		if (mod->chn == 4) {
-	    	    tracker_id = TRACKER_PROTRACKER;
-		} else if (mod->chn == 6 || mod->chn == 8) {
-	    	    tracker_id = TRACKER_FASTTRACKER;	/* FastTracker 1.01? */
-		} else {
-	    	    tracker_id = TRACKER_UNKNOWN;
-		}
-	    }
-	} else {	/* Has loops with 0 size */
-	    for (i = 15; i < 31; i++) {
-	        if (strlen((char *)mh.ins[i].name) || mh.ins[i].size > 0)
-		    break;
-	    }
-	    if (i == 31 && is_st_ins((char *)mh.ins[14].name)) {
-		tracker_id = TRACKER_CONVERTEDST;
-		goto skip_test;
-	    }
-
-	    /* Assume that Fast Tracker modules won't have ST- instruments */
-	    for (i = 0; i < 31; i++) {
-	        if (is_st_ins((char *)mh.ins[i].name))
-		    break;
-	    }
-	    if (i < 31) {
-		tracker_id = TRACKER_UNKNOWN_CONV;
-		goto skip_test;
-	    }
-
-	    if (mod->chn == 4 || mod->chn == 6 || mod->chn == 8) {
-	    	tracker_id = TRACKER_FASTTRACKER;
-		goto skip_test;
-	    }
-
-	    tracker_id = TRACKER_UNKNOWN;	/* ??!? */
-	}
+    /* something else */
+    else {
+        tracker_id = get_tracker_id(m, &mh, tracker_id);
     }
 
 skip_test:
@@ -550,7 +576,7 @@ skip_test:
 			mod->xxs[i].len > mod->xxs[i].lpe ? '!' : ' ');
     }
 
-    if (pattern_init(mod) < 0)
+    if (libxmp_init_pattern(mod) < 0)
 	return -1;
 
     /* Load and convert patterns */
@@ -559,7 +585,7 @@ skip_test:
     for (i = 0; i < mod->pat; i++) {
 	long pos;
 
-	if (pattern_tracks_alloc(mod, i, 64) < 0)
+	if (libxmp_alloc_pattern_tracks(mod, i, 64) < 0)
 	    return -1;
 
 	pos = hio_tell(f);
@@ -612,10 +638,10 @@ skip_test:
 	    switch (tracker_id) {
 	    case TRACKER_PROBABLY_NOISETRACKER:
 	    case TRACKER_NOISETRACKER:
-	    	decode_noisetracker_event(event, mod_event);
+	    	libxmp_decode_noisetracker_event(event, mod_event);
 		break;
 	    default:	
-	        decode_protracker_event(event, mod_event);
+	        libxmp_decode_protracker_event(event, mod_event);
 	    }
 	}
     }
@@ -628,20 +654,20 @@ skip_test:
     case TRACKER_PROBABLY_NOISETRACKER:
     case TRACKER_NOISETRACKER:
 	tracker = "Noisetracker";
-	ptkloop = 1;
+	m->quirk |= QUIRK_NOBPM;
 	break;
     case TRACKER_SOUNDTRACKER:
 	tracker = "Soundtracker";
-	ptkloop = 1;
+	m->quirk |= QUIRK_NOBPM;
 	break;
     case TRACKER_FASTTRACKER:
     case TRACKER_FASTTRACKER2:
 	tracker = "Fast Tracker";
-	m->quirk &= ~QUIRK_MODRNG;
+	m->period_type = PERIOD_AMIGA;
 	break;
     case TRACKER_TAKETRACKER:
 	tracker = "Take Tracker";
-	m->quirk &= ~QUIRK_MODRNG;
+	m->period_type = PERIOD_AMIGA;
 	break;
     case TRACKER_OCTALYSER:
 	tracker = "Octalyser";
@@ -657,7 +683,7 @@ skip_test:
 	break;
     case TRACKER_SCREAMTRACKER3:
 	tracker = "Scream Tracker";
-	m->quirk &= ~QUIRK_MODRNG;
+	m->period_type = PERIOD_AMIGA;
 	break;
     case TRACKER_CONVERTEDST:
     case TRACKER_CONVERTED:
@@ -665,7 +691,7 @@ skip_test:
 	break;
     case TRACKER_CLONE:
 	tracker = "Protracker clone";
-	m->quirk &= ~QUIRK_MODRNG;
+	m->period_type = PERIOD_AMIGA;
 	break;
     case TRACKER_OPENMPT:
 	tracker = "OpenMPT";
@@ -675,12 +701,12 @@ skip_test:
     case TRACKER_UNKNOWN_CONV:
     case TRACKER_UNKNOWN:
 	tracker = "Unknown tracker";
-	m->quirk &= ~QUIRK_MODRNG;
+	m->period_type = PERIOD_AMIGA;
 	break;
     }
 
     if (out_of_range) {
-	m->quirk &= ~QUIRK_MODRNG;
+	m->period_type = PERIOD_AMIGA;
     }
 
     if (tracker_id == TRACKER_MODSGRAVE) {
@@ -713,7 +739,7 @@ skip_test:
 	    snprintf(sn, XMP_NAME_SIZE, "%s%s", pathname, mod->xxi[i].name);
 	
 	    if ((s = hio_open(sn, "rb"))) {
-	        if (load_sample(m, s, flags, &mod->xxs[i], NULL) < 0) {
+	        if (libxmp_load_sample(m, s, flags, &mod->xxs[i], NULL) < 0) {
 		    hio_close(s);
 		    return -1;
 		}
@@ -735,7 +761,7 @@ skip_test:
 		hio_seek(f, pos, SEEK_SET);
 	    }
 
-	    if (load_sample(m, f, flags, &mod->xxs[i], NULL) < 0)
+	    if (libxmp_load_sample(m, f, flags, &mod->xxs[i], NULL) < 0)
 		return -1;
 	}
     }
@@ -743,12 +769,14 @@ skip_test:
     if (tracker_id == TRACKER_PROTRACKER || tracker_id == TRACKER_OPENMPT) {
 	m->quirk |= QUIRK_PROTRACK;
     } else if (tracker_id == TRACKER_SCREAMTRACKER3) {
+	m->c4rate = C4_NTSC_RATE;
 	m->quirk |= QUIRKS_ST3;
 	m->read_event_type = READ_EVENT_ST3;
-    } else if (mod->chn > 4) {
-	m->quirk &= ~QUIRK_MODRNG;
-	m->quirk |= QUIRKS_FT2;
+    } else if (tracker_id == TRACKER_FASTTRACKER || tracker_id == TRACKER_FASTTRACKER2 || tracker_id == TRACKER_TAKETRACKER || tracker_id == TRACKER_MODSGRAVE || mod->chn > 4) {
+	m->c4rate = C4_NTSC_RATE;
+	m->quirk |= QUIRKS_FT2 | QUIRK_FTMOD;
 	m->read_event_type = READ_EVENT_FT2;
+	m->period_type = PERIOD_AMIGA;
     }
 
     return 0;
