@@ -31,7 +31,7 @@
 static int no_test (HIO_HANDLE *, char *, const int);
 static int no_load (struct module_data *, HIO_HANDLE *, const int);
 
-const struct format_loader no_loader = {
+const struct format_loader libxmp_loader_no = {
 	"Liquid Tracker NO",
 	no_test,
 	no_load
@@ -73,7 +73,7 @@ static int no_test(HIO_HANDLE *f, char *t, const int start)
 
 	hio_seek(f, start + 5, SEEK_SET);
 
-	read_title(f, t, nsize);
+	libxmp_read_title(f, t, nsize);
 
 	return 0;
 }
@@ -109,7 +109,7 @@ static int no_load(struct module_data *m, HIO_HANDLE *f, const int start)
 
 	hio_read32b(f);			/* NO 0x00 0x00 */
 
-	set_type(m, "Liquid Tracker");
+	libxmp_set_type(m, "Liquid Tracker");
 
 	nsize = hio_read8(f);
 	for (i = 0; i < nsize; i++) {
@@ -142,16 +142,18 @@ static int no_load(struct module_data *m, HIO_HANDLE *f, const int start)
 	hio_seek(f, 255 - i, SEEK_CUR);
 	mod->len = i;
 
+	m->c4rate = C4_NTSC_RATE;
+
 	MODULE_INFO();
 
-	if (instrument_init(mod) < 0)
+	if (libxmp_init_instrument(m) < 0)
 		return -1;
 
 	/* Read instrument names */
 	for (i = 0; i < mod->ins; i++) {
 		int hasname, c2spd;
 
-		if (subinstrument_alloc(mod, i, 1) < 0)
+		if (libxmp_alloc_subinstrument(mod, i, 1) < 0)
 			return -1;
 
 		nsize = hio_read8(f);
@@ -198,18 +200,17 @@ static int no_load(struct module_data *m, HIO_HANDLE *f, const int start)
 				mod->xxs[i].flg & XMP_SAMPLE_LOOP ? 'L' : ' ',
 				mod->xxi[i].sub[0].vol, c2spd);
 
-		c2spd = 8363 * c2spd / 8448;
-		c2spd_to_note(c2spd, &mod->xxi[i].sub[0].xpo, &mod->xxi[i].sub[0].fin);
+		libxmp_c2spd_to_note(c2spd, &mod->xxi[i].sub[0].xpo, &mod->xxi[i].sub[0].fin);
 	}
 
-	if (pattern_init(mod) < 0)
+	if (libxmp_init_pattern(mod) < 0)
 		return -1;
 
 	/* Read and convert patterns */
 	D_(D_INFO "Stored patterns: %d ", mod->pat);
 
 	for (i = 0; i < mod->pat; i++) {
-		if (pattern_tracks_alloc(mod, i, 64) < 0)
+		if (libxmp_alloc_pattern_tracks(mod, i, 64) < 0)
 			return -1;
 
 		for (j = 0; j < mod->xxp[i]->rows; j++) {
@@ -245,7 +246,7 @@ static int no_load(struct module_data *m, HIO_HANDLE *f, const int start)
 	for (i = 0; i < mod->ins; i++) {
 		if (mod->xxs[i].len == 0)
 			continue;
-		if (load_sample(m, f, SAMPLE_FLAG_UNS, &mod->xxs[i], NULL) < 0)
+		if (libxmp_load_sample(m, f, SAMPLE_FLAG_UNS, &mod->xxs[i], NULL) < 0)
 			return -1;
 	}
 
