@@ -34,6 +34,12 @@ static int depack_np1(HIO_HANDLE *in, FILE *out)
 	pw_write_zero(out, 20);			/* write title */
 
 	len = hio_read16b(in) >> 1;		/* size of pattern list */
+
+	/* Sanity check */
+	if (len > 128) {
+		return -1;
+	}
+
 	hio_read16b(in);			/* 2 unknown bytes */
 	/*tsize =*/ hio_read16b(in);		/* read track data size */
 
@@ -103,6 +109,10 @@ static int depack_np1(HIO_HANDLE *in, FILE *out)
 				c3 = hio_read8(in);
 				c4 = (c1 & 0xfe) / 2;
 
+				if (hio_error(in) || c4 >= 37) {
+					return -1;
+				}
+
 				tmp[x] = ((c1 << 4) & 0x10) | ptk_table[c4][0];
 				tmp[x + 1] = ptk_table[c4][1];
 
