@@ -23,9 +23,9 @@ static int depack_p61a(HIO_HANDLE *in, FILE *out)
     long max_row;
     uint8 tmp[1024];
     signed char *smp_buffer;
-    int len = 0;
-    int npat = 0;
-    int nins = 0;
+    int len;
+    int npat;
+    int nins;
     uint8 tdata[512][256];
     uint8 ptable[128];
     int isize[31];
@@ -49,13 +49,19 @@ static int depack_p61a(HIO_HANDLE *in, FILE *out)
     memset(isize, 0, 31 * 2);
     for (i = 0; i < 31; i++) {
 	PACK[i] = 0;
-/*    DELTA[i] = 0;*/
+	/* DELTA[i] = 0;*/
     }
 
     saddr[0] = 0;
-    sdata_addr = hio_read16b(in);		/* read sample data address */
-    npat = hio_read8(in);			/* read Real number of pattern */
-    nins = hio_read8(in);			/* read number of samples */
+    sdata_addr = hio_read16b(in);	/* read sample data address */
+    npat = hio_read8(in);		/* read real number of pattern */
+
+    /* Sanity check */
+    if (npat >= 128) {
+        return -1;
+    }
+
+    nins = hio_read8(in);		/* read number of samples */
 
     if (nins & 0x80) {
 	/* Samples are saved as delta values */
@@ -138,7 +144,9 @@ static int depack_p61a(HIO_HANDLE *in, FILE *out)
     fwrite(ptable, 128, 1, out);	/* write pattern table */
     write32b(out, PW_MOD_MAGIC);	/* write ptk ID */
 
-    tdata_addr = hio_tell(in);
+    if ((tdata_addr = hio_tell(in)) < 0) {
+        return -1;
+    }
 
     /* rewrite the track data */
     for (i = 0; i < npat; i++) {
@@ -284,7 +292,9 @@ static int depack_p61a(HIO_HANDLE *in, FILE *out)
 			c4 = hio_read8(in);
 	                z = (c3 << 8) + c4;
 	            }
-	            a = hio_tell(in);
+	            if ((a = hio_tell(in)) < 0) {
+                        return -1;
+                    }
 	            c5 = c2;
 
 	            hio_seek(in, -z, SEEK_CUR);
