@@ -34,6 +34,8 @@ const struct pw_format *const pw_format[NUM_PW_FORMATS + 1] = {
 	&pw_wn,
 	&pw_unic_id,
 	&pw_tp3,
+	&pw_tp2,
+	&pw_tp1,
 	&pw_skyt,
 
 	/* No signature */
@@ -44,6 +46,7 @@ const struct pw_format *const pw_format[NUM_PW_FORMATS + 1] = {
 	&pw_p4x,
 	&pw_pp21,
 	&pw_pp30,
+	&pw_pp10,
 	&pw_p50a,
 	&pw_p60a,
 	&pw_p61a,
@@ -59,6 +62,7 @@ const struct pw_format *const pw_format[NUM_PW_FORMATS + 1] = {
 	&pw_tdd,
 	&pw_starpack,
 	&pw_gmc,
+	/* &pw_pm01, */
 	&pw_titanics,
 	NULL
 };
