@@ -61,7 +61,7 @@ extern const struct pw_format pw_np2;
 extern const struct pw_format pw_np3;
 extern const struct pw_format pw_nru;
 extern const struct pw_format pw_ntp;
-extern const struct pw_format pw_p01;
+extern const struct pw_format pw_pm01;
 extern const struct pw_format pw_p10c;
 extern const struct pw_format pw_p18a;
 extern const struct pw_format pw_p20;
@@ -70,6 +70,7 @@ extern const struct pw_format pw_p50a;
 extern const struct pw_format pw_p60a;
 extern const struct pw_format pw_p61a;
 extern const struct pw_format pw_pha;
+extern const struct pw_format pw_pp10;
 extern const struct pw_format pw_pp21;
 extern const struct pw_format pw_pp30;
 extern const struct pw_format pw_pru1;
@@ -79,6 +80,8 @@ extern const struct pw_format pw_starpack;
 extern const struct pw_format pw_stim;
 extern const struct pw_format pw_tdd;
 extern const struct pw_format pw_titanics;
+extern const struct pw_format pw_tp1;
+extern const struct pw_format pw_tp2;
 extern const struct pw_format pw_tp3;
 extern const struct pw_format pw_unic_emptyid;
 extern const struct pw_format pw_unic_id;
