@@ -36,7 +36,7 @@ static uint8 set_event(uint8 *x, uint8 c1, uint8 c2, uint8 c3)
 #define track(p,c,r) tdata[((int)(p) * 4 + (c)) * 512 + (r) * 4]
 
 
-static void decode_pattern(HIO_HANDLE *in, int npat, uint8 *tdata, int taddr[128][4])
+static int decode_pattern(HIO_HANDLE *in, int npat, uint8 *tdata, int taddr[128][4])
 {
     int i, j, k, l;
     int max_row;
@@ -45,7 +45,9 @@ static void decode_pattern(HIO_HANDLE *in, int npat, uint8 *tdata, int taddr[128
     long pos;
     uint8 c1, c2, c3, c4;
 
-    tdata_addr = hio_tell(in);
+    if ((tdata_addr = hio_tell(in)) < 0) {
+        return -1;
+    }
 
     for (i = 0; i < npat; i++) {
 	max_row = 63;
@@ -100,7 +102,9 @@ static void decode_pattern(HIO_HANDLE *in, int npat, uint8 *tdata, int taddr[128
 		    int lines;
 
 		    c4 = hio_read8(in);
-		    pos = hio_tell(in);
+		    if ((pos = hio_tell(in)) < 0) {
+                        return -1;
+                    }
 		    lines = c2;
 		    hio_seek(in, -(((int)c3 << 8) + c4), SEEK_CUR);
 
@@ -170,6 +174,8 @@ static void decode_pattern(HIO_HANDLE *in, int npat, uint8 *tdata, int taddr[128
 	    }
 	}
     }
+
+    return 0;
 }
 
 
@@ -184,7 +190,7 @@ static int theplayer_depack(HIO_HANDLE *in, FILE *out, int version)
     uint8 ptable[128];
     int isize[31];
     uint8 delta = 0;
-    uint8 pack = 0;
+    /*uint8 pack = 0;*/
     int taddr[128][4];
     int sdata_addr = 0;
     int ssize = 0;
@@ -195,9 +201,9 @@ static int theplayer_depack(HIO_HANDLE *in, FILE *out, int version)
     int val;
     uint8 buf[1024];
 
-    tdata = calloc(512, 256);
-    if (tdata == NULL)
+    if ((tdata = calloc(512, 256)) == NULL) {
 	return -1;
+    }
 
     memset(taddr, 0, 128 * 4 * 4);
     memset(ptable, 0, 128);
@@ -211,6 +217,13 @@ static int theplayer_depack(HIO_HANDLE *in, FILE *out, int version)
     saddr[0] = 0;
     sdata_addr = hio_read16b(in);		/* read sample data address */
     npat = hio_read8(in);			/* read real number of patterns */
+
+    /* Sanity check */
+    if (npat > 128) {
+	free(tdata);
+        return -1;
+    }
+
     nins = hio_read8(in);			/* read number of samples */
 
     if (nins & 0x80) {
@@ -228,8 +241,16 @@ static int theplayer_depack(HIO_HANDLE *in, FILE *out, int version)
 
     nins &= 0x3f;
 
+    /* Sanity check */
+    if (nins > 31) {
+	free(tdata);
+        return -1;
+    }
+
+#if 0
     if (pack == 1)
 	/* unpacked_ssize =*/ hio_read32b(in);	/* unpacked sample data size */
+#endif
 
     pw_write_zero(out, 20);		/* write title */
 
@@ -296,7 +317,10 @@ static int theplayer_depack(HIO_HANDLE *in, FILE *out, int version)
     write32b(out, PW_MOD_MAGIC);	/* M.K. */
 
     /* patterns */
-    decode_pattern(in, npat, tdata, taddr);
+    if (decode_pattern(in, npat, tdata, taddr) < 0) {
+        free(tdata);
+        return -1;
+    }
 
     /* write pattern data */
     for (i = 0; i < npat; i++) {
