@@ -129,7 +129,7 @@ struct RTSMHeader {		/* Real Tracker Sample */
 static int rtm_test(HIO_HANDLE *, char *, const int);
 static int rtm_load (struct module_data *, HIO_HANDLE *, const int);
 
-const struct format_loader rtm_loader = {
+const struct format_loader libxmp_loader_rtm = {
 	"Real Tracker",
 	rtm_test,
 	rtm_load
@@ -147,7 +147,7 @@ static int rtm_test(HIO_HANDLE *f, char *t, const int start)
 	if (hio_read8(f) != 0x20)
 		return -1;
 
-	read_title(f, t, 32);
+	libxmp_read_title(f, t, 32);
 
 	return 0;
 }
@@ -240,14 +240,15 @@ static int rtm_load(struct module_data *m, HIO_HANDLE *f, const int start)
 	mod->spd = rh.speed;
 	mod->bpm = rh.tempo;
 
-	m->quirk |= rh.flags & 0x01 ? QUIRK_LINEAR : 0;
+	m->c4rate = C4_NTSC_RATE;
+	m->period_type = rh.flags & 0x01 ? PERIOD_LINEAR : PERIOD_AMIGA;
 
 	MODULE_INFO();
 
 	for (i = 0; i < mod->chn; i++)
 		mod->xxc[i].pan = rh.panning[i] & 0xff;
 
-	if (pattern_init(mod) < 0)
+	if (libxmp_init_pattern(mod) < 0)
 		return -1;
 
 	D_(D_INFO "Stored patterns: %d", mod->pat);
@@ -276,7 +277,7 @@ static int rtm_load(struct module_data *m, HIO_HANDLE *f, const int start)
 
 		offset += 42 + oh.headerSize + rp.datasize;
 
-		if (pattern_tracks_alloc(mod, i, rp.nrows) < 0)
+		if (libxmp_alloc_pattern_tracks(mod, i, rp.nrows) < 0)
 			return -1;
 
 		for (r = 0; r < rp.nrows; r++) {
@@ -336,7 +337,7 @@ static int rtm_load(struct module_data *m, HIO_HANDLE *f, const int start)
 	/* ESTIMATED value! We don't know the actual value at this point */
 	mod->smp = MAX_SAMP;
 
-	if (instrument_init(mod) < 0)
+	if (libxmp_init_instrument(m) < 0)
 		return -1;
 
 	smpnum = 0;
@@ -348,7 +349,7 @@ static int rtm_load(struct module_data *m, HIO_HANDLE *f, const int start)
 			return -1;
 		}
 
-		instrument_name(mod, i, (uint8 *)&oh.name, 32);
+		libxmp_instrument_name(mod, i, (uint8 *)&oh.name, 32);
 
 		if (oh.headerSize == 0) {
 			D_(D_INFO "[%2X] %-26.26s %2d ", i,
@@ -418,7 +419,7 @@ static int rtm_load(struct module_data *m, HIO_HANDLE *f, const int start)
 		if (xxi->nsm > 16)
 			xxi->nsm = 16;
 
-		if (subinstrument_alloc(mod, i, xxi->nsm) < 0)
+		if (libxmp_alloc_subinstrument(mod, i, xxi->nsm) < 0)
 			return -1;
 
 		for (j = 0; j < 120; j++)
@@ -467,7 +468,7 @@ static int rtm_load(struct module_data *m, HIO_HANDLE *f, const int start)
 			rs.basenote = hio_read8(f);
 			rs.panning = hio_read8(f);
 
-			c2spd_to_note(rs.basefreq, &sub->xpo, &sub->fin);
+			libxmp_c2spd_to_note(rs.basefreq, &sub->xpo, &sub->fin);
 			sub->xpo += 48 - rs.basenote;
 			sub->vol = rs.defaultvolume * rs.basevolume / 0x40;
 			sub->pan = 0x80 + rs.panning * 2;
@@ -478,14 +479,14 @@ static int rtm_load(struct module_data *m, HIO_HANDLE *f, const int start)
 			sub->sid = smpnum;
 
 			if (smpnum >= mod->smp) {
-				 mod->xxs = realloc_samples(mod->xxs,
+				 mod->xxs = libxmp_realloc_samples(mod->xxs,
 						&mod->smp, mod->smp * 3 / 2);
 				if (mod->xxs == NULL)
 					return -1;
 			}
  			xxs = &mod->xxs[smpnum];
 
-			copy_adjust(xxs->name, (uint8 *)oh.name, 31);
+			libxmp_copy_adjust(xxs->name, (uint8 *)oh.name, 31);
 
 			xxs->len = rs.length;
 			xxs->lps = rs.loopbegin;
@@ -511,13 +512,13 @@ static int rtm_load(struct module_data *m, HIO_HANDLE *f, const int start)
 				xxs->flg & XMP_SAMPLE_LOOP ? 'L' : ' ',
 				sub->vol, sub->fin, sub->pan, sub->xpo);
 
-			if (load_sample(m, f, SAMPLE_FLAG_DIFF, xxs, NULL) < 0)
+			if (libxmp_load_sample(m, f, SAMPLE_FLAG_DIFF, xxs, NULL) < 0)
 				return -1;
 		}
 	}
 
 	/* Final sample number adjustment */
-	mod->xxs = realloc_samples(mod->xxs, &mod->smp, smpnum);
+	mod->xxs = libxmp_realloc_samples(mod->xxs, &mod->smp, smpnum);
 	if (mod->xxs == NULL)
 		return -1;
 
