@@ -75,10 +75,6 @@
 #include "s3m.h"
 #include "period.h"
 
-#ifndef LIBXMP_CORE_PLAYER
-#include "synth.h"
-#endif
-
 #define MAGIC_SCRM	MAGIC4('S','C','R','M')
 #define MAGIC_SCRI	MAGIC4('S','C','R','I')
 #define MAGIC_SCRS	MAGIC4('S','C','R','S')
@@ -86,7 +82,7 @@
 static int s3m_test(HIO_HANDLE *, char *, const int);
 static int s3m_load(struct module_data *, HIO_HANDLE *, const int);
 
-const struct format_loader s3m_loader = {
+const struct format_loader libxmp_loader_s3m = {
 	"Scream Tracker 3",
 	s3m_test,
 	s3m_load
@@ -103,7 +99,7 @@ static int s3m_test(HIO_HANDLE *f, char *t, const int start)
 		return -1;
 
 	hio_seek(f, start + 0, SEEK_SET);
-	read_title(f, t, 28);
+	libxmp_read_title(f, t, 28);
 
 	return 0;
 }
@@ -152,6 +148,12 @@ static void xlat_fx(int c, struct xmp_event *e)
 {
 	uint8 h = MSN(e->fxp), l = LSN(e->fxp);
 
+	if (e->fxt > 26) {
+		D_(D_WARN "invalid effect %02x", e->fxt);
+		e->fxt = e->fxp = 0;
+		return;
+	}
+
 	switch (e->fxt = fx[e->fxt]) {
 	case FX_S3M_BPM:
 		if (e->fxp < 0x20) {
@@ -294,7 +296,7 @@ static int s3m_load(struct module_data *m, HIO_HANDLE * f, const int start)
 	}
 #endif
 
-	copy_adjust(mod->name, sfh.name, 28);
+	libxmp_copy_adjust(mod->name, sfh.name, 28);
 
 	pp_ins = calloc(2, sfh.insnum);
 	if (pp_ins == NULL)
@@ -305,7 +307,7 @@ static int s3m_load(struct module_data *m, HIO_HANDLE * f, const int start)
 		goto err2;
 
 	if (sfh.flags & S3M_AMIGA_RANGE)
-		m->quirk |= QUIRK_MODRNG;
+		m->period_type = PERIOD_MODRNG;
 	if (sfh.flags & S3M_ST300_VOLS)
 		m->quirk |= QUIRK_VSALL;
 	/* m->volbase = 4096 / sfh.gv; */
@@ -377,8 +379,9 @@ static int s3m_load(struct module_data *m, HIO_HANDLE * f, const int start)
 
 	m->c4rate = C4_NTSC_RATE;
 
-	if (sfh.version == 0x1300)
+	if (sfh.version == 0x1300) {
 		m->quirk |= QUIRK_VSALL;
+	}
 
 #ifndef LIBXMP_CORE_PLAYER
 	switch (sfh.version >> 12) {
@@ -423,14 +426,15 @@ static int s3m_load(struct module_data *m, HIO_HANDLE * f, const int start)
 		snprintf(tracker_name, 40, "unknown (%04x)", sfh.version);
 	}
 
-	set_type(m, "%s S3M", tracker_name);
+	libxmp_set_type(m, "%s S3M", tracker_name);
 #else
-	set_type(m, "Scream Tracker 3");
+	libxmp_set_type(m, "Scream Tracker 3");
+	m->quirk |= QUIRK_ST3BUGS;
 #endif
 
 	MODULE_INFO();
 
-	if (pattern_init(mod) < 0)
+	if (libxmp_init_pattern(mod) < 0)
 		goto err3;
 
 	/* Read patterns */
@@ -438,7 +442,7 @@ static int s3m_load(struct module_data *m, HIO_HANDLE * f, const int start)
 	D_(D_INFO "Stored patterns: %d", mod->pat);
 
 	for (i = 0; i < mod->pat; i++) {
-		if (pattern_tracks_alloc(mod, i, 64) < 0)
+		if (libxmp_alloc_pattern_tracks(mod, i, 64) < 0)
 			goto err3;
 
 		if (pp_pat[i] == 0)
@@ -486,9 +490,6 @@ static int s3m_load(struct module_data *m, HIO_HANDLE * f, const int start)
 
 			if (b & S3M_FX_FOLLOWS) {
 				event->fxt = hio_read8(f);
-				if (event->fxt > 26) {
-					goto err3;
-				}
 				event->fxp = hio_read8(f);
 				xlat_fx(c, event);
 
@@ -500,7 +501,7 @@ static int s3m_load(struct module_data *m, HIO_HANDLE * f, const int start)
 	D_(D_INFO "Stereo enabled: %s", sfh.mv & 0x80 ? "yes" : "no");
 	D_(D_INFO "Pan settings: %s", sfh.dp ? "no" : "yes");
 
-	if (instrument_init(mod) < 0)
+	if (libxmp_init_instrument(m) < 0)
 		goto err3;
 
 	/* Read and convert instruments and samples */
@@ -546,14 +547,14 @@ static int s3m_load(struct module_data *m, HIO_HANDLE * f, const int start)
 			}
 			sah.magic = 0;
 
-			instrument_name(mod, i, sah.name, 28);
+			libxmp_instrument_name(mod, i, sah.name, 28);
 
 			xxi->nsm = 1;
 			sub->vol = sah.vol;
-			c2spd_to_note(sah.c2spd, &sub->xpo, &sub->fin);
+			libxmp_c2spd_to_note(sah.c2spd, &sub->xpo, &sub->fin);
 			sub->xpo += 12;
 			ret =
-			    load_sample(m, f, SAMPLE_FLAG_ADLIB, xxs,
+			    libxmp_load_sample(m, f, SAMPLE_FLAG_ADLIB, xxs,
 					(char *)&sah.reg);
 			if (ret < 0)
 				goto err3;
@@ -622,7 +623,7 @@ static int s3m_load(struct module_data *m, HIO_HANDLE * f, const int start)
 		sub->vol = sih.vol;
 		sih.magic = 0;
 
-		instrument_name(mod, i, sih.name, 28);
+		libxmp_instrument_name(mod, i, sih.name, 28);
 
 		D_(D_INFO "[%2X] %-28.28s %04x%c%04x %04x %c V%02x %5d",
 		   i, mod->xxi[i].name, mod->xxs[i].len,
@@ -630,11 +631,11 @@ static int s3m_load(struct module_data *m, HIO_HANDLE * f, const int start)
 		   xxs->lps, mod->xxs[i].lpe,
 		   xxs->flg & XMP_SAMPLE_LOOP ? 'L' : ' ', sub->vol, sih.c2spd);
 
-		c2spd_to_note(sih.c2spd, &sub->xpo, &sub->fin);
+		libxmp_c2spd_to_note(sih.c2spd, &sub->xpo, &sub->fin);
 
 		hio_seek(f, start + 16L * sih.memseg, SEEK_SET);
 
-		ret = load_sample(m, f, sfh.ffi == 1 ? 0 : SAMPLE_FLAG_UNS,
+		ret = libxmp_load_sample(m, f, sfh.ffi == 1 ? 0 : SAMPLE_FLAG_UNS,
 								xxs, NULL);
 		if (ret < 0) {
 			goto err3;
@@ -644,10 +645,7 @@ static int s3m_load(struct module_data *m, HIO_HANDLE * f, const int start)
 	free(pp_pat);
 	free(pp_ins);
 
-#ifndef LIBXMP_CORE_PLAYER
-	m->synth = &synth_adlib;
-#endif
-	m->quirk |= QUIRKS_ST3;
+	m->quirk |= QUIRKS_ST3 | QUIRK_ARPMEM;
 	m->read_event_type = READ_EVENT_ST3;
 
 	return 0;
