@@ -24,7 +24,6 @@
 #include "loader.h"
 
 #ifndef LIBXMP_CORE_PLAYER
-#include "synth.h"
 
 /*
  * From the Audio File Formats (version 2.5)
@@ -79,26 +78,6 @@ static void convert_vidc_to_linear(uint8 *p, int l)
 	}
 }
 
-/* Convert HSC OPL2 instrument data to SBI instrument data */
-static void convert_hsc_to_sbi(uint8 *a)
-{
-	uint8 b[11];
-	int i;
-
-	for (i = 0; i < 10; i += 2) {
-		uint8 x;
-		x = a[i];
-		a[i] = a[i + 1];
-		a[i + 1] = x;
-	}
-
-	memcpy(b, a, 11);
-	a[8] = b[10];
-	a[10] = b[9];
-	a[9] = b[8];
-}
-
-
 static void adpcm4_decoder(uint8 *inp, uint8 *outp, char *tab, int len)
 {
 	char delta = 0;
@@ -216,32 +195,13 @@ static void unroll_loop(struct xmp_sample *xxs)
 }
 
 
-int load_sample(struct module_data *m, HIO_HANDLE *f, int flags, struct xmp_sample *xxs, void *buffer)
+int libxmp_load_sample(struct module_data *m, HIO_HANDLE *f, int flags, struct xmp_sample *xxs, void *buffer)
 {
 	int bytelen, extralen, unroll_extralen, i;
 
 #ifndef LIBXMP_CORE_PLAYER
 	/* Adlib FM patches */
 	if (flags & SAMPLE_FLAG_ADLIB) {
-		const int size = 11;
-
-		if (flags & SAMPLE_FLAG_HSC) {
-			convert_hsc_to_sbi(buffer);
-		}
-
-		xxs->data = malloc(size + 4);
-		if (xxs->data == NULL) {
-			return -1;
-		}
-
-		*(uint32 *)xxs->data = 0;
-		xxs->data += 4;
-
-		memcpy(xxs->data, buffer, size);
-
-		xxs->flg |= XMP_SAMPLE_SYNTH;
-		xxs->len = size;
-
 		return 0;
 	}
 #endif
@@ -425,20 +385,20 @@ int load_sample(struct module_data *m, HIO_HANDLE *f, int flags, struct xmp_samp
 
 	/* Fix sample at loop */
 	if (xxs->flg & XMP_SAMPLE_LOOP) {
+		int lpe = xxs->lpe;
+		int lps = xxs->lps;
+
+		if (xxs->flg & XMP_SAMPLE_LOOP_BIDIR) {
+			lpe += lpe - lps;
+		}
+
 		if (xxs->flg & XMP_SAMPLE_16BIT) {
-			int lpe = xxs->lpe * 2;
-			int lps = xxs->lps * 2;
-
-			if (xxs->flg & XMP_SAMPLE_LOOP_BIDIR) {
-				lpe += (xxs->lpe - xxs->lps) * 2;
-			}
-
+			lpe <<= 1;
+			lps <<= 1;
 			for (i = 0; i < 8; i++) {
 				xxs->data[lpe + i] = xxs->data[lps + i];
 			}
 		} else {
-			int lpe = xxs->lpe + unroll_extralen;
-			int lps = xxs->lps;
 			for (i = 0; i < 4; i++) {
 				xxs->data[lpe + i] = xxs->data[lps + i];
 			}
