@@ -44,7 +44,7 @@ version of the table is as follows:
  * so I'll perform linear interpolation to have all 256 values
  */
 
-int const arch_vol_table[] = {
+int const libxmp_arch_vol_table[] = {
 	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
 	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
 	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
