@@ -47,37 +47,37 @@
 #define LIM16_HI	 32767
 #define LIM16_LO	-32768
 
-#define MIX_FN(x) void x(struct mixer_voice *, int *, int, int, int, int, int, int, int)
+#define MIX_FN(x) void libxmp_mix_##x(struct mixer_voice *, int *, int, int, int, int, int, int, int)
 
-MIX_FN(smix_mono_8bit_nearest);
-MIX_FN(smix_mono_8bit_linear);
-MIX_FN(smix_mono_16bit_nearest);
-MIX_FN(smix_mono_16bit_linear);
-MIX_FN(smix_stereo_8bit_nearest);
-MIX_FN(smix_stereo_8bit_linear);
-MIX_FN(smix_stereo_16bit_nearest);
-MIX_FN(smix_stereo_16bit_linear);
-MIX_FN(smix_mono_8bit_spline);
-MIX_FN(smix_mono_16bit_spline);
-MIX_FN(smix_stereo_8bit_spline);
-MIX_FN(smix_stereo_16bit_spline);
+MIX_FN(mono_8bit_nearest);
+MIX_FN(mono_8bit_linear);
+MIX_FN(mono_16bit_nearest);
+MIX_FN(mono_16bit_linear);
+MIX_FN(stereo_8bit_nearest);
+MIX_FN(stereo_8bit_linear);
+MIX_FN(stereo_16bit_nearest);
+MIX_FN(stereo_16bit_linear);
+MIX_FN(mono_8bit_spline);
+MIX_FN(mono_16bit_spline);
+MIX_FN(stereo_8bit_spline);
+MIX_FN(stereo_16bit_spline);
 
 #ifndef LIBXMP_CORE_DISABLE_IT
-MIX_FN(smix_mono_8bit_linear_filter);
-MIX_FN(smix_mono_16bit_linear_filter);
-MIX_FN(smix_stereo_8bit_linear_filter);
-MIX_FN(smix_stereo_16bit_linear_filter);
-MIX_FN(smix_mono_8bit_spline_filter);
-MIX_FN(smix_mono_16bit_spline_filter);
-MIX_FN(smix_stereo_8bit_spline_filter);
-MIX_FN(smix_stereo_16bit_spline_filter);
+MIX_FN(mono_8bit_linear_filter);
+MIX_FN(mono_16bit_linear_filter);
+MIX_FN(stereo_8bit_linear_filter);
+MIX_FN(stereo_16bit_linear_filter);
+MIX_FN(mono_8bit_spline_filter);
+MIX_FN(mono_16bit_spline_filter);
+MIX_FN(stereo_8bit_spline_filter);
+MIX_FN(stereo_16bit_spline_filter);
 #endif
 
 #ifdef LIBXMP_PAULA_SIMULATOR
-MIX_FN(smix_mono_a500);
-MIX_FN(smix_mono_a500_filter);
-MIX_FN(smix_stereo_a500);
-MIX_FN(smix_stereo_a500_filter);
+MIX_FN(mono_a500);
+MIX_FN(mono_a500_filter);
+MIX_FN(stereo_a500);
+MIX_FN(stereo_a500_filter);
 #endif
 
 /* Mixers array index:
@@ -90,52 +90,52 @@ MIX_FN(smix_stereo_a500_filter);
 typedef void (*mixer_set[])(struct mixer_voice *, int *, int, int, int, int, int, int, int);
 
 static mixer_set nearest_mixers = {
-	smix_mono_8bit_nearest,
-	smix_mono_16bit_nearest,
-	smix_stereo_8bit_nearest,
-	smix_stereo_16bit_nearest,
+	libxmp_mix_mono_8bit_nearest,
+	libxmp_mix_mono_16bit_nearest,
+	libxmp_mix_stereo_8bit_nearest,
+	libxmp_mix_stereo_16bit_nearest,
 
 #ifndef LIBXMP_CORE_DISABLE_IT
-	smix_mono_8bit_nearest,
-	smix_mono_16bit_nearest,
-	smix_stereo_8bit_nearest,
-	smix_stereo_16bit_nearest,
+	libxmp_mix_mono_8bit_nearest,
+	libxmp_mix_mono_16bit_nearest,
+	libxmp_mix_stereo_8bit_nearest,
+	libxmp_mix_stereo_16bit_nearest,
 #endif
 };
 
 static mixer_set linear_mixers = {
-	smix_mono_8bit_linear,
-	smix_mono_16bit_linear,
-	smix_stereo_8bit_linear,
-	smix_stereo_16bit_linear,
+	libxmp_mix_mono_8bit_linear,
+	libxmp_mix_mono_16bit_linear,
+	libxmp_mix_stereo_8bit_linear,
+	libxmp_mix_stereo_16bit_linear,
 
 #ifndef LIBXMP_CORE_DISABLE_IT
-	smix_mono_8bit_linear_filter,
-	smix_mono_16bit_linear_filter,
-	smix_stereo_8bit_linear_filter,
-	smix_stereo_16bit_linear_filter
+	libxmp_mix_mono_8bit_linear_filter,
+	libxmp_mix_mono_16bit_linear_filter,
+	libxmp_mix_stereo_8bit_linear_filter,
+	libxmp_mix_stereo_16bit_linear_filter
 #endif
 };
 
 static mixer_set spline_mixers = {
-	smix_mono_8bit_spline,
-	smix_mono_16bit_spline,
-	smix_stereo_8bit_spline,
-	smix_stereo_16bit_spline,
+	libxmp_mix_mono_8bit_spline,
+	libxmp_mix_mono_16bit_spline,
+	libxmp_mix_stereo_8bit_spline,
+	libxmp_mix_stereo_16bit_spline,
 
 #ifndef LIBXMP_CORE_DISABLE_IT
-	smix_mono_8bit_spline_filter,
-	smix_mono_16bit_spline_filter,
-	smix_stereo_8bit_spline_filter,
-	smix_stereo_16bit_spline_filter
+	libxmp_mix_mono_8bit_spline_filter,
+	libxmp_mix_mono_16bit_spline_filter,
+	libxmp_mix_stereo_8bit_spline_filter,
+	libxmp_mix_stereo_16bit_spline_filter
 #endif
 };
 
 #ifdef LIBXMP_PAULA_SIMULATOR
 static mixer_set a500_mixers = {
-	smix_mono_a500,
+	libxmp_mix_mono_a500,
 	NULL,
-	smix_stereo_a500,
+	libxmp_mix_stereo_a500,
 	NULL,
 	NULL,
 	NULL,
@@ -145,9 +145,9 @@ static mixer_set a500_mixers = {
 
 
 static mixer_set a500led_mixers = {
-	smix_mono_a500_filter,
+	libxmp_mix_mono_a500_filter,
 	NULL,
-	smix_stereo_a500_filter,
+	libxmp_mix_stereo_a500_filter,
 	NULL,
 	NULL,
 	NULL,
@@ -198,24 +198,6 @@ static void downmix_int_16bit(int16 *dest, int32 *src, int num, int amp, int off
 	}
 }
 
-
-/* Prepare the mixer for the next tick */
-void mixer_prepare(struct context_data *ctx)
-{
-	struct player_data *p = &ctx->p;
-	struct module_data *m = &ctx->m;
-	struct mixer_data *s = &ctx->s;
-	int bytelen;
-
-	s->ticksize = s->freq * m->time_factor * m->rrate / p->bpm / 1000;
-
-	bytelen = s->ticksize * sizeof(int);
-	if (~s->format & XMP_FORMAT_MONO) {
-		bytelen *= 2;
-	}
-	memset(s->buf32, 0, bytelen);
-}
-
 static void anticlick(struct mixer_voice *vi)
 {
 	vi->flags |= ANTICLICK;
@@ -277,7 +259,7 @@ static void set_sample_end(struct context_data *ctx, int voc, int end)
 	if (end) {
 		SET_NOTE(NOTE_SAMPLE_END);
 		if (HAS_QUIRK(QUIRK_RSTCHN)) {
-			virt_resetvoice(ctx, voc, 0);
+			libxmp_virt_resetvoice(ctx, voc, 0);
 		}
 	} else {
 		RESET_NOTE(NOTE_SAMPLE_END);
@@ -325,10 +307,27 @@ static void loop_reposition(struct context_data *ctx, struct mixer_voice *vi, st
 	}
 }
 
+
+/* Prepare the mixer for the next tick */
+void libxmp_mixer_prepare(struct context_data *ctx)
+{
+	struct player_data *p = &ctx->p;
+	struct module_data *m = &ctx->m;
+	struct mixer_data *s = &ctx->s;
+	int bytelen;
+
+	s->ticksize = s->freq * m->time_factor * m->rrate / p->bpm / 1000;
+
+	bytelen = s->ticksize * sizeof(int);
+	if (~s->format & XMP_FORMAT_MONO) {
+		bytelen *= 2;
+	}
+	memset(s->buf32, 0, bytelen);
+}
 /* Fill the output buffer calling one of the handlers. The buffer contains
  * sound for one tick (a PAL frame or 1/50s for standard vblank-timed mods)
  */
-void mixer_softmixer(struct context_data *ctx)
+void libxmp_mixer_softmixer(struct context_data *ctx)
 {
 	struct player_data *p = &ctx->p;
 	struct mixer_data *s = &ctx->s;
@@ -339,7 +338,7 @@ void mixer_softmixer(struct context_data *ctx)
 	double step;
 	int samples, size;
 	int vol_l, vol_r, voc, usmp;
-	int prev_l, prev_r;
+	int prev_l, prev_r = 0;
 	int lps, lpe;
 	int32 *buf_pos;
 	void (*mix_fn)(struct mixer_voice *, int *, int, int, int, int, int, int, int);
@@ -371,9 +370,11 @@ void mixer_softmixer(struct context_data *ctx)
 	}
 #endif
 
-	mixer_prepare(ctx);
+	libxmp_mixer_prepare(ctx);
 
 	for (voc = 0; voc < p->virt.maxvoc; voc++) {
+		int c5spd;
+
 		vi = &p->virt.voice_array[voc];
 
 		if (vi->flags & ANTICLICK) {
@@ -388,7 +389,7 @@ void mixer_softmixer(struct context_data *ctx)
 		}
 
 		if (vi->period < 1) {
-			virt_resetvoice(ctx, voc, 1);
+			libxmp_virt_resetvoice(ctx, voc, 1);
 			continue;
 		}
 
@@ -403,18 +404,20 @@ void mixer_softmixer(struct context_data *ctx)
 			vol_l = vi->vol * (0x80 + vi->pan);
 		}
 
-		step = s->pbase / vi->period;
+		if (vi->smp < mod->smp) {
+			xxs = &mod->xxs[vi->smp];
+			c5spd = m->xtra[vi->smp].c5spd;
+		} else {
+			xxs = &ctx->smix.xxs[vi->smp - mod->smp];
+			c5spd = m->c4rate;
+		}
+
+		step = C4_PERIOD * c5spd / s->freq / vi->period;
 
 		if (step < 0.001) {	/* otherwise m5v-nwlf.it crashes */
 			continue;
 		}
 
-		if (vi->smp < mod->smp) {
-			xxs = &mod->xxs[vi->smp];
-		} else {
-			xxs = &ctx->smix.xxs[vi->smp - mod->smp];
-		}
-
 #ifndef LIBXMP_CORE_DISABLE_IT
 		if (xxs->flg & XMP_SAMPLE_SLOOP && vi->smp < mod->smp) {
 			if (~vi->flags & VOICE_RELEASE) {
@@ -475,7 +478,6 @@ void mixer_softmixer(struct context_data *ctx)
 			}
 
 			if (vi->vol) {
-				int idx;
 				int mix_size = samples;
 				int mixer = vi->fidx & FIDX_FLAGMASK;
 
@@ -484,10 +486,11 @@ void mixer_softmixer(struct context_data *ctx)
 				}
 
 				/* For Hipolito's anticlick routine */
-				idx = mix_size;
-				if (mix_size >= 2) {
-					prev_r = buf_pos[idx - 2];
-					prev_l = buf_pos[idx - 1];
+				if (samples > 0) {
+					if (~s->format & XMP_FORMAT_MONO) {
+						prev_r = buf_pos[mix_size - 2];
+					}
+					prev_l = buf_pos[mix_size - 1];
 				} else {
 					prev_r = prev_l = 0;
 				}
@@ -503,7 +506,7 @@ void mixer_softmixer(struct context_data *ctx)
 				mix_fn = (*mixers)[mixer];
 
 				/* Call the output handler */
-				if (samples >= 0 && vi->sptr != NULL) {
+				if (samples > 0 && vi->sptr != NULL) {
 					int rsize = 0;
 
 					if (rampsize > samples) {
@@ -529,10 +532,10 @@ void mixer_softmixer(struct context_data *ctx)
 
 
 					/* For Hipolito's anticlick routine */
-					if (mix_size >= 2) {
+					if (~s->format & XMP_FORMAT_MONO) {
 						vi->sright = buf_pos[-2] - prev_r;
-						vi->sleft = buf_pos[-1] - prev_l;
 					}
+					vi->sleft = buf_pos[-1] - prev_l;
 				}
 			}
 
@@ -541,9 +544,11 @@ void mixer_softmixer(struct context_data *ctx)
 			/* No more samples in this tick */
 			size -= samples + usmp;
 			if (size <= 0) {
-				if (vi->pos + step > vi->end) {
-					vi->pos += step;
-					loop_reposition(ctx, vi, xxs);
+				if (xxs->flg & XMP_SAMPLE_LOOP) {
+					if (vi->pos + step > vi->end) {
+						vi->pos += step;
+						loop_reposition(ctx, vi, xxs);
+					}
 				}
 				continue;
 			}
@@ -585,7 +590,7 @@ void mixer_softmixer(struct context_data *ctx)
 	s->dtright = s->dtleft = 0;
 }
 
-void mixer_voicepos(struct context_data *ctx, int voc, double pos)
+void libxmp_mixer_voicepos(struct context_data *ctx, int voc, double pos, int ac)
 {
 	struct player_data *p = &ctx->p;
 	struct module_data *m = &ctx->m;
@@ -630,16 +635,18 @@ void mixer_voicepos(struct context_data *ctx, int voc, double pos)
 #endif
 	}
 
-	anticlick(vi);
+	if (ac) {
+		anticlick(vi);
+	}
 }
 
-int mixer_getvoicepos(struct context_data *ctx, int voc)
+double libxmp_mixer_getvoicepos(struct context_data *ctx, int voc)
 {
 	struct player_data *p = &ctx->p;
 	struct mixer_voice *vi = &p->virt.voice_array[voc];
 	struct xmp_sample *xxs;
 
-	xxs = get_sample(ctx, vi->smp);
+	xxs = libxmp_get_sample(ctx, vi->smp);
 
 	if (xxs->flg & XMP_SAMPLE_SYNTH) {
 		return 0;
@@ -654,7 +661,7 @@ int mixer_getvoicepos(struct context_data *ctx, int voc)
 	return vi->pos;
 }
 
-void mixer_setpatch(struct context_data *ctx, int voc, int smp)
+void libxmp_mixer_setpatch(struct context_data *ctx, int voc, int smp, int ac)
 {
 	struct player_data *p = &ctx->p;
 #ifndef LIBXMP_CORE_DISABLE_IT
@@ -664,7 +671,7 @@ void mixer_setpatch(struct context_data *ctx, int voc, int smp)
 	struct mixer_voice *vi = &p->virt.voice_array[voc];
 	struct xmp_sample *xxs;
 
-	xxs = get_sample(ctx, smp);
+	xxs = libxmp_get_sample(ctx, smp);
 
 	vi->smp = smp;
 	vi->vol = 0;
@@ -679,13 +686,11 @@ void mixer_setpatch(struct context_data *ctx, int voc, int smp)
 
 	set_sample_end(ctx, voc, 0);
 
-	mixer_setvol(ctx, voc, 0);
+	/*mixer_setvol(ctx, voc, 0);*/
 
 	vi->sptr = xxs->data;
 	vi->fidx |= FLAG_ACTIVE;
 
-	anticlick(vi);
-
 #ifndef LIBXMP_CORE_DISABLE_IT
 	if (HAS_QUIRK(QUIRK_FILTER) && s->dsp & XMP_DSP_LOWPASS) {
 		vi->fidx |= FLAG_FILTER;
@@ -696,11 +701,10 @@ void mixer_setpatch(struct context_data *ctx, int voc, int smp)
 		vi->fidx |= FLAG_16_BITS;
 	}
 
-	mixer_voicepos(ctx, voc, 0);
-
+	libxmp_mixer_voicepos(ctx, voc, 0, ac);
 }
 
-void mixer_setnote(struct context_data *ctx, int voc, int note)
+void libxmp_mixer_setnote(struct context_data *ctx, int voc, int note)
 {
 	struct player_data *p = &ctx->p;
 	struct mixer_voice *vi = &p->virt.voice_array[voc];
@@ -713,12 +717,12 @@ void mixer_setnote(struct context_data *ctx, int voc, int note)
 	}
 
 	vi->note = note;
-	vi->period = note_to_period_mix(note, 0);
+	vi->period = libxmp_note_to_period_mix(note, 0);
 
 	anticlick(vi);
 }
 
-void mixer_setperiod(struct context_data *ctx, int voc, double period)
+void libxmp_mixer_setperiod(struct context_data *ctx, int voc, double period)
 {
 	struct player_data *p = &ctx->p;
 	struct mixer_voice *vi = &p->virt.voice_array[voc];
@@ -726,7 +730,7 @@ void mixer_setperiod(struct context_data *ctx, int voc, double period)
 	vi->period = period;
 }
 
-void mixer_setvol(struct context_data *ctx, int voc, int vol)
+void libxmp_mixer_setvol(struct context_data *ctx, int voc, int vol)
 {
 	struct player_data *p = &ctx->p;
 	struct mixer_voice *vi = &p->virt.voice_array[voc];
@@ -738,7 +742,7 @@ void mixer_setvol(struct context_data *ctx, int voc, int vol)
 	vi->vol = vol;
 }
 
-void mixer_release(struct context_data *ctx, int voc, int rel)
+void libxmp_mixer_release(struct context_data *ctx, int voc, int rel)
 {
 	struct player_data *p = &ctx->p;
 	struct mixer_voice *vi = &p->virt.voice_array[voc];
@@ -750,7 +754,7 @@ void mixer_release(struct context_data *ctx, int voc, int rel)
 	}
 }
 
-void mixer_seteffect(struct context_data *ctx, int voc, int type, int val)
+void libxmp_mixer_seteffect(struct context_data *ctx, int voc, int type, int val)
 {
 #ifndef LIBXMP_CORE_DISABLE_IT
 	struct player_data *p = &ctx->p;
@@ -776,7 +780,7 @@ void mixer_seteffect(struct context_data *ctx, int voc, int type, int val)
 #endif
 }
 
-void mixer_setpan(struct context_data *ctx, int voc, int pan)
+void libxmp_mixer_setpan(struct context_data *ctx, int voc, int pan)
 {
 	struct player_data *p = &ctx->p;
 	struct mixer_voice *vi = &p->virt.voice_array[voc];
@@ -784,7 +788,7 @@ void mixer_setpan(struct context_data *ctx, int voc, int pan)
 	vi->pan = pan;
 }
 
-int mixer_numvoices(struct context_data *ctx, int num)
+int libxmp_mixer_numvoices(struct context_data *ctx, int num)
 {
 	struct mixer_data *s = &ctx->s;
 
@@ -795,7 +799,7 @@ int mixer_numvoices(struct context_data *ctx, int num)
 	}
 }
 
-int mixer_on(struct context_data *ctx, int rate, int format, int c4rate)
+int libxmp_mixer_on(struct context_data *ctx, int rate, int format, int c4rate)
 {
 	struct mixer_data *s = &ctx->s;
 
@@ -811,7 +815,7 @@ int mixer_on(struct context_data *ctx, int rate, int format, int c4rate)
 	s->format = format;
 	s->amplify = DEFAULT_AMPLIFY;
 	s->mix = DEFAULT_MIX;
-	s->pbase = C4_PERIOD * c4rate / s->freq;
+	/* s->pbase = C4_PERIOD * c4rate / s->freq; */
 	s->interp = XMP_INTERP_LINEAR;	/* default interpolation type */
 	s->dsp = XMP_DSP_LOWPASS;	/* enable filters by default */
 	/* s->numvoc = SMIX_NUMVOC; */
@@ -825,7 +829,7 @@ int mixer_on(struct context_data *ctx, int rate, int format, int c4rate)
 	return -1;
 }
 
-void mixer_off(struct context_data *ctx)
+void libxmp_mixer_off(struct context_data *ctx)
 {
 	struct mixer_data *s = &ctx->s;
 
