@@ -66,6 +66,191 @@ static const struct retrig_control rval[] = {
  */
 
 
+/* Envelope */
+
+static int check_envelope_end(struct xmp_envelope *env, int x)
+{
+	int16 *data = env->data;
+	int index;
+
+	if (~env->flg & XMP_ENVELOPE_ON || env->npt <= 0)
+		return 0;
+
+	index = (env->npt - 1) * 2;
+
+	/* last node */
+	if (x >= data[index] || index == 0) { 
+		if (~env->flg & XMP_ENVELOPE_LOOP) {
+			return 1;
+		}
+	}
+
+	return 0;
+}
+
+static int get_envelope(struct xmp_envelope *env, int x, int def)
+{
+	int x1, x2, y1, y2;
+	int16 *data = env->data;
+	int index;
+
+	if (x < 0 || ~env->flg & XMP_ENVELOPE_ON || env->npt <= 0)
+		return def;
+
+	index = (env->npt - 1) * 2;
+
+	x1 = data[index];		/* last node */
+	if (x >= x1 || index == 0) { 
+		return data[index + 1];
+	}
+
+	do {
+		index -= 2;
+		x1 = data[index];
+	} while (index > 0 && x1 > x);
+
+	/* interpolate */
+	y1 = data[index + 1];
+	x2 = data[index + 2];
+	y2 = data[index + 3];
+
+	return x2 == x1 ? y2 : ((y2 - y1) * (x - x1) / (x2 - x1)) + y1;
+}
+
+static int update_envelope_xm(struct xmp_envelope *env, int x, int release)
+{
+	int16 *data = env->data;
+	int has_loop, has_sus;
+	int lpe, lps, sus;
+
+	has_loop = env->flg & XMP_ENVELOPE_LOOP;
+	has_sus = env->flg & XMP_ENVELOPE_SUS;
+
+	lps = env->lps << 1;
+	lpe = env->lpe << 1;
+	sus = env->sus << 1;
+
+	/* FT2 and IT envelopes behave in a different way regarding loops,
+	 * sustain and release. When the sustain point is at the end of the
+	 * envelope loop end and the key is released, FT2 escapes the loop
+	 * while IT runs another iteration. (See EnvLoops.xm in the OpenMPT
+	 * test cases.)
+	 */
+	if (has_loop && has_sus && sus == lpe) {
+		if (!release)
+			has_sus = 0;
+	}
+
+	/* If the envelope point is set to somewhere after the sustain point
+	 * or sustain loop, enable release to prevent the envelope point to
+	 * return to the sustain point or loop start. (See Filip Skutela's
+	 * farewell_tear.xm.)
+	 */
+	if (has_loop && x > data[lpe] + 1) {
+		release = 1;
+	} else if (has_sus && x > data[sus] + 1) {
+		release = 1;
+	}
+
+	/* If enabled, stay at the sustain point */
+	if (has_sus && !release) {
+		if (x >= data[sus]) {
+			x = data[sus];
+		}
+	}
+
+	/* Envelope loops */
+	if (has_loop && x >= data[lpe]) {
+		if (!(release && has_sus && sus == lpe))
+			x = data[lps];
+	}
+
+	return x;
+}
+
+#ifndef LIBXMP_CORE_DISABLE_IT
+
+static int update_envelope_it(struct xmp_envelope *env, int x, int release, int key_off)
+{
+	int16 *data = env->data;
+	int has_loop, has_sus;
+	int lpe, lps, sus, sue;
+
+	has_loop = env->flg & XMP_ENVELOPE_LOOP;
+	has_sus = env->flg & XMP_ENVELOPE_SUS;
+
+	lps = env->lps << 1;
+	lpe = env->lpe << 1;
+	sus = env->sus << 1;
+	sue = env->sue << 1;
+
+	/* Release at the end of a sustain loop, run another loop */
+	if (has_sus && key_off && x == data[sue] + 1) {
+		x = data[sus];
+	} else
+	/* If enabled, stay in the sustain loop */
+	if (has_sus && !release) {
+		if (x == data[sue] + 1) {
+			x = data[sus];
+		}
+	} else
+	/* Finally, execute the envelope loop */
+	if (has_loop) {
+		if (x > data[lpe]) {
+			x = data[lps];
+		}
+	}
+
+	return x;
+}
+
+#endif
+
+static int update_envelope(struct xmp_envelope *env, int x, int release, int key_off, int it_env)
+{
+	if (x < 0xffff)	{	/* increment tick */
+		x++;
+	}
+
+	if (x < 0) {
+		return -1;
+	}
+
+	if (~env->flg & XMP_ENVELOPE_ON || env->npt <= 0) {
+		return x;
+	}
+
+#ifndef LIBXMP_CORE_DISABLE_IT
+	return it_env ?
+		update_envelope_it(env, x, release, key_off) :
+		update_envelope_xm(env, x, release);
+#else
+	return update_envelope_xm(env, x, release);
+#endif
+}
+
+
+/* Returns: 0 if do nothing, <0 to reset channel, >0 if has fade */
+static int check_envelope_fade(struct xmp_envelope *env, int x)
+{
+	int16 *data = env->data;
+	int index;
+
+	if (~env->flg & XMP_ENVELOPE_ON)
+		return 0;
+
+	index = (env->npt - 1) * 2;		/* last node */
+	if (x > data[index]) {
+		if (data[index + 1] == 0)
+			return -1;
+		else
+			return 1;
+	}
+
+	return 0;
+}
+
+
 #ifndef LIBXMP_CORE_PLAYER
 
 /* From http://www.un4seen.com/forum/?topic=7554.0
@@ -185,7 +370,7 @@ static void reset_channels(struct context_data *ctx)
 		extra = xc->extra;
 		memset(xc, 0, sizeof (struct channel_data));
 		xc->extra = extra;
-		reset_channel_extras(ctx, xc);
+		libxmp_reset_channel_extras(ctx, xc);
 		xc->ins = -1;
 		xc->old_ins = 1;	/* raw value */
 		xc->key = -1;
@@ -329,9 +514,9 @@ static inline void read_row(struct context_data *ctx, int pat, int row)
 
 		if (check_delay(ctx, &ev, chn) == 0) {
 			if (!f->rowdelay_set || f->rowdelay > 0) {
-				read_event(ctx, &ev, chn);
+				libxmp_read_event(ctx, &ev, chn);
 #ifndef LIBXMP_CORE_PLAYER
-				med_hold_hack(ctx, pat, chn, row);
+				libxmp_med_hold_hack(ctx, pat, chn, row);
 #endif
 			}
 		} else {
@@ -357,7 +542,7 @@ static inline int get_channel_vol(struct context_data *ctx, int chn)
 		return 0;
 
 	/* root is invalid */
-	root = virt_getroot(ctx, chn);
+	root = libxmp_virt_getroot(ctx, chn);
 	if (root < 0)
 		return 0;
 
@@ -431,7 +616,7 @@ static void process_volume(struct context_data *ctx, int chn, int act)
 	uint16 vol_envelope;
 	int fade = 0;
 
-	instrument = get_instrument(ctx, xc->ins);
+	instrument = libxmp_get_instrument(ctx, xc->ins);
 
 	/* Keyoff and fadeout */
 
@@ -504,12 +689,12 @@ static void process_volume(struct context_data *ctx, int chn, int act)
 
 	/* If note ended in background channel, we can safely reset it */
 	if (TEST_NOTE(NOTE_END) && chn >= p->virt.num_tracks) {
-		virt_resetchannel(ctx, chn);
+		libxmp_virt_resetchannel(ctx, chn);
 		return;
 	}
 
 #ifndef LIBXMP_CORE_PLAYER
-	finalvol = extras_get_volume(ctx, xc);
+	finalvol = libxmp_extras_get_volume(ctx, xc);
 #else
 	finalvol = xc->volume;
 #endif
@@ -521,11 +706,11 @@ static void process_volume(struct context_data *ctx, int chn, int act)
 	if (TEST(TREMOLO)) {
 		/* OpenMPT VibratoReset.mod */
 		if (!is_first_frame(ctx) || !HAS_QUIRK(QUIRK_PROTRACK)) {
-			finalvol += get_lfo(ctx, &xc->tremolo.lfo, 0) / (1 << 6);
+			finalvol += libxmp_lfo_get(ctx, &xc->tremolo.lfo, 0) / (1 << 6);
 		}
 
 		if (!is_first_frame(ctx) || HAS_QUIRK(QUIRK_VIBALL)) {
-			update_lfo(&xc->tremolo.lfo);
+			libxmp_lfo_update(&xc->tremolo.lfo);
 		}
 	}
 
@@ -566,11 +751,11 @@ static void process_volume(struct context_data *ctx, int chn, int act)
 
 	xc->info_finalvol = TEST_NOTE(NOTE_SAMPLE_END) ? 0 : finalvol;
 
-	virt_setvol(ctx, chn, finalvol);
+	libxmp_virt_setvol(ctx, chn, finalvol);
 
 	/* Check Amiga split channel */
 	if (xc->split) {
-		virt_setvol(ctx, xc->pair, finalvol);
+		libxmp_virt_setvol(ctx, xc->pair, finalvol);
 	}
 }
 
@@ -591,7 +776,7 @@ static void process_frequency(struct context_data *ctx, int chn, int act)
 	int cutoff, resonance;
 #endif
 
-	instrument = get_instrument(ctx, xc->ins);
+	instrument = libxmp_get_instrument(ctx, xc->ins);
 
 	if (!TEST_PER(FENV_PAUSE)) {
 		xc->f_idx = update_envelope(&instrument->fei, xc->f_idx,
@@ -605,20 +790,20 @@ static void process_frequency(struct context_data *ctx, int chn, int act)
 	if (TEST(NOTE_SLIDE)) {
 		if (xc->noteslide.count == 0) {
 			xc->note += xc->noteslide.slide;
-			xc->period = note_to_period(ctx, xc->note, xc->finetune,
-					xc->per_adj);
+			xc->period = libxmp_note_to_period(ctx, xc->note,
+					xc->finetune, xc->per_adj);
 			xc->noteslide.count = xc->noteslide.speed;
 		}
 		xc->noteslide.count--;
 
-		virt_setnote(ctx, chn, xc->note);
+		libxmp_virt_setnote(ctx, chn, xc->note);
 	}
 #endif
 
 	/* Instrument vibrato */
-	vibrato = 1.0 * get_lfo(ctx, &xc->insvib.lfo, 1) /
+	vibrato = 1.0 * libxmp_lfo_get(ctx, &xc->insvib.lfo, 1) /
 				(4096 * (1 + xc->insvib.sweep));
-	update_lfo(&xc->insvib.lfo);
+	libxmp_lfo_update(&xc->insvib.lfo);
 	if (xc->insvib.sweep > 1) {
 		xc->insvib.sweep -= 2;
 	} else {
@@ -630,7 +815,7 @@ static void process_frequency(struct context_data *ctx, int chn, int act)
 		/* OpenMPT VibratoReset.mod */
 		if (!is_first_frame(ctx) || !HAS_QUIRK(QUIRK_PROTRACK)) {
 			int shift = HAS_QUIRK(QUIRK_VIBHALF) ? 10 : 9;
-			int vib = get_lfo(ctx, &xc->vibrato.lfo, 1) / (1 << shift);
+			int vib = libxmp_lfo_get(ctx, &xc->vibrato.lfo, 1) / (1 << shift);
 
 			if (HAS_QUIRK(QUIRK_VIBINV)) {
 				vibrato -= vib;
@@ -640,13 +825,13 @@ static void process_frequency(struct context_data *ctx, int chn, int act)
 		}
 
 		if (!is_first_frame(ctx) || HAS_QUIRK(QUIRK_VIBALL)) {
-			update_lfo(&xc->vibrato.lfo);
+			libxmp_lfo_update(&xc->vibrato.lfo);
 		}
 	}
 
 	period = xc->period;
 #ifndef LIBXMP_CORE_PLAYER
-	period += extras_get_period(ctx, xc);
+	period += libxmp_extras_get_period(ctx, xc);
 #endif
 
 	/* Sanity check */
@@ -680,7 +865,7 @@ static void process_frequency(struct context_data *ctx, int chn, int act)
 		}
 	}
 
-	linear_bend = period_to_bend(ctx, period + vibrato, xc->note,
+	linear_bend = libxmp_period_to_bend(ctx, period + vibrato, xc->note,
 							xc->per_adj);
 
 	if (TEST_NOTE(NOTE_GLISSANDO) && TEST(TONEPORTA)) {
@@ -725,18 +910,18 @@ static void process_frequency(struct context_data *ctx, int chn, int act)
 			if (xc->note + arp > MAX_NOTE_MOD + 1) {
 				linear_bend -= 12800 * (3 * 12);
 			} else if (xc->note + arp > MAX_NOTE_MOD) {
-				virt_setvol(ctx, chn, 0);
+				libxmp_virt_setvol(ctx, chn, 0);
 			}
 		}
 	}
 
 
 #ifndef LIBXMP_CORE_PLAYER
-	linear_bend += extras_get_linear_bend(ctx, xc);
+	linear_bend += libxmp_extras_get_linear_bend(ctx, xc);
 #endif
 
-	period = note_to_period_mix(xc->note, linear_bend);
-	virt_setperiod(ctx, chn, period);
+	period = libxmp_note_to_period_mix(xc->note, linear_bend);
+	libxmp_virt_setperiod(ctx, chn, period);
 
 	/* For xmp_get_frame_info() */
 	xc->info_pitchbend = linear_bend >> 7;
@@ -744,8 +929,8 @@ static void process_frequency(struct context_data *ctx, int chn, int act)
 
 	if (IS_PERIOD_MODRNG()) {
 		CLAMP(xc->info_period,
-			note_to_period(ctx, MAX_NOTE_MOD, xc->finetune, 0) * 4096,
-			note_to_period(ctx, MIN_NOTE_MOD, xc->finetune, 0) * 4096);
+			libxmp_note_to_period(ctx, MAX_NOTE_MOD, xc->finetune, 0) * 4096,
+			libxmp_note_to_period(ctx, MIN_NOTE_MOD, xc->finetune, 0) * 4096);
 	} else if (xc->info_period < (1 << 12)) {
 		xc->info_period = (1 << 12);
 	}
@@ -773,15 +958,15 @@ static void process_frequency(struct context_data *ctx, int chn, int act)
 		cutoff = 0xff;
 	} else if (cutoff < 0xff) {
 		int a0, b0, b1;
-		filter_setup(s->freq, cutoff, resonance, &a0, &b0, &b1);
-		virt_seteffect(ctx, chn, DSP_EFFECT_FILTER_A0, a0);
-		virt_seteffect(ctx, chn, DSP_EFFECT_FILTER_B0, b0);
-		virt_seteffect(ctx, chn, DSP_EFFECT_FILTER_B1, b1);
-		virt_seteffect(ctx, chn, DSP_EFFECT_RESONANCE, resonance);
+		libxmp_filter_setup(s->freq, cutoff, resonance, &a0, &b0, &b1);
+		libxmp_virt_seteffect(ctx, chn, DSP_EFFECT_FILTER_A0, a0);
+		libxmp_virt_seteffect(ctx, chn, DSP_EFFECT_FILTER_B0, b0);
+		libxmp_virt_seteffect(ctx, chn, DSP_EFFECT_FILTER_B1, b1);
+		libxmp_virt_seteffect(ctx, chn, DSP_EFFECT_RESONANCE, resonance);
 	}
 
 	/* Always set cutoff */
-	virt_seteffect(ctx, chn, DSP_EFFECT_CUTOFF, cutoff);
+	libxmp_virt_seteffect(ctx, chn, DSP_EFFECT_CUTOFF, cutoff);
 
 #endif
 }
@@ -797,7 +982,7 @@ static void process_pan(struct context_data *ctx, int chn, int act)
 	int pan_envelope;
 	int channel_pan;
 
-	instrument = get_instrument(ctx, xc->ins);
+	instrument = libxmp_get_instrument(ctx, xc->ins);
 
 	if (!TEST_PER(PENV_PAUSE)) {
 		xc->p_idx = update_envelope(&instrument->pei, xc->p_idx,
@@ -807,9 +992,9 @@ static void process_pan(struct context_data *ctx, int chn, int act)
 
 #ifndef LIBXMP_CORE_DISABLE_IT
 	if (TEST(PANBRELLO)) {
-		panbrello = get_lfo(ctx, &xc->panbrello.lfo, 0) / 512;
+		panbrello = libxmp_lfo_get(ctx, &xc->panbrello.lfo, 0) / 512;
 		if (is_first_frame(ctx)) {
-			update_lfo(&xc->panbrello.lfo);
+			libxmp_lfo_update(&xc->panbrello.lfo);
 		}
 	}
 #endif
@@ -845,9 +1030,9 @@ static void process_pan(struct context_data *ctx, int chn, int act)
 	xc->info_finalpan = finalpan + 0x80;
 
 	if (xc->pan.surround) {
-		virt_setpan(ctx, chn, PAN_SURROUND);
+		libxmp_virt_setpan(ctx, chn, PAN_SURROUND);
 	} else {
-		virt_setpan(ctx, chn, finalpan);
+		libxmp_virt_setpan(ctx, chn, finalpan);
 	}
 }
 
@@ -984,7 +1169,7 @@ static void update_frequency(struct context_data *ctx, int chn)
 #ifndef LIBXMP_CORE_PLAYER
 		if (TEST(FINE_NSLIDE)) {
 			xc->note += xc->noteslide.fslide;
-			xc->period = note_to_period(ctx, xc->note,
+			xc->period = libxmp_note_to_period(ctx, xc->note,
 				xc->finetune, xc->per_adj);
 		}
 #endif
@@ -996,8 +1181,8 @@ static void update_frequency(struct context_data *ctx, int chn)
 		break;
 	case PERIOD_MODRNG:
 		CLAMP(xc->period,
-			note_to_period(ctx, MAX_NOTE_MOD, xc->finetune, 0),
-			note_to_period(ctx, MIN_NOTE_MOD, xc->finetune, 0));
+			libxmp_note_to_period(ctx, MAX_NOTE_MOD, xc->finetune, 0),
+			libxmp_note_to_period(ctx, MIN_NOTE_MOD, xc->finetune, 0));
 		break;
 	}
 
@@ -1009,7 +1194,7 @@ static void update_frequency(struct context_data *ctx, int chn)
 	 * ambio.it uses low (~8) period values
 	 */
 	if (xc->period < 0.25) {
-		virt_setvol(ctx, chn, 0);
+		libxmp_virt_setvol(ctx, chn, 0);
 	}
 }
 
@@ -1055,11 +1240,11 @@ static void play_channel(struct context_data *ctx, int chn)
 	/* Do delay */
 	if (xc->delay > 0) {
 		if (--xc->delay == 0) {
-			read_event(ctx, &xc->delayed_event, chn);
+			libxmp_read_event(ctx, &xc->delayed_event, chn);
 		}
 	}
 
-	act = virt_cstat(ctx, chn);
+	act = libxmp_virt_cstat(ctx, chn);
 	if (act == VIRT_INVALID) {
 		/* We need this to keep processing global volume slides */
 		update_volume(ctx, chn);
@@ -1068,7 +1253,7 @@ static void play_channel(struct context_data *ctx, int chn)
 
 	if (p->frame == 0 && act != VIRT_ACTIVE) {
 		if (!IS_VALID_INSTRUMENT_OR_SFX(xc->ins) || act == VIRT_ACTION_CUT) {
-			virt_resetchannel(ctx, chn);
+			libxmp_virt_resetchannel(ctx, chn);
 			return;
 		}
 	}
@@ -1077,7 +1262,7 @@ static void play_channel(struct context_data *ctx, int chn)
 		return;
 
 #ifndef LIBXMP_CORE_PLAYER
-	play_extras(ctx, xc, chn);
+	libxmp_play_extras(ctx, xc, chn);
 #endif
 
 	/* Do cut/retrig */
@@ -1089,7 +1274,7 @@ static void play_channel(struct context_data *ctx, int chn)
 		if (cond) {
 			if (xc->retrig.type < 0x10) {
 				/* don't retrig on cut */
-				virt_voicepos(ctx, chn, 0);
+				libxmp_virt_voicepos(ctx, chn, 0);
 			} else {
 				SET_NOTE(NOTE_END);
 			}
@@ -1106,7 +1291,7 @@ static void play_channel(struct context_data *ctx, int chn)
 			SET_NOTE(NOTE_RELEASE);
 	}
 
-	virt_release(ctx, chn, TEST_NOTE(NOTE_RELEASE));
+	libxmp_virt_release(ctx, chn, TEST_NOTE(NOTE_RELEASE));
 
 	process_volume(ctx, chn, act);
 	process_frequency(ctx, chn, act);
@@ -1126,7 +1311,7 @@ static void play_channel(struct context_data *ctx, int chn)
 		SET_NOTE(NOTE_RELEASE);
 	}
 
-	xc->info_position = virt_getvoicepos(ctx, chn);
+	xc->info_position = libxmp_virt_getvoicepos(ctx, chn);
 }
 
 /*
@@ -1144,7 +1329,7 @@ static void inject_event(struct context_data *ctx)
 	for (chn = 0; chn < mod->chn + smix->chn; chn++) {
 		struct xmp_event *e = &p->inject_event[chn];
 		if (e->_flag > 0) {
-			read_event(ctx, e, chn);
+			libxmp_read_event(ctx, e, chn);
 			e->_flag = 0;
 		}
 	}
@@ -1173,7 +1358,7 @@ static void next_order(struct context_data *ctx)
 			    p->ord < m->seq_data[p->sequence].entry_point) {
 				p->ord = m->seq_data[p->sequence].entry_point;
 			} else {
-				if (get_sequence(ctx, mod->rst) == p->sequence) {
+				if (libxmp_get_sequence(ctx, mod->rst) == p->sequence) {
 					p->ord = mod->rst;
 				} else {
 					p->ord = m->seq_data[p->sequence].entry_point;
@@ -1246,9 +1431,9 @@ static void next_row(struct context_data *ctx)
 #ifndef LIBXMP_CORE_DISABLE_IT
 
 /*
- * Set note action for virt_pastnote
+ * Set note action for libxmp_virt_pastnote
  */
-void player_set_release(struct context_data *ctx, int chn)
+void libxmp_player_set_release(struct context_data *ctx, int chn)
 {
 	struct player_data *p = &ctx->p;
 	struct channel_data *xc = &p->xc_data[chn];
@@ -1256,7 +1441,7 @@ void player_set_release(struct context_data *ctx, int chn)
 	SET_NOTE(NOTE_RELEASE);
 }
 
-void player_set_fadeout(struct context_data *ctx, int chn)
+void libxmp_player_set_fadeout(struct context_data *ctx, int chn)
 {
 	struct player_data *p = &ctx->p;
 	struct channel_data *xc = &p->xc_data[chn];
@@ -1304,7 +1489,7 @@ int xmp_start_player(xmp_context opaque, int rate, int format)
 	if (ctx->state > XMP_STATE_LOADED)
 		xmp_end_player(opaque);
 
-	if (mixer_on(ctx, rate, format, m->c4rate) < 0)
+	if (libxmp_mixer_on(ctx, rate, format, m->c4rate) < 0)
 		return -XMP_ERROR_INTERNAL;
 
 	p->master_vol = 100;
@@ -1345,7 +1530,7 @@ int xmp_start_player(xmp_context opaque, int rate, int format)
 
 	update_from_ord_info(ctx);
 
-	if (virt_on(ctx, mod->chn + smix->chn) != 0) {
+	if (libxmp_virt_on(ctx, mod->chn + smix->chn) != 0) {
 		ret = -XMP_ERROR_INTERNAL;
 		goto err;
 	}
@@ -1371,7 +1556,7 @@ int xmp_start_player(xmp_context opaque, int rate, int format)
 #ifndef LIBXMP_CORE_PLAYER
 	for (i = 0; i < p->virt.virt_channels; i++) {
 		struct channel_data *xc = &p->xc_data[i];
-		if (new_channel_extras(ctx, xc) < 0)
+		if (libxmp_new_channel_extras(ctx, xc) < 0)
 			goto err2;
 	}
 #endif
@@ -1464,7 +1649,7 @@ int xmp_play_frame(xmp_context opaque)
 
 		update_from_ord_info(ctx);
 
-		virt_reset(ctx);
+		libxmp_virt_reset(ctx);
 		reset_channels(ctx);
 	} else {
 		p->frame++;
@@ -1516,7 +1701,7 @@ int xmp_play_frame(xmp_context opaque)
 	p->frame_time = m->time_factor * m->rrate / p->bpm;
 	p->current_time += p->frame_time;
 
-	mixer_softmixer(ctx);
+	libxmp_mixer_softmixer(ctx);
 
 	return 0;
 }
@@ -1597,11 +1782,11 @@ void xmp_end_player(xmp_context opaque)
 	/* Free channel extras */
 	for (i = 0; i < p->virt.virt_channels; i++) {
 		xc = &p->xc_data[i];
-		release_channel_extras(ctx, xc);
+		libxmp_release_channel_extras(ctx, xc);
 	}
 #endif
 
-	virt_off(ctx);
+	libxmp_virt_off(ctx);
 
 	free(p->xc_data);
 	free(f->loop);
@@ -1609,7 +1794,7 @@ void xmp_end_player(xmp_context opaque)
 	p->xc_data = NULL;
 	f->loop = NULL;
 
-	mixer_off(ctx);
+	libxmp_mixer_off(ctx);
 }
 
 void xmp_get_module_info(xmp_context opaque, struct xmp_module_info *info)
