@@ -2,7 +2,6 @@
 #define LIBXMP_PLAYER_H
 
 #include "lfo.h"
-#include "envelope.h"
 
 /* Quirk control */
 #define HAS_QUIRK(x)	(m->quirk & (x))
@@ -251,8 +250,9 @@ struct channel_data {
 };
 
 
-void process_fx(struct context_data *, struct channel_data *, int, struct xmp_event *, int);
-void filter_setup(int, int, int, int*, int*, int *);
-int read_event(struct context_data *, struct xmp_event *, int);
+void	libxmp_process_fx	(struct context_data *, struct channel_data *,
+				 int, struct xmp_event *, int);
+void	libxmp_filter_setup	(int, int, int, int*, int*, int *);
+int	libxmp_read_event	(struct context_data *, struct xmp_event *, int);
 
 #endif /* LIBXMP_PLAYER_H */
