@@ -27,7 +27,6 @@
 #include "effects.h"
 #include "virtual.h"
 #include "period.h"
-#include "envelope.h"
 
 #ifndef LIBXMP_CORE_PLAYER
 #include "med_extras.h"
@@ -91,7 +90,7 @@ static void reset_envelopes_carry(struct context_data *ctx,
 
  	RESET_NOTE(NOTE_ENV_END);
 
-	xxi = get_instrument(ctx, xc->ins);
+	xxi = libxmp_get_instrument(ctx, xc->ins);
 
 	/* Reset envelope positions */
 	if (~xxi->aei.flg & XMP_ENVELOPE_CARRY) {
@@ -144,13 +143,13 @@ static void set_effect_defaults(struct context_data *ctx, int note,
 		} */
 #endif
 
-		set_lfo_depth(&xc->insvib.lfo, sub->vde);
-		set_lfo_rate(&xc->insvib.lfo, sub->vra >> 2);
-		set_lfo_waveform(&xc->insvib.lfo, sub->vwf);
+		libxmp_lfo_set_depth(&xc->insvib.lfo, sub->vde);
+		libxmp_lfo_set_rate(&xc->insvib.lfo, sub->vra >> 2);
+		libxmp_lfo_set_waveform(&xc->insvib.lfo, sub->vwf);
 		xc->insvib.sweep = sub->vsw;
 
-		set_lfo_phase(&xc->vibrato.lfo, 0);
-		set_lfo_phase(&xc->tremolo.lfo, 0);
+		libxmp_lfo_set_phase(&xc->vibrato.lfo, 0);
+		libxmp_lfo_set_phase(&xc->tremolo.lfo, 0);
 	}
 
 	xc->delay = 0;
@@ -177,7 +176,7 @@ static void set_period(struct context_data *ctx, int note,
 	struct module_data *m = &ctx->m;
 
 	if (sub != NULL && note >= 0) {
-		double per = note_to_period(ctx, note, xc->finetune,
+		double per = libxmp_note_to_period(ctx, note, xc->finetune,
 							xc->per_adj);
 
 		if (!HAS_QUIRK(QUIRK_PROTRACK) || (note > 0 && is_toneporta)) {
@@ -200,12 +199,12 @@ static void set_period_ft2(struct context_data *ctx, int note,
 				struct channel_data *xc, int is_toneporta)
 {
 	if (note > 0 && is_toneporta) {
-		xc->porta.target = note_to_period(ctx, note, xc->finetune,
+		xc->porta.target = libxmp_note_to_period(ctx, note, xc->finetune,
 								xc->per_adj);
 	}
 	if (sub != NULL && note >= 0) {
 		if (xc->period < 1 || !is_toneporta) {
-			xc->period = note_to_period(ctx, note, xc->finetune,
+			xc->period = libxmp_note_to_period(ctx, note, xc->finetune,
 								xc->per_adj);
 		}
 	}
@@ -221,7 +220,7 @@ static void set_period_ft2(struct context_data *ctx, int note,
 #endif
 
 #define set_patch(ctx,chn,ins,smp,note) \
-	virt_setpatch(ctx, chn, ins, smp, note, 0, 0, 0)
+	libxmp_virt_setpatch(ctx, chn, ins, smp, note, 0, 0, 0)
 
 static int read_event_mod(struct context_data *ctx, struct xmp_event *e, int chn)
 {
@@ -281,7 +280,7 @@ static int read_event_mod(struct context_data *ctx, struct xmp_event *e, int chn
 			}
 		} else {
 			new_invalid_ins = 1;
-			virt_resetchannel(ctx, chn);
+			libxmp_virt_resetchannel(ctx, chn);
 		}
 	}
 
@@ -335,12 +334,12 @@ static int read_event_mod(struct context_data *ctx, struct xmp_event *e, int chn
 	}
 
 	/* Secondary effect handled first */
-	process_fx(ctx, xc, chn, e, 1);
-	process_fx(ctx, xc, chn, e, 0);
+	libxmp_process_fx(ctx, xc, chn, e, 1);
+	libxmp_process_fx(ctx, xc, chn, e, 0);
 
 #ifndef LIBXMP_CORE_PLAYER
 	if (IS_SFX_PITCH(e->fxt)) {
- 		xc->period = note_to_period(ctx, note, xc->finetune,
+ 		xc->period = libxmp_note_to_period(ctx, note, xc->finetune,
                                 			xc->per_adj);
 	} else
 #endif
@@ -354,7 +353,7 @@ static int read_event_mod(struct context_data *ctx, struct xmp_event *e, int chn
 
 	if (note >= 0) {
 		xc->note = note;
-		virt_voicepos(ctx, chn, xc->offset.val);
+		libxmp_virt_voicepos(ctx, chn, xc->offset.val);
 	}
 
 	if (TEST(OFFSET)) {
@@ -466,7 +465,12 @@ static int read_event_ft2(struct context_data *ctx, struct xmp_event *e, int chn
 			if (sub != NULL) {
 				int p = mod->xxc[chn].pan - 128;
 				xc->volume = sub->vol;
-				xc->pan.val = p + ((sub->pan - 128) * (128 - abs(p))) / 128 + 128;
+
+				if (!HAS_QUIRK(QUIRK_FTMOD)) {
+					xc->pan.val = p + ((sub->pan - 128) *
+						(128 - abs(p))) / 128 + 128;
+				}
+
 				xc->ins_fade = mod->xxi[xc->ins].rls;
 				SET(NEW_VOL);
 			}
@@ -521,7 +525,12 @@ static int read_event_ft2(struct context_data *ctx, struct xmp_event *e, int chn
 			if (sub != NULL) {
 				int p = mod->xxc[chn].pan - 128;
 				xc->volume = sub->vol;
-				xc->pan.val = p + ((sub->pan - 128) * (128 - abs(p))) / 128 + 128;
+
+				if (!HAS_QUIRK(QUIRK_FTMOD)) {
+					xc->pan.val = p + ((sub->pan - 128) *
+						(128 - abs(p))) / 128 + 128;
+				}
+
 				xc->ins_fade = mod->xxi[xc->ins].rls;
 			} else {
 				xc->volume = 0;
@@ -597,7 +606,7 @@ static int read_event_ft2(struct context_data *ctx, struct xmp_event *e, int chn
 		}
 
 		if (new_invalid_ins) {
-			virt_resetchannel(ctx, chn);
+			libxmp_virt_resetchannel(ctx, chn);
 		}
 	}
 
@@ -681,8 +690,8 @@ static int read_event_ft2(struct context_data *ctx, struct xmp_event *e, int chn
 	xc->offset.val = 0;
 
 	/* Secondary effect handled first */
-	process_fx(ctx, xc, chn, &ev, 1);
-	process_fx(ctx, xc, chn, &ev, 0);
+	libxmp_process_fx(ctx, xc, chn, &ev, 1);
+	libxmp_process_fx(ctx, xc, chn, &ev, 0);
 	set_period_ft2(ctx, note, sub, xc, is_toneporta);
 
 	if (sub == NULL) {
@@ -701,7 +710,7 @@ static int read_event_ft2(struct context_data *ctx, struct xmp_event *e, int chn
 		 *  Reported by Vladislav Suschikh.
 		 */
 		if (HAS_QUIRK(QUIRK_FT2BUGS) && xc->offset.val >= mod->xxs[sub->sid].len) {
-			virt_resetchannel(ctx, chn);
+			libxmp_virt_resetchannel(ctx, chn);
 		} else {
 
 			/* (From Decibelter - Cosmic 'Wegian Mamas.xm p04 ch7)
@@ -709,7 +718,7 @@ static int read_event_ft2(struct context_data *ctx, struct xmp_event *e, int chn
 			 * without tone portamento, otherwise we won't play
 			 * sweeps and loops correctly.
 			 */
-			virt_voicepos(ctx, chn, xc->offset.val);
+			libxmp_virt_voicepos(ctx, chn, xc->offset.val);
 		}
 	}
 
@@ -742,7 +751,7 @@ static int read_event_st3(struct context_data *ctx, struct xmp_event *e, int chn
 		is_toneporta = 1;
 	}
 
-	if (virt_mapchannel(ctx, chn) < 0 && xc->ins != e->ins - 1) {
+	if (libxmp_virt_mapchannel(ctx, chn) < 0 && xc->ins != e->ins - 1) {
 		is_toneporta = 0;
 	}
 
@@ -839,8 +848,8 @@ static int read_event_st3(struct context_data *ctx, struct xmp_event *e, int chn
 	}
 
 	/* Secondary effect handled first */
-	process_fx(ctx, xc, chn, e, 1);
-	process_fx(ctx, xc, chn, e, 0);
+	libxmp_process_fx(ctx, xc, chn, e, 1);
+	libxmp_process_fx(ctx, xc, chn, e, 0);
 	set_period(ctx, note, sub, xc, is_toneporta);
 
 	if (sub == NULL) {
@@ -849,7 +858,7 @@ static int read_event_st3(struct context_data *ctx, struct xmp_event *e, int chn
 
 	if (note >= 0) {
 		xc->note = note;
-		virt_voicepos(ctx, chn, xc->offset.val);
+		libxmp_virt_voicepos(ctx, chn, xc->offset.val);
 	}
 
 	if (use_ins_vol && !TEST(NEW_VOL)) {
@@ -880,7 +889,7 @@ static inline int has_note_event(struct xmp_event *e)
 
 static int check_fadeout(struct context_data *ctx, struct channel_data *xc, int ins)
 {
-	struct xmp_instrument *xxi = get_instrument(ctx, ins);
+	struct xmp_instrument *xxi = libxmp_get_instrument(ctx, ins);
 
 	if (xxi == NULL) {
 		return 1;
@@ -912,9 +921,9 @@ static void fix_period(struct context_data *ctx, int chn, struct xmp_subinstrume
 	if (sub->nna == XMP_INST_NNA_CONT) {
 		struct player_data *p = &ctx->p;
 		struct channel_data *xc = &p->xc_data[chn];
-		struct xmp_instrument *xxi = get_instrument(ctx, xc->ins);
+		struct xmp_instrument *xxi = libxmp_get_instrument(ctx, xc->ins);
 
-		xc->period = note_to_period(ctx, xc->key + sub->xpo +
+		xc->period = libxmp_note_to_period(ctx, xc->key + sub->xpo +
 			xxi->map[xc->key_porta].xpo, xc->finetune, xc->per_adj);
 	}
 }
@@ -1072,7 +1081,7 @@ static int read_event_it(struct context_data *ctx, struct xmp_event *e, int chn)
 			if (!key && !TEST_NOTE(NOTE_KEY_CUT)) {
 				/* Retrig in new ins in sample mode */
 				if (sample_mode && TEST_NOTE(NOTE_END)) {
-					virt_voicepos(ctx, chn, 0);
+					libxmp_virt_voicepos(ctx, chn, 0);
 				}
 
 				/* IT: Reset note for every new != ins */
@@ -1127,7 +1136,7 @@ static int read_event_it(struct context_data *ctx, struct xmp_event *e, int chn)
 		} else if (key == XMP_KEY_CUT) {
 			SET_NOTE(NOTE_END | NOTE_CUT | NOTE_KEY_CUT);
 			xc->period = 0;
-			virt_resetchannel(ctx, chn);
+			libxmp_virt_resetchannel(ctx, chn);
 		} else if (key == XMP_KEY_OFF) {
 			struct xmp_envelope *env = NULL;
 			if (IS_VALID_INSTRUMENT(xc->ins)) {
@@ -1186,9 +1195,9 @@ static int read_event_it(struct context_data *ctx, struct xmp_event *e, int chn)
 
 			if (not_same_smp) {
 				fix_period(ctx, chn, sub);
-				virt_resetchannel(ctx, chn);
+				libxmp_virt_resetchannel(ctx, chn);
 			}
-			to = virt_setpatch(ctx, chn, candidate_ins, smp,
+			to = libxmp_virt_setpatch(ctx, chn, candidate_ins, smp,
 				note, sub->nna, sub->dct, sub->dca);
 
 			/* Random value for volume swing */
@@ -1265,7 +1274,7 @@ static int read_event_it(struct context_data *ctx, struct xmp_event *e, int chn)
 	/* See OpenMPT wnoteoff.it vs noteoff3.it */
 	if (retrig_ins && not_same_ins) {
 		SET(NEW_INS);
-		virt_voicepos(ctx, chn, 0);
+		libxmp_virt_voicepos(ctx, chn, 0);
 		xc->fadeout = 0x10000;
 		RESET_NOTE(NOTE_RELEASE|NOTE_SUSEXIT|NOTE_FADEOUT);
 	}
@@ -1304,8 +1313,8 @@ static int read_event_it(struct context_data *ctx, struct xmp_event *e, int chn)
 	/* According to Storlek test 25, Impulse Tracker handles the volume
 	 * column effects after the standard effects.
 	 */
-	process_fx(ctx, xc, chn, &ev, 0);
-	process_fx(ctx, xc, chn, &ev, 1);
+	libxmp_process_fx(ctx, xc, chn, &ev, 0);
+	libxmp_process_fx(ctx, xc, chn, &ev, 1);
 	set_period(ctx, note, sub, xc, is_toneporta);
 
 	if (sub == NULL) {
@@ -1314,7 +1323,7 @@ static int read_event_it(struct context_data *ctx, struct xmp_event *e, int chn)
 
 	if (note >= 0) {
 		xc->note = note;
-		virt_voicepos(ctx, chn, xc->offset.val);
+		libxmp_virt_voicepos(ctx, chn, xc->offset.val);
 	}
 
 	if (use_ins_vol && !TEST(NEW_VOL)) {
@@ -1374,7 +1383,7 @@ static int read_event_med(struct context_data *ctx, struct xmp_event *e, int chn
 			}
 		} else {
 			new_invalid_ins = 1;
-			virt_resetchannel(ctx, chn);
+			libxmp_virt_resetchannel(ctx, chn);
 		}
 
 		MED_CHANNEL_EXTRAS(*xc)->arp = 0;
@@ -1397,7 +1406,7 @@ static int read_event_med(struct context_data *ctx, struct xmp_event *e, int chn
 		} else if (e->note == XMP_KEY_CUT) {
 			SET_NOTE(NOTE_END);
 			xc->period = 0;
-			virt_resetchannel(ctx, chn);
+			libxmp_virt_resetchannel(ctx, chn);
 		} else if (!is_toneporta && IS_VALID_INSTRUMENT(xc->ins)) {
 			struct xmp_instrument *xxi = &mod->xxi[xc->ins];
 
@@ -1458,8 +1467,8 @@ static int read_event_med(struct context_data *ctx, struct xmp_event *e, int chn
 	}
 
 	/* Secondary effect handled first */
-	process_fx(ctx, xc, chn, e, 1);
-	process_fx(ctx, xc, chn, e, 0);
+	libxmp_process_fx(ctx, xc, chn, e, 1);
+	libxmp_process_fx(ctx, xc, chn, e, 0);
 	set_period(ctx, note, sub, xc, is_toneporta);
 
 	if (sub == NULL) {
@@ -1468,7 +1477,7 @@ static int read_event_med(struct context_data *ctx, struct xmp_event *e, int chn
 
 	if (note >= 0) {
 		xc->note = note;
-		virt_voicepos(ctx, chn, xc->offset.val);
+		libxmp_virt_voicepos(ctx, chn, xc->offset.val);
 	}
 
 	if (use_ins_vol && !TEST(NEW_VOL)) {
@@ -1562,12 +1571,12 @@ static int read_event_smix(struct context_data *ctx, struct xmp_event *e, int ch
 	xc->volume = e->vol - 1;
 
 	xc->note = note;
-	virt_voicepos(ctx, chn, xc->offset.val);
+	libxmp_virt_voicepos(ctx, chn, xc->offset.val);
 
 	return 0;
 }
 
-int read_event(struct context_data *ctx, struct xmp_event *e, int chn)
+int libxmp_read_event(struct context_data *ctx, struct xmp_event *e, int chn)
 {
 	struct player_data *p = &ctx->p;
 	struct module_data *m = &ctx->m;
