@@ -125,7 +125,7 @@ static int scan_module(struct context_data *ctx, int ep, int chain)
 	    if (mod->rst > mod->len || mod->xxo[mod->rst] >= mod->pat) {
 		ord = ep;
 	    } else {
-		if (get_sequence(ctx, mod->rst) == chain) {
+		if (libxmp_get_sequence(ctx, mod->rst) == chain) {
 	            ord = mod->rst;
 		} else {
 		    ord = ep;
@@ -169,7 +169,7 @@ static int scan_module(struct context_data *ctx, int ep, int chain)
          * a loop containing e.g. a global volume fade can make the pattern
          * start with the wrong volume.
          */
-        if (!inside_loop) {
+        if (!inside_loop && info->gvl < 0) {
             info->gvl = gvl;
             info->bpm = bpm;
             info->speed = speed;
@@ -275,7 +275,7 @@ static int scan_module(struct context_data *ctx, int ep, int chain)
 		    frame_count += row_count * speed;
 		    row_count = 0;
 		    if (parm) {
-			if (p->flags & XMP_FLAGS_VBLANK || parm < 0x20) {
+			if (HAS_QUIRK(QUIRK_NOBPM) || p->flags & XMP_FLAGS_VBLANK || parm < 0x20) {
 			    if (parm > 0) {
 			        speed = parm;
 #ifndef LIBXMP_CORE_PLAYER
@@ -488,13 +488,13 @@ end_module:
     return (time + m->time_factor * frame_count * base_time / bpm);
 }
 
-int get_sequence(struct context_data *ctx, int ord)
+int libxmp_get_sequence(struct context_data *ctx, int ord)
 {
 	struct player_data *p = &ctx->p;
 	return p->sequence_control[ord];
 }
 
-int scan_sequences(struct context_data *ctx)
+int libxmp_scan_sequences(struct context_data *ctx)
 {
 	struct player_data *p = &ctx->p;
 	struct module_data *m = &ctx->m;
@@ -503,6 +503,13 @@ int scan_sequences(struct context_data *ctx)
 	int seq;
 	unsigned char temp_ep[XMP_MAX_MOD_LENGTH];
 
+	/* Initialize order data to prevent overwrite when a position is used
+	 * multiple times at different starting points (see janosik.xm).
+	 */
+	for (i = 0; i < XMP_MAX_MOD_LENGTH; i++) {
+		m->xxo_info[i].gvl = -1;
+	}
+
 	ep = 0;
 	memset(p->sequence_control, 0xff, XMP_MAX_MOD_LENGTH);
 	temp_ep[0] = 0;
