@@ -1,5 +1,5 @@
 /* Extended Module Player
- * Copyright (C) 1996-2015 Claudio Matsuoka and Hipolito Carraro Jr
+ * Copyright (C) 1996-2016 Claudio Matsuoka and Hipolito Carraro Jr
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -31,6 +31,11 @@
 #include <string.h>
 #include <limits.h>
 #include <unistd.h>
+
+#ifdef HAVE_UMASK
+#include <sys/stat.h>
+#endif
+
 #include "tempfile.h"
 
 #ifdef WIN32
@@ -56,7 +61,7 @@ static int get_temp_dir(char *buf, int size)
 	return 0;
 }
 
-#elif defined ANDROID
+#elif defined __ANDROID__
 
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -109,6 +114,9 @@ FILE *make_temp_file(char **filename) {
 	if ((*filename = strdup(tmp)) == NULL)
 		goto err;
 
+#ifdef HAVE_UMASK
+	umask(0177);
+#endif
 	if ((fd = mkstemp(*filename)) < 0)
 		goto err2;
 
